/******************************************************************/
/* ACM ICPC 2017-2018                                             */
/* NEERC - Northern Eurasia Finals                                */
/* St Petersburg - Barnaul - Tbilisi - Almaty, December 3, 2017   */
/******************************************************************/
/* Problem A. Archery Tournament                                  */
/*                                                                */
/* Original idea         Maxim Akhmedov                           */
/* Problem statement     Artem Vasilyev                           */
/* Test set              Artem Vasilyev                           */
/******************************************************************/
/* Tests                                                          */
/*                                                                */
/* Author                Artem Vasilyev                           */
/******************************************************************/

import java.io.*;
import java.nio.file.*;
import java.util.*;

public class Tests {
    private static int nTests = 0;
    private static final Path root = Paths.get("tests");
    private static final Random random = new Random("archery".hashCode());

    private static final int MAX_N = 200_000;
    private static final int MAX_X = 1_000_000_000;


    public static void main(String[] args) throws IOException {
        Files.createDirectories(root);
        printSample();
    }

    private static void printSample() {
        printTest(Arrays.asList(
                new Query(1, 0, 12),
                new Query(2, -11, 22),
                new Query(1, 24, 10),
                new Query(1, 12, 3),
                new Query(2, 12, 12),
                new Query(2, 16, 14),
                new Query(1, 28, 15),
                new Query(2, 3, 6)
        ));

        printRandom(10, 100, (int) 1e6, 1000, true);
        printRandom(1000, MAX_N - 1000, MAX_X, 1000, true);
        printRandom(5000, 10000, MAX_X, 1000, false);
        printRandom(MAX_N / 2, MAX_N / 2, MAX_X, 100, false);
        printRandom(MAX_N / 2, MAX_N / 2, MAX_X, 100, true);
        printRandom(MAX_N - 1, 1, MAX_X, 50, false);

        printMaxNested(100, 1000, (int) 1e5, false);
        printMaxNested(1000, 10000, (int) 1e5, true);
        printMaxNested(MAX_N / 2, MAX_N / 2, (int) 1e4, false);
        printMaxNested(MAX_N / 2, MAX_N / 2, (int) 1e4, true);
        printMaxNested(100, MAX_N - 100, (int) 1e9, false);

        printMaxNested2(MAX_N / 2, MAX_N / 2, (int) 1e4, false);
        printMaxNested2(MAX_N / 2, MAX_N / 2, (int) 1e4, true);
        printMaxNested2(100, MAX_N - 100, (int) 1e9, false);

        printInterleaving(100);
        printInterleaving(5000);
        printInterleaving(MAX_N);

        random.setSeed(32123L);
        printOneBigManySmall(5000, 10000);
        printOneBigManySmall(MAX_N / 2, MAX_N / 2);
        printOneBigManySmall(MAX_N / 3, 2 * MAX_N / 3);
        printOneBigManySmall(MAX_N * 2 / 3, MAX_N / 3);
        printOneBigManySmall(MAX_N / 4, MAX_N * 3 / 4);
        random.setSeed(32123L);

        printMaxNested3(MAX_N / 2, MAX_N / 2, (int) 1e4, false);
        printMaxNested3(MAX_N / 2, MAX_N / 2, (int) 1e4, true);
        printMaxNested3(100, MAX_N - 100, (int) 1e8, false);
        printMaxNested3(30, MAX_N - 30, (int) 1e9, false);

        printSomeBigManySmall(1000, MAX_N / 2 - 1000, (int) 1e4, 5, MAX_N / 2);
        printSomeBigManySmall(100, MAX_N / 2 - 100, (int) 1e5, 5, MAX_N / 2);
        printSomeBigManySmall(10, MAX_N / 2 - 10, (int) 1e8, 3, MAX_N / 2);
    }


    private static void printRandom(int n, int q, int maxX, int maxRadius, boolean shuffle) {
        List<Query> qs = new ArrayList<>();
        int lastX = -maxX;
        for (int i = 0; i < n; i++) {
            qs.add(randomCircle(lastX, lastX + maxRadius * 10, maxRadius));
            lastX = qs.get(i).x + qs.get(i).y + maxRadius;
        }
        for (int i = 0; i < q; i++) {
            if (random.nextBoolean()) {
                qs.add(new Query(2, randomRange(-maxX, maxX), randomRange(1, maxX)));
            } else {
                int pos = random.nextInt(n);
                qs.add(randomPointInCircle(qs.get(pos)));
            }
        }
        if (shuffle) {
            Collections.shuffle(qs, random);
        }
        printTest(qs);
    }

    private static void printMaxNested(int n, int q, int start, boolean shuffle) {
        List<Query> qs = new ArrayList<>();

        for (long pos = -MAX_X + start; pos <= MAX_X && qs.size() < n; pos += 2L * start) {
            int cur = start;
            while (cur > 0 && qs.size() < n) {
                qs.add(new Query(1, (int) (pos + start - cur), cur));
                cur /= 6;
            }
        }
        n = qs.size();
        for (int i = 0; i < q; i++) {
            int pos = random.nextInt(n);
            qs.add(new Query(2, qs.get(pos).x + qs.get(pos).y, qs.get(pos).y));
        }
        if (shuffle) {
            Collections.shuffle(qs, random);
        }
        printTest(qs);
    }

    private static void printMaxNested2(int n, int q, int start, boolean shuffle) {
        List<Query> qs = new ArrayList<>();

        for (long pos = -MAX_X + start; pos <= MAX_X && qs.size() < n; pos += 2L * start) {
            int cur = start;
            while (cur > 0 && qs.size() < n) {
                qs.add(new Query(1, (int) (pos + start - cur), cur));
                cur /= 6;
            }
        }
        n = qs.size();
        for (int i = 0; i < q; i++) {
            int pos = random.nextInt(n);
            qs.add(new Query(2, qs.get(pos).x + qs.get(pos).y - 1, MAX_X));
        }
        if (shuffle) {
            Collections.shuffle(qs, random);
        }
        printTest(qs);
    }

    private static void printMaxNested3(int n, int q, int start, boolean shuffle) {
        List<Query> qs = new ArrayList<>();
        List<Integer> positions = new ArrayList<>();
        for (long pos = -MAX_X + start; pos + start <= MAX_X && qs.size() < n; pos += 4L * start) {
            int cur = start;
            positions.add((int) pos);
            while (cur > 0 && qs.size() < n) {
                qs.add(new Query(1, (int) (pos - cur), cur));
                cur /= 6;
            }
            cur = start;
            while (cur > 0 && qs.size() < n) {
                qs.add(new Query(1, (int) (pos + cur), cur));
                cur /= 6;
            }
        }
        for (int i = 0; i < q; i++) {
            int pos = random.nextInt(positions.size());
            qs.add(new Query(2, positions.get(pos), randomRange(1, start)));
        }
        if (shuffle) {
            Collections.shuffle(qs, random);
        }
        printTest(qs);
    }


    private static void printInterleaving(int n) {
        List<Query> qs = new ArrayList<>();
        for (int i = 0; i < n; i++) {
            if (i % 2 == 0) {
                qs.add(randomCircle(MAX_X));
            } else {
                qs.add(randomPointInCircle(qs.get(i - 1)));
            }
        }
        printTest(qs);
    }

    private static void printOneBigManySmall(int n, int q) {
        List<Query> qs = new ArrayList<>();
        qs.add(new Query(1, randomRange(-MAX_X, 0), randomRange(1, MAX_X)));
        int lastX = qs.get(0).x + qs.get(0).y / 2;
        int maxR = 10;
        for (int i = 1; i < n; i++) {
            int y = randomRange(1, maxR);
            Query circle = new Query(1, lastX + y, y);
            qs.add(circle);
            lastX = qs.get(i).x + y * 2;
        }

        for (int i = 0; i < q / 2; i++) {
            qs.add(randomPointInCircle(qs.get(0)));
            qs.add(qs.get(0));
        }
        printTest(qs);
    }

    private static void printSomeBigManySmall(int big, int small, int bigR, int smallR, int queries) {
        List<Query> qs = new ArrayList<>();
        for (int i = 0; i < big; i++) {
            while (true) {
                Query q = randomCircle(-MAX_X, MAX_X, bigR);
                boolean inter = false;
                for (int j = 0; j < i; j++) {
                    if (circlesIntersect(qs.get(j), q)) {
                        inter=  true;
                        break;
                    }
                }
                if (!inter) {
                    qs.add(q);
                    break;
                }
            }
        }
        Set<Integer> usedPositions = new HashSet<>();
        for (int I = 0; I < small; I++) {
            while (true) {
                Query q = randomCircle(-MAX_X, MAX_X, smallR);
                boolean inter = false;
                for (int i = q.x - q.y; i <= q.x + q.y; i++) {
                    inter |= usedPositions.contains(i);
                    if (inter) {
                        break;
                    }
                }
                for (int j = 0; j < big; j++) {
                    inter |= circlesIntersect(q, qs.get(j));
                    if (inter) {
                        break;
                    }
                }
                if (!inter) {
                    qs.add(q);
                    break;
                }
            }
        }
        Collections.shuffle(qs, random);
        for (int i = 0; i < queries / 2; i++) {
            Query circle = qs.get(random.nextInt(big));
            Query q = randomPointInCircle(circle);
            qs.add(q);
            qs.add(circle);
        }
    }

    static Query randomCircle(int max) {
        return randomCircle(-max, max, max);
    }

    static Query randomCircle(int l, int r, int top) {
        return new Query(1, randomRange(l, r), randomRange(1, top));
    }

    static Query randomPointInCircle(Query circle) {
        int minX = Math.max(-MAX_X, circle.x - circle.y);
        int maxX = Math.min(MAX_X, circle.x + circle.y);
        int minY = 0;
        int maxY = Math.min(MAX_X, circle.y + circle.y);

        while (true) {
            int x = randomRange(minX, maxX);
            int y = randomRange(minY, maxY);
            if (inside(x, y, circle)) {
                return new Query(2, x, y);
            }
        }
    }

    private static boolean inside(int x, int y, Query circle) {
        return (long) (x - circle.x) * (x - circle.x) + (long) (y - circle.y) * (y - circle.y) < (long) circle.y * circle.y;
    }

    private static boolean circlesIntersect(Query a, Query b) {
        return (long) (a.x - b.x) * (a.x - b.x) + (long) (a.y - b.y) * (a.y - b.y) < (long) (a.y + b.y) * (a.y + b.y);
    }

    private static int randomRange(int from, int to) {
        return from + random.nextInt(to - from + 1);
    }

    private static int[] randomPermutation(int n) {
        int[] perm = new int[n];
        for (int i = 0; i < perm.length; i++) {
            perm[i] = i;
            int pos = random.nextInt(i + 1);
            perm[i] = perm[pos];
            perm[pos] = i;
        }
        return perm;
    }

    static class Query {
        int type, x, y;

        public Query(int type, int x, int y) {
            this.type = type;
            this.x = x;
            this.y = y;
        }
    }

    private static void printTest(List<Query> queries) {
        try (PrintWriter out = new PrintWriter(String.format("%s/%02d", root, ++nTests))) {
            System.out.println("Writing test " + nTests);
            out.println(queries.size());
            for (Query q : queries) {
                out.println(q.type + " " + q.x + " " + q.y);
            }
        } catch (IOException e) {
            throw new AssertionError(e);
        }
    }
}

