/******************************************************************/
/* ACM ICPC 2017-2018                                             */
/* NEERC - Northern Eurasia Finals                                */
/* St Petersburg - Barnaul - Tbilisi - Almaty, December 3, 2017   */
/******************************************************************/
/* Problem A. Archery Tournament                                  */
/*                                                                */
/* Original idea         Maxim Akhmedov                           */
/* Problem statement     Artem Vasilyev                           */
/* Test set              Artem Vasilyev                           */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Artem Vasilyev                           */
/******************************************************************/

import java.io.*;
import java.util.*;

public class archery_av {

    final int INF = Integer.MAX_VALUE;
    final int MAX_CIRCLES = 50;

    void solve() {
        int n = in.nextInt();
        Query[] qs = new Query[n];
        List<Pair> allXs = new ArrayList<>();
        for (int i = 0; i < n; i++) {
            qs[i] = new Query(in.nextInt(), in.nextInt(), in.nextInt());
            if (qs[i].type == 1) {
                allXs.add(new Pair(qs[i].x - qs[i].y, i));
            } else {
                allXs.add(new Pair(qs[i].x, i));
            }
        }
        Collections.sort(allXs);
        int[] pos = new int[n];
        for (int i = 0; i < allXs.size(); i++) {
            pos[allXs.get(i).id] = i;
        }
        SegmentTree st = new SegmentTree(allXs.size());
        IntersectingCircles result = new IntersectingCircles(MAX_CIRCLES);
        for (int i = 0; i < n; i++) {
            if (qs[i].type == 1) {
                st.set(pos[i], qs[i].x + qs[i].y);
            } else {
                int inter = -1;
                st.collect(pos[i], qs[i].x, result);
                for (int t = 0; t < result.size; t++) {
                    int cId = allXs.get(result.ids[t]).id;
                    long distSquared = sqr(qs[i].x - qs[cId].x) + sqr(qs[i].y - qs[cId].y);
                    if (distSquared < sqr(qs[cId].y)) {
                        if (inter != -1) {
                            throw new AssertionError();
                        }
                        inter = cId;
                        st.set(pos[inter], -INF);
                        break;
                    }
                }
                result.clear();
                out.println(inter == -1 ? -1 : (inter + 1));
            }
        }
    }

    long sqr(long x) {
        return x * x;
    }

    class SegmentTree {
        int[] value, max;
        int size;

        public SegmentTree(int n) {
            size = n;
            value = new int[n];
            max = new int[4 * size];
            Arrays.fill(value, -INF);
            build(0, size, 0);
        }

        void build(int l, int r, int i) {
            max[i] = l;
            if (l + 1 == r) {
                return;
            }
            int m = (l + r) >>> 1;
            build(l, m, i * 2 + 1);
            build(m, r, i * 2 + 2);
        }

        void set(int pos, int val) {
            internalSet(0, size, pos, val, 0);
        }

        void internalSet(int l, int r, int pos, int val, int i) {
            if (l + 1 == r) {
                value[pos] = val;
                return;
            }
            int m = (l + r) >>> 1;
            if (pos < m) {
                internalSet(l, m, pos, val, 2 * i + 1);
            } else {
                internalSet(m, r, pos, val, 2 * i + 2);
            }
            update(i);
        }

        void update(int i) {
            int m1 = max[2 * i + 1], m2 = max[2 * i + 2];
            max[i] = value[m1] > value[m2] ? m1 : m2;
        }

        void collect(int pos, int val, IntersectingCircles result) {
            internalCollect(0, size, pos, val, result, 0);
        }

        void internalCollect(int l, int r, int pos, int val, IntersectingCircles result, int i) {
            if (value[max[i]] < val || l > pos) {
                return;
            }
            if (l + 1 == r) {
                result.add(l);
                return;
            }
            int m = (l + r) >>> 1;
            internalCollect(l, m, pos, val, result, 2 * i + 1);
            internalCollect(m, r, pos, val, result, 2 * i + 2);
        }
    }

    class IntersectingCircles {
        int[] ids;
        int size;

        public IntersectingCircles(int sz) {
            ids = new int[sz];
            size = 0;
        }

        void add(int val) {
            ids[size++] = val;
        }

        void clear() {
            size = 0;
        }
    }

    class Pair implements Comparable<Pair> {
        int value, id;

        public Pair(int value, int id) {
            this.value = value;
            this.id = id;
        }

        @Override
        public int compareTo(Pair o) {
            return Integer.compare(value, o.value);
        }

        @Override
        public String toString() {
            return "Pair{" +
                    "value=" + value +
                    ", id=" + id +
                    '}';
        }
    }

    class Query {
        int type, x, y;

        public Query(int type, int x, int y) {
            this.type = type;
            this.x = x;
            this.y = y;
        }

        @Override
        public String toString() {
            return "Query{" +
                    "type=" + type +
                    ", x=" + x +
                    ", y=" + y +
                    '}';
        }
    }

    void run() throws FileNotFoundException {
        in = new FastScanner();
        out = new PrintWriter(System.out);
        solve();
        out.close();
    }

    FastScanner in;
    PrintWriter out;

    class FastScanner {
        BufferedReader br;
        StringTokenizer st;

        public FastScanner() {
            br = new BufferedReader(new InputStreamReader(System.in));
        }

        public FastScanner(String s) {
            try {
                br = new BufferedReader(new FileReader(s));
            } catch (FileNotFoundException e) {
                e.printStackTrace();
            }
        }

        public String nextToken() {
            while (st == null || !st.hasMoreTokens()) {
                try {
                    st = new StringTokenizer(br.readLine());
                } catch (IOException e) {
                }
            }
            return st.nextToken();
        }

        public int nextInt() {
            return Integer.parseInt(nextToken());
        }

        public long nextLong() {
            return Long.parseLong(nextToken());
        }

        public double nextDouble() {
            return Double.parseDouble(nextToken());
        }
    }

    public static void main(String[] args) throws FileNotFoundException {
        new archery_av().run();
    }
}

