/******************************************************************/
/* ACM ICPC 2017-2018                                             */
/* NEERC - Northern Eurasia Finals                                */
/* St Petersburg - Barnaul - Tbilisi - Almaty, December 3, 2017   */
/******************************************************************/
/* Problem A. Archery Tournament                                  */
/*                                                                */
/* Original idea         Maxim Akhmedov                           */
/* Problem statement     Artem Vasilyev                           */
/* Test set              Artem Vasilyev                           */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Borys Minaiev                            */
/******************************************************************/

import java.io.*;
import java.util.*;

public class archery_bm {
    private FastScanner in;
    private PrintWriter out;

    class Point {
        int x, y;
        int from, to;
        int realX;
        int id;

        public Point(int x, int y, int id) {
            this.x = x;
            realX = x;
            this.y = y;
            this.id = id;
            alive = true;
        }

        boolean inside(Point fire) {
            int dx = realX - fire.realX;
            int dy = y - fire.y;
            long dist = dx * 1L * dx + dy * 1L * dy;
            return dist < y * 1L * y;
        }

        boolean alive;
    }

    private void solve() {
        long START = System.currentTimeMillis();
        int n = in.nextInt();
        int[] type = new int[n];
        Point[] pts = new Point[n];
        for (int i = 0; i < n; i++) {
            type[i] = in.nextInt();
            pts[i] = new Point(in.nextInt(), in.nextInt(), i + 1);
        }
        List<Integer> xx = new ArrayList<>();
        for (Point p : pts) {
            xx.add(p.x);
            xx.add(p.x - p.y);
            xx.add(p.x + p.y);
        }
        Collections.sort(xx);
        int[] newX = new int[xx.size()];
        int sz = 0;
        for (int i = 0; i < xx.size(); i++) {
            if (i == 0 || xx.get(i) - xx.get(i - 1) != 0) {
                newX[sz++] = xx.get(i);
            }
        }
        for (Point p : pts) {
            p.from = Arrays.binarySearch(newX, 0, sz, p.x - p.y);
            p.to = Arrays.binarySearch(newX, 0, sz, p.x + p.y);
            p.x = Arrays.binarySearch(newX, 0, sz, p.x);
        }
        SegmentTree st = new SegmentTree(sz);
        for (int i = 0; i < n; i++) {
            if (type[i] == 1) {
                st.add(0, 0, sz - 1, pts[i]);
            } else {
                out.println(st.fire(0, 0, sz - 1, pts[i]));
            }
        }
        System.err.println(System.currentTimeMillis() - START);
    }

    class SegmentTree {
        List<Point>[] pts;

        SegmentTree(int n) {
            pts = new List[n * 4];
            for (int i = 0; i < pts.length; i++) {
                pts[i] = new ArrayList<>();
            }
        }

        void add(int v, int l, int r, Point p) {
            if (p.from > r || p.to < l) {
                return;
            }
            if (p.from <= l && p.to >= r) {
                pts[v].add(p);
                return;
            }
            int m = (l + r) >> 1;
            add(v * 2 + 1, l, m, p);
            add(v * 2 + 2, m + 1, r, p);
        }

        int fire(int v, int l, int r, Point p) {
            List<Point> curList = pts[v];
            for (int i = 0; i < curList.size(); i++) {
                Point pp = curList.get(i);
                if (!pp.alive) {
                    curList.set(i, curList.get(curList.size() - 1));
                    curList.remove(curList.size() - 1);
                    i--;
                    continue;
                }
                if (pp.inside(p)) {
                    pp.alive = false;
                    return pp.id;
                }
            }
            if (l == r) {
                return -1;
            }
            int m = (l + r) >> 1;
            if (p.x <= m) {
                return fire(v * 2 + 1, l, m, p);
            } else {
                return fire(v * 2 + 2, m + 1, r, p);
            }
        }
    }

    private void run() {
        try {
            in = new FastScanner(new File("archery.in"));
            out = new PrintWriter(new File("archery.out"));

            solve();

            out.close();
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        }
    }

    private void runIO() {
        in = new FastScanner(System.in);
        out = new PrintWriter(System.out);

        solve();

        out.close();
    }

    private class FastScanner {
        BufferedReader br;
        StringTokenizer st;

        FastScanner(File f) {
            try {
                br = new BufferedReader(new FileReader(f));
            } catch (FileNotFoundException e) {
                e.printStackTrace();
            }
        }

        FastScanner(InputStream f) {
            br = new BufferedReader(new InputStreamReader(f));
        }

        String next() {
            while (st == null || !st.hasMoreTokens()) {
                String s = null;
                try {
                    s = br.readLine();
                } catch (IOException e) {
                    e.printStackTrace();
                }
                if (s == null)
                    return null;
                st = new StringTokenizer(s);
            }
            return st.nextToken();
        }

        boolean hasMoreTokens() {
            while (st == null || !st.hasMoreTokens()) {
                String s = null;
                try {
                    s = br.readLine();
                } catch (IOException e) {
                    e.printStackTrace();
                }
                if (s == null)
                    return false;
                st = new StringTokenizer(s);
            }
            return true;
        }

        int nextInt() {
            return Integer.parseInt(next());
        }

        long nextLong() {
            return Long.parseLong(next());
        }

        double nextDouble() {
            return Double.parseDouble(next());
        }
    }

    public static void main(String[] args) {
        new archery_bm().runIO();
    }
}
