/******************************************************************/
/* ACM ICPC 2017-2018                                             */
/* NEERC - Northern Eurasia Finals                                */
/* St Petersburg - Barnaul - Tbilisi - Almaty, December 3, 2017   */
/******************************************************************/
/* Problem B. Box                                                 */
/*                                                                */
/* Original idea         Georgiy Korneev                          */
/* Problem statement     Niyaz Nigmatullin                        */
/* Test set              Niyaz Nigmatullin                        */
/******************************************************************/
/* Tests                                                          */
/*                                                                */
/* Author                Niyaz Nigmatullin                        */
/******************************************************************/

import java.io.File
import java.io.PrintWriter
import java.util.*

var tests = 0

val rng = Random("Staying tuned!".hashCode().toLong())

fun main(args: Array<String>) {
    // Sample Tests
    Test(1, 2, 3, 6, 5).print()
    Test(1, 2, 3, 5, 5).print()
    Test(1, 1, 1, 10, 2).print()
    // Other
    getMinimumTest2(2, 3, 1, 4, 100).print()
    getMinimumTest2(20, 30, 40, 76, 1000).print()
    getMinimumTest2( 30, 20, 40, 76, 1000).subtractOne().print()
    Test(1, 1, 1, 3, 4).print()
    Test(1, 1, 1, 3, 3).print()
    Test(1, 1, 1, 4, 4).print()
    Test(1, 1, 1, 2, 100000000).print()
    Test(3, 4, 5, 14, 13).print()
    Test(4, 5, 3, 14, 13).print()
    for (i in (20..50) + arrayOf(15, 16, 20, 1000000, 25000000, 99999999, 100000000)) {
        randomTest(i).print()
    }
    for (i in (40..50) + arrayOf(12345678, 12345679, 10000, 20000, 30000)) {
        if (rng.nextInt(3) == 0)
            randomMinimum(i).subtractOne().print()
        else
            randomMinimum(i).print()
        if (rng.nextInt(3) == 0)
            randomMinimum2(i).subtractOne().print()
        else
            randomMinimum2(i).print()
    }
}

fun randomTest(n: Int) = Test(rng.nextInt(n / 3) + 1, rng.nextInt(n / 3) + 1, rng.nextInt(n / 3) + 1,
                              rng.nextInt(2 * n / 3) + n / 3 + 1, rng.nextInt(2 * n / 3) + n / 3 + 1)

fun randomMinimum(n: Int): Test {
    while (true) {
        val a = rng.nextInt(n / 4) + 1
        val b = rng.nextInt(n / 4) + 1
        val c = rng.nextInt(n / 4) + 1
        val test = getMinimumTest(a, b, c)
        if (test.w > n || test.h > n) continue
        return test
    }
}

fun getMinimumTest(a: Int, b: Int, c: Int): Test {
    val (w, h) = getMinWH(a, b, c)
    return when(rng.nextBoolean()) {
        true -> Test(a, b, c, w, h)
        else -> Test(a, b, c, h, w)
    }
}

fun randomMinimum2(n: Int): Test {
    val a = rng.nextInt(n / 4) + 1
    val b = rng.nextInt(n / 4) + 1
    val c = rng.nextInt(n / 4) + 1
    val x = rng.nextInt(n) + 1
    return getMinimumTest2(a, b, c, x, n)
}

fun getMinimumTest2(a: Int, b: Int, c: Int, x: Int, n: Int): Test {
    var h = getMinH(a, b, c, x)
    if (h == Int.MAX_VALUE) {
        h = rng.nextInt(n) + 1
    }
    assert(h <= n)
    var w = getMinH(a, b, c, h)
    if (w == Int.MAX_VALUE) {
        w = rng.nextInt(n) + 1
    }
    assert(w <= n)
    return when(rng.nextBoolean()) {
        true -> Test(a, b, c, w, h)
        else -> Test(a, b, c, h, w)
    }
}

private fun getMinWH(a: Int, b: Int, c: Int): Pair<Int, Int> {
    var left = 0
    var right = Int.MAX_VALUE
    while (left < right - 1) {
        val mid = (left + right) ushr 1
        if (solve(a, b, c, mid, Int.MAX_VALUE)) {
            right = mid
        } else {
            left = mid
        }
    }
    if (right == Int.MAX_VALUE) throw AssertionError()
    val w = right
    val h = getMinH(a, b, c, w)
    return Pair(w, h)
}

private fun getMinH(a: Int, b: Int, c: Int, w: Int): Int {
    var left = 0
    var right = Int.MAX_VALUE
    while (left < right - 1) {
        val mid = (left + right) ushr 1
        if (solve(a, b, c, w, mid)) {
            right = mid
        } else {
            left = mid
        }
    }
    return right
}

data class Test(val a: Int, val b: Int, val c: Int, val w: Int, val h: Int) {

    fun print() {
        File("tests", "%02d".format(++tests)).printWriter().use {
            println("Printing test #$tests")
            printToStream(it)
        }
    }

    fun subtractOne() = when(rng.nextInt(2)) {
        0 -> Test(a, b, c, w - 1, h)
        else -> Test(a, b, c, w, h - 1)
    }

    private fun printToStream(stream: PrintWriter) {
        stream.println("$a $b $c")
        stream.println("$w $h")
    }
}



private fun check(x: Int, y: Int, w: Int, h: Int) = ((w >= x) and (h >= y)) or ((h >= x) and (w >= y))

private fun tryToSolve(a: Int, b: Int, c: Int, w: Int, h: Int) =
        check(a + a + c + c, b + c + c, w, h) or check(a + c + c, b + b + c + c, w, h) or
                check(a + c, 3 * b + a + c, w, h) or check(b + c, 3 * a + b + c, w, h)

private fun solve(a: Int, b: Int, c: Int, w: Int, h: Int) =
        tryToSolve(a, b, c, w, h) or tryToSolve(b, c, a, w, h) or tryToSolve(c, a, b, w, h)

