/******************************************************************/
/* ACM ICPC 2017-2018                                             */
/* NEERC - Northern Eurasia Finals                                */
/* St Petersburg - Barnaul - Tbilisi - Almaty, December 3, 2017   */
/******************************************************************/
/* Problem B. Box                                                 */
/*                                                                */
/* Original idea         Georgiy Korneev                          */
/* Problem statement     Niyaz Nigmatullin                        */
/* Test set              Niyaz Nigmatullin                        */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Niyaz Nigmatullin                        */
/******************************************************************/

import java.util.*
import kotlin.collections.HashMap

private var faceCount = 0

fun main(args: Array<String>) = with(Scanner(System.`in`)) {
    val (a, b, c) = Triple(nextInt(), nextInt(), nextInt())
    val (w, h) = Pair(nextInt(), nextInt())
    println(Backtrack().solve(a, b, c, w, h))
}

class Backtrack {
    fun solve(a: Int, b: Int, c: Int, w: Int, h: Int): String {
        val bot = Face(a, b)
        val top = Face(a, b)
        val right = Face(a, c)
        val left = Face(a, c)
        val front = Face(c, b)
        val back = Face(c, b)
        bot.add(Edge(0, 0, right, 0))
        right.add(Edge(2, 0, bot, 0))
        bot.add(Edge(2, 0, left, 1))
        left.add(Edge(0, 0, bot, 1))
        bot.add(Edge(3, 0, front, 2))
        front.add(Edge(1, 0, bot, 2))
        bot.add(Edge(1, 0, back, 3))
        back.add(Edge(3, 0, bot, 3))
        top.add(Edge(0, 2, right, 4))
        right.add(Edge(0, 2, top, 4))
        top.add(Edge(2, 2, left, 5))
        left.add(Edge(2, 2, top, 5))
        top.add(Edge(3, 0, back, 6))
        back.add(Edge(1, 0, top, 6))
        top.add(Edge(1, 0, front, 7))
        front.add(Edge(3, 0, top, 7))
        right.add(Edge(1, 1, back, 8))
        back.add(Edge(0, 3, right, 8))
        right.add(Edge(3, 3, front, 9))
        front.add(Edge(0, 1, right, 9))
        left.add(Edge(1, 3, back, 10))
        back.add(Edge(2, 1, left, 10))
        left.add(Edge(3, 1, front, 11))
        front.add(Edge(2, 3, left, 11))
        val faces = arrayOf(top, right, left, back, front, bot)
        return when {
            (0 until (1 shl 12)).filter { Integer.bitCount(it) == 5 }
                    .any { checkDraw(faces, it, w, h) } -> "Yes"
            else -> "No"
        }
    }

    private fun checkDraw(faces: Array<Face>, mask: Int, w: Int, h: Int): Boolean {
        val startFace = faces[0]
        val s = hashSetOf<Face>()
        startFace.gather(mask, s)
        if (s.size != 6) return false
        val position = hashMapOf<Face, Triple<Int, Int, Int>>()
        startFace.setPosition(position, mask, 0, 0, 0)
        var minX = 0
        var minY = 0
        var maxX = 0
        var maxY = 0
        for (x in faces) {
            val posX = position[x]!!
            val sizeX = x.rotate(posX.third)
            for (y in faces) {
                if (x === y) break
                val posY = position[y]!!
                val sizeY = y.rotate(posY.third)
                if (Math.max(posX.first, posY.first) < Math.min(posX.first + sizeX.first, posY.first + sizeY.first) &&
                        Math.max(posX.second, posY.second) < Math.min(posX.second + sizeX.second, posY.second + sizeY.second)) {
                    return false
                }
            }
            minX = Math.min(minX, posX.first)
            maxX = Math.max(maxX, posX.first + sizeX.first)
            minY = Math.min(minY, posX.second)
            maxY = Math.max(maxY, posX.second + sizeX.second)
        }
        val dx = maxX - minX
        val dy = maxY - minY
        return ((w >= dx) and (h >= dy)) or ((w >= dy) and (h >= dx))
    }

    class Face(val a: Int, val b: Int) {
        val id = faceCount++
        val neighbours = mutableListOf<Edge>()

        fun add(e: Edge) = neighbours.add(e)

        fun gather(mask: Int, s: MutableSet<Face>) {
            if (s.contains(this)) return
            s.add(this)
            for (e in neighbours) {
                if (((mask shr e.id) and 1) == 0) continue
                e.face.gather(mask, s)
            }
        }

        fun setPosition(position: HashMap<Face, Triple<Int, Int, Int>>, mask: Int, dir: Int, cx: Int, cy: Int) {
            if (position.containsKey(this)) return
            position[this] = Triple(cx, cy, dir)
            val dx = when (dir) {
                0, 2 -> b
                else -> a
            }
            val dy = when (dir) {
                0, 2 -> a
                else -> b
            }
            for (e in neighbours) {
                if (((mask shr e.id) and 1) == 0) continue
                val curDir = (e.dir - dir) and 3
                val nx = when (curDir) {
                    0 -> cx + dx
                    2 -> cx - (e.face.a xor e.face.b xor dy)
                    else -> cx
                }
                val ny = when (curDir) {
                    1 -> cy + dy
                    3 -> cy - (e.face.a xor e.face.b xor dx)
                    else -> cy
                }
                e.face.setPosition(position, mask, (dir + e.changeDir) and 3, nx, ny)
            }
        }

        fun rotate(dir: Int) = when(dir) {
            0, 2 -> Pair(b, a)
            else -> Pair(a, b)
        }

        override fun toString(): String {
            return "Face(a=$a, b=$b, id=$id)"
        }


    }

    class Edge(val dir: Int, val changeDir: Int, val face: Face, val id: Int)
}

