/******************************************************************/
/* ACM ICPC 2017-2018                                             */
/* NEERC - Northern Eurasia Finals                                */
/* St Petersburg - Barnaul - Tbilisi - Almaty, December 3, 2017   */
/******************************************************************/
/* Problem C. Connections                                         */
/*                                                                */
/* Original idea         Pavel Irzhavski                          */
/* Problem statement     Pavel Irzhavski                          */
/* Test set              Pavel Irzhavski                          */
/******************************************************************/
/* Tests                                                          */
/*                                                                */
/* Author                Pavel Irzhavski                          */
/******************************************************************/

import java.io.*;
import java.util.*;

public class Tests implements Runnable {
    final static int MAXM = 100 * 1000;

    int nTests = 0;
    static File root = new File("tests");
    Random random = new Random(1234567890);

    public static void main(String[] args) throws IOException {
        if (!root.exists()) {
            try {
                root.mkdir();
            } catch (Exception e) {
                System.out.println("Can not create tests/ directory: " + e);
                return;
            }
        }

        new Thread(null, new Tests(), "", 64 * 1024 * 1024).start();
    }

    int DFS(ArrayList<ArrayList<Integer>> G, int v, boolean[] visited) {
        visited[v] = true;
        int k = 1;

        for (int i = 0; i < G.get(v).size(); i++)
            if (!visited[G.get(v).get(i)])
                k += DFS(G, G.get(v).get(i), visited);

        return k;
    }

    boolean isStrong(ArrayList<Integer[]> arcs, int n) {
        for (int t = 0; t < 2; t++) {
            ArrayList<ArrayList<Integer>> G = new ArrayList<ArrayList<Integer>>();
            for (int i = 0; i <= n; i++)
                G.add(new ArrayList<Integer>());

            for (int i = 0; i < arcs.size(); i++)
                G.get(arcs.get(i)[0]).add(arcs.get(i)[1]);

            boolean[] visited = new boolean[n + 1];
            if (DFS(G, 1, visited) != n)
                return false;

            for (int i = 0; i < arcs.size(); i++) {
                int x = arcs.get(i)[0];
                arcs.get(i)[0] = arcs.get(i)[1];
                arcs.get(i)[1] = x;
            }
        }

        return true;
    }

    int n = 0;
    ArrayList<Integer[]> arcs = new ArrayList<Integer[]>();

    void addArc(int u, int v) {
        arcs.add(new Integer[]{ u, v });
    }

    void uniqueArcs() {
        Collections.sort(arcs, new java.util.Comparator<Integer[]>() {
            public int compare(Integer[] a, Integer[] b) {
                return Integer.compare(a[0], b[0]) != 0 ? Integer.compare(a[0], b[0]) : Integer.compare(a[1], b[1]);
            }
        });

        ArrayList<Integer[]> newArcs = new ArrayList<Integer[]>();
        for (int i = 0; i < arcs.size(); i++)
            if (i == 0 ||
                Integer.compare(arcs.get(i)[0], arcs.get(i - 1)[0]) != 0 ||
                Integer.compare(arcs.get(i)[1], arcs.get(i - 1)[1]) != 0)
                newArcs.add(arcs.get(i));

        arcs = newArcs;
    }

    public void run() {
        generate();
    }

    void generate() {
        generateSample();
        generateManySmall();
        generateGrowingSize();
        generateHuge();
    }

    void generateSample() {
        n = 4;
        addArc(1, 2);
        addArc(1, 3);
        addArc(2, 3);
        addArc(2, 4);
        addArc(3, 2);
        addArc(3, 4);
        addArc(4, 1);
        addArc(4, 2);
        addArc(4, 3);

        endCase(false);
        writeTest(false);
    }

    int[] randomPermutation(int k) {
        int[] p = new int[k];
        for (int i = 0; i < p.length; i++)
            p[i] = i;

        for (int i = 0; i < p.length; i++) {
            int j = random.nextInt(i + 1);
            int x = p[i];
            p[i] = p[j];
            p[j] = x;
        }

        return p;
    }

    void generateManySmall() {
        for (int x = 0; x < 2; x++)
            for (n = 5; n < 13; n++) {
                for (; sumM + n * n <= MAXM / (x == 0 ? 125 - 10 * n : 1); ) {
                    for (;;) {
                        if (isStrong(arcs, n)) {
                            uniqueArcs();

                            if (2 * n < arcs.size())
                                break;
                        }

                        int u = random.nextInt(n) + 1;
                        int v = random.nextInt(n) + 1;

                        if (u != v)
                            addArc(u, v);
                    }

                    endCase();
                }

                writeTest(true);
            }
    }

    void generateGrowingSize() {
        for (n = 13; n < MAXM / 2; n = n * 3) {
            for (; sumM +  2 * n + 1 <= MAXM; ) {
                int[] p = randomPermutation(n);
                for (int i = 0; i < p.length; i++) {
                    addArc(p[i] + 1, p[(i + 1) % n] + 1);
                    addArc(p[(i + 1) % n] + 1, p[i] + 1);
                }

                addArc(p[0] + 1, p[2] + 1);

                endCase();
            }

            writeTest(true);
        }
    }

    void generateHuge() {
        // Two random Hamiltonian cycles plus random arcs.
        n = MAXM / 2 - random.nextInt(987);

        for (int i = 0; i < 2; i++) {
            int[] p = randomPermutation(n);

            for (int j = 0; j < p.length; j++)
                addArc(p[j] + 1, p[(j + 1) % n] + 1);
        }

        int[] p = randomPermutation(n);
        for (int j = 1; j < p.length && arcs.size() < MAXM; j += 2)
            addArc(p[j - 1] + 1, p[j] + 1);

        endCase();
        writeTest(true);

        // Two random Hamiltonian cycles plus oriented random perfect matching.
        n = MAXM * 2 / 5 - random.nextInt(987);
        n &= ~1;

        for (int i = 0; i < 2; i++) {
            p = randomPermutation(n);

            for (int j = 0; j < p.length; j++)
                addArc(p[j] + 1, p[(j + 1) % n] + 1);
        }

        p = randomPermutation(n);
        for (int j = 1; j < p.length; j += 2)
            addArc(p[j - 1] + 1, p[j] + 1);

        endCase();
        writeTest(true);

        // Two-way path plus arcs from the start to other vertices.
        n = MAXM / 2 - random.nextInt(987);

        p = randomPermutation(n);
        for (int i = 1; i < p.length; i++) {
            addArc(p[i - 1] + 1, p[i] + 1);
            addArc(p[i] + 1, p[i - 1] + 1);
        }

        for (int i = 2; i < p.length && arcs.size() < MAXM; i++)
            addArc(p[0] + 1, p[i] + 1);

        endCase();
        writeTest(true);

        // Double star plus random arcs.
        n = MAXM / 2 - random.nextInt(987);

        p = randomPermutation(n);
        for (int i = 1; i < p.length; i++) {
            addArc(p[0] + 1, p[i] + 1);
            addArc(p[i] + 1, p[0] + 1);
        }

        p = randomPermutation(n);
        for (int i = 1; i < p.length && arcs.size() < MAXM; i += 2)
            addArc(p[i - 1] + 1, p[i] + 1);

        endCase();
        writeTest(true);
    }

    ArrayList<Integer> allN = new ArrayList<Integer>();
    ArrayList<ArrayList<Integer[]>> allArcs = new ArrayList<ArrayList<Integer[]>>();
    int sumM = 0;

    void endCase(boolean unique) {
        if (unique)
            uniqueArcs();

        if (arcs.size() <= 2 * n)
            System.out.println("There is not enough arcs.");

        if (!isStrong(arcs, n))
            System.out.println("A graph is not strong enough.");

        if (arcs.size() > MAXM)
            System.out.println("There are too many arcs.");

        if (sumM + arcs.size() > MAXM)
            writeTest(true);

        sumM += arcs.size();
        allN.add(n);
        allArcs.add(arcs);
        arcs = new ArrayList<Integer[]>();
    }

    void endCase() {
    	endCase(true);
    }
    
    void writeTest(boolean shuffle) {
        if (allN.size() == 0)
            return;

        try (PrintWriter fout = new PrintWriter(String.format("%s/%02d", root.getName(), ++nTests))) {
            System.out.println("Writing test " + nTests);
            fout.println(allN.size());
            for (int i = 0; i < allN.size(); i++) {
                int n = allN.get(i);
                int[] p = new int[n + 1];
                for (int j = 0; j < p.length; j++)
                    p[j] = j;

                Integer[][] a = new Integer[allArcs.get(i).size()][];
                for (int j = 0; j < a.length; j++)
                    a[j] = allArcs.get(i).get(j);
                    
                if (shuffle) {
                    for (int j = 1; j < p.length; j++) {
                        int k = random.nextInt(j) + 1;
                        int x = p[j];
                        p[j] = p[k];
                        p[k] = x;
                    }

                    for (int j = 0; j < a.length; j++) {
                        int k = random.nextInt(j + 1);
                        Integer[] x = a[j];
                        a[j] = a[k];
                        a[k] = x;
                    }
                }

                fout.println(n + " " + a.length);

                for (int j = 0; j < a.length; j++)
                    fout.println(p[a[j][0]] + " " + p[a[j][1]]);
            }
            fout.flush();
        } catch (IOException e) {
            System.out.println("Can not write test " + nTests + ": " + e);
        }

        allN.clear();
        allArcs.clear();
        sumM = 0;
    }
}

