/******************************************************************/
/* ACM ICPC 2017-2018                                             */
/* NEERC - Northern Eurasia Finals                                */
/* St Petersburg - Barnaul - Tbilisi - Almaty, December 3, 2017   */
/******************************************************************/
/* Problem D. Designing the Toy                                   */
/*                                                                */
/* Original idea         Maxim Akhmedov                           */
/* Problem statement     Maxim Akhmedov                           */
/* Test set              Maxim Akhmedov                           */
/******************************************************************/
/* Checker                                                        */
/*                                                                */
/* Author                Maxim Akhmedov                           */
/******************************************************************/

import ru.ifmo.testlib.Checker;
import ru.ifmo.testlib.InStream;
import ru.ifmo.testlib.Outcome;
import java.util.*;

public class Check implements Checker {

    final int MAXN = 1000_000;
    final int MAXC = 100;

    int readInt(InStream stream, int minv, int maxv, String name, Outcome.Type outcome) {
        int x = stream.nextInt();
        if (x < minv || x > maxv) {
            throw new Outcome(outcome, "Value of `" + name + "`: " + x +
                " does not belong to the range [" + minv + ", " + maxv + "]");
        }
        return x;
    }

    void checkProjection(boolean[][] projection, int expectedArea, String plane, Outcome.Type outcome)
    {
        int area = 0;
        for (int i = 0; i < projection.length; ++i) {
            for (int j = 0; j < projection[i].length; ++j) {
                area += projection[i][j] ? 1 : 0;
            }
        }
        if (area != expectedArea) {
            throw new Outcome(outcome, String.format(Locale.US,
                "Area of figure projection onto %s is: %d, expected: %d", plane, area, expectedArea));
        }
    }

    boolean readAns(int a, int b, int c, InStream stream, Outcome.Type outcome) {
        int n = readInt(stream, -1, MAXN, "n", outcome);
        if (n == -1) {
            if (!stream.seekEoF()) {
                throw new Outcome(outcome, "Extra data in output file");
            }
            return false;
        }
        boolean[][] usedXY = new boolean[2 * MAXC + 1][2 * MAXC + 1];
        boolean[][] usedXZ = new boolean[2 * MAXC + 1][2 * MAXC + 1];
        boolean[][] usedYZ = new boolean[2 * MAXC + 1][2 * MAXC + 1];
        Set<List<Integer>> voxels = new HashSet<List<Integer>>(n);
        for (int i = 0; i < n; i++) {
            int x = readInt(stream, -MAXC, MAXC, "x[" + i + "]", outcome);
            int y = readInt(stream, -MAXC, MAXC, "y[" + i + "]", outcome);
            int z = readInt(stream, -MAXC, MAXC, "z[" + i + "]", outcome);
            if (!voxels.add(Arrays.asList(x, y, z))) {
                throw new Outcome(outcome, String.format(Locale.US,
                        "Voxel (%d, %d, %d) appears twice", x, y, z));
            }
            x += MAXC;
            y += MAXC;
            z += MAXC;
            usedXY[x][y] = usedXZ[x][z] = usedYZ[y][z] = true;
        }
        if (!stream.seekEoF()) {
            throw new Outcome(outcome, "Extra data in output file");
        }
        checkProjection(usedXY, a, "Oxy", outcome);
        checkProjection(usedXZ, b, "Oxz", outcome);
        checkProjection(usedYZ, c, "Oyz", outcome);
        return true;
    }

    public Outcome test(InStream inf, InStream ouf, InStream ans) {
        int a = inf.nextInt();
        int b = inf.nextInt();
        int c = inf.nextInt();

        boolean juryAnswer = readAns(a, b, c, ans, Outcome.Type.FAIL);
        boolean participantAnswer = readAns(a, b, c, ouf, Outcome.Type.WA);

        if (juryAnswer && participantAnswer) {
            throw new Outcome(Outcome.Type.OK, "possible (a = " + a + ", b = " + b + ", c = " + c + ")");
        } else if (!juryAnswer && !participantAnswer) {
            throw new Outcome(Outcome.Type.OK, "impossible (a = " + a + ", b = " + b + ", c = " + c + ")");
        } else if (juryAnswer && !participantAnswer) {
            throw new Outcome(Outcome.Type.WA, "contestant didn't find answer, jury did (a = " + a + ", b = " + b + ", c = " + c + ")");
        } else if (!juryAnswer && participantAnswer) {
            throw new Outcome(Outcome.Type.FAIL, "contestant found answer, jury didn't (a = " + a + ", b = " + b + ", c = " + c + ")");
        }

        return null;
    }
}

