/******************************************************************/
/* ACM ICPC 2017-2018                                             */
/* NEERC - Northern Eurasia Finals                                */
/* St Petersburg - Barnaul - Tbilisi - Almaty, December 3, 2017   */
/******************************************************************/
/* Problem D. Designing the Toy                                   */
/*                                                                */
/* Original idea         Maxim Akhmedov                           */
/* Problem statement     Maxim Akhmedov                           */
/* Test set              Maxim Akhmedov                           */
/******************************************************************/
/* Tests                                                          */
/*                                                                */
/* Author                Maxim Akhmedov                           */
/******************************************************************/

import java.io.*;
import java.math.BigInteger;
import java.util.*;

public class Tests {
    static int nTests = 0;
    static File root = new File("tests");

    static Random random = new Random(43159345394151999L);

    public static void main(String[] args) throws IOException {
        if (!root.exists()) {
            try {
                root.mkdir();
            } catch (Exception e) {
                System.out.println("Can not create tests/ directory: " + e);
                return;
            }
        }

        generate();
    }

    static void generate() {
        test(4, 3, 5);
        test(100, 1, 1);
        testAllPermutations(1, 1, 1);
        testAllPermutations(1, 1, 2);
        testAllPermutations(1, 2, 2);
        testAllPermutations(2, 2, 2);
        testAllPermutations(1, 1, 100);
        testAllPermutations(1, 100, 100);
        testAllPermutations(100, 100, 100);
        testAllPermutations(42, 42, 42);
        testAllPermutations(2, 3, 3);
        testAllPermutations(2, 3, 4);
        testAllPermutations(2, 3, 5);
        testAllPermutations(2, 3, 6);
        testAllPermutations(2, 3, 7);
        
        final int yesNoBorderLineCount = 3;
        for (int i = 0; i < yesNoBorderLineCount; ++i) {
            int a, b, c;
            while (true) {
                a = 1 + random.nextInt(100);
                b = 1 + random.nextInt(100);
                int r = -1 + random.nextInt(4);
                c = a * b + r;
                if (1 <= c && c <= 100) {
                    break;
                }
            }
            testAllPermutations(a, b, c);
        }

        final int cornerBorderLineCount = 3;
        
        for (int i = 0; i < yesNoBorderLineCount; ++i) {
            int a, b, c;
            while (true) {
                a = 1 + random.nextInt(100);
                b = 1 + random.nextInt(100);
                int r = -1 + random.nextInt(4);
                c = a + b - 1 + r;
                if (1 <= c && c <= 100) {
                    break;
                }
            }
            testAllPermutations(a, b, c);
        }

        final int randomCount = 20;
        for (int i = 0; i < randomCount; ++i) {
            int type = random.nextInt(3);
            // type 0: s2 <= s0 + s1 - 1
            // type 1: s2 > s0 + s1 - 1, s2 <= s0 * s1
            // type 2: s2 > s0 * s1
            int a, b, c;
            while (true) {
                a = 1 + random.nextInt(100);
                b = 1 + random.nextInt(100);
                c = 1 + random.nextInt(100);
                int s2 = Math.max(Math.max(a, b), c);
                int s0 = Math.min(Math.min(a, b), c);
                int s1 = a + b + c - s0 - s2;
                if ((type == 0 && (s2 <= s0 + s1 - 1)) ||
                    (type == 1 && (s2 > s0 + s1 - 1 && s2 <= s0 * s1)) ||
                    (type == 2 && (s2 > s0 * s1))) 
                {
                    break;
                }
            }
            test(a, b, c);
        }
    }

    static void testAllPermutations(int a, int b, int c) {
        if (a == b && b == c) {
            test(a, b, c);
        } else if (a != b && b != c && a != c) {
            test(a, b, c);
            test(a, c, b);
            test(b, a, c);
            test(b, c, a);
            test(c, a, b);
            test(c, b, a);
        } else {
            if (a == c) {
                int t = a;
                a = b;
                b = t;
            }
            if (a == b) {
                int t = c;
                c = a;
                a = t;
            }
            // a != b, c; b == c
            test(a, b, c);
            test(b, a, c);
            test(b, c, a);
        }
    }

    static void test(int a, int b, int c) {
        try (PrintWriter out = new PrintWriter(String.format("%s/%03d", root.getName(), ++nTests))) {
            System.out.println("Writing test " + nTests);
            out.println(a + " " + b + " " + c);
        } catch (Exception e) {
            System.out.println("Can not write test " + nTests + ": " + e);
        }
    }
}

