/******************************************************************/
/* ACM ICPC 2017-2018                                             */
/* NEERC - Northern Eurasia Finals                                */
/* St Petersburg - Barnaul - Tbilisi - Almaty, December 3, 2017   */
/******************************************************************/
/* Problem E. Easy Quest                                          */
/*                                                                */
/* Original idea         Pavel Mavrin                             */
/* Problem statement     Pavel Mavrin                             */
/* Test set              Pavel Mavrin                             */
/******************************************************************/
/* Tests                                                          */
/*                                                                */
/* Author                Pavel Mavrin                             */
/******************************************************************/

import java.io.*;
import java.nio.file.*;
import java.util.*;

public class Tests {

    static final int MAX = 1000;

    static int nTests = 0;
    private static final Path root = Paths.get("tests");

    static Random random = new Random(43159345394151999L);

    static double[][] d = new double[2 * MAX + 1][2 * MAX + 1];

    static {
        d[0][0] = 1;
        for (int n = 1; n <= 2 * MAX; n++) {
            double s = 0;
            for (int b = 0; b <= n; b++) {
                if (b < n) d[n][b] += d[n - 1][b + 1];
                if (b > 0) d[n][b] += d[n - 1][b - 1];
                s += d[n][b];
            }
            for (int b = 0; b <= n; b++) {
                d[n][b] /= s;
            }
        }
    }

    public static void main(String[] args) throws IOException {
        Files.createDirectories(root);
        test(new int[]{1, 0, -4, 0, 0, -1, -3, 0, -1, -2});
        test(new int[]{5, 8, 0, -6, -3});
        test(new int[]{2, -2, -2});

        test(fillRandom(genRandom(10), 10, .5));
        test(fillRandom(genRandomImpossible(10), 10, .5));
        test(makeImpossible(fillRandom(genRandom(10), 10, .5)));

        test(fillRandom(genRandom(MAX, 10), MAX, 0));
        test(fillRandom(genRandom(MAX, 10), MAX, 0.01));
        test(fillRandom(genRandom(MAX, 10), MAX, .5));
        test(fillRandom(genRandom(MAX, 10), MAX, 0.99));
        test(fillRandom(genRandom(MAX, 10), MAX, 1));

        test(fillRandom(genRandom(MAX), MAX, .5));

        test(fillRandom(genDeep(MAX, MAX / 2), MAX, 0));
        test(fillRandom(genDeep(MAX, MAX / 2), MAX, .5));
        test(fillRandom(genDeep(MAX, MAX / 2), MAX, 1));
        test(fillRandom(genDeep(MAX, MAX / 2 - 50), MAX, .5));

        test(fillRandom(genRandomImpossible(MAX), MAX, .5));
        test(makeImpossible(fillRandom(genRandom(MAX), MAX, .5)));
        {
            int[] a = new int[MAX];
            test(a);
            Arrays.fill(a, 666);
            test(a);
            Arrays.fill(a, -666);
            test(a);
        }
        test(fillRandom(genRandom(MAX), 1, 1));

    }


    static int[] genRandomImpossible(int n) {
        int[] a = new int[n];
        int b = 0;
        if (n % 2 == 1) {
            a[n - 1] = 1;
            n--;
        }

        int n1 = random.nextInt(n / 2) *  2;
        int n2 = n - 2 - n1;

        int[] a1 = genRandom(n1);
        int[] a2 = genRandom(n2);

        System.arraycopy(a1, 0, a, 0, n1);
        a[n1] = -1;
        a[n1 + 1] = 1;
        System.arraycopy(a2, 0, a, n1 + 2, n2);

        return a;
    }    

    static int[] genRandom(int n) {
        return genRandom(n, 0);
    }

    static int[] genRandom(int n, int e) {
        int[] a = new int[n];
        int b = 0;
        if ((n + e) % 2 == 1) {
            e++;
        }
        for (int i = 0; i < n; i++) {
            double p = d[n + e - i - 1][b + 1];
            double q = b == 0 ? 0 : d[n + e - i - 1][b - 1];
            if (random.nextDouble() < p / (p + q)) {
                a[i] = 1;
            } else {
                a[i] = -1;
            }
            b += a[i];
        }
        return a;
    }

    static int[] genDeep(int n, int depth) {
        int[] c = new int[n];
        int[] a = new int[depth * 2];
        for (int i = 0; i < depth; i++) {
            a[i] = 1;
            a[depth + i] = -1;
        }
        int[] b = genRandom(n - depth * 2);
        int i = 0;
        int j = 0;
        while (i + j < n) {
            if (random.nextInt(a.length - i + b.length - j) < a.length - i) {
                c[i + j] = a[i++];
            } else {
                c[i + j] = b[j++];
            }
        }
        return c;
    }

    static int[] fillRandom(int[] a, int max, double p) {
        int n = a.length;
        int[] st = new int[n];
        int state = 1;
        int sp = 0;
        for (int i = 0; i < n; i++) {
            
            int x = a[i];
            if (x == 0) x = 1;

            if (x == state || sp == 0) {
                int y = random.nextInt(max) + 1;
                st[sp++] = y;
                a[i] = a[i] * y;
                state = x;
            } else {
                int t = random.nextInt(sp);
                int y = st[t];
                st[t] = st[--sp];
                a[i] = a[i] * y;
            }

            if (a[i] > 0 && random.nextDouble() < p) {
                a[i] = 0;
            }
        }
        return a;
    }

    static int[] makeImpossible(int[] a) {
        while (possible(a)) {
            int i, j;
            do {
                i = random.nextInt(a.length);
                j = random.nextInt(a.length);
            } while (a[i] * a[j] <= 0);
            int t = a[i];
            a[i] = a[j];
            a[j] = t;
        }
        return a;
    }


    static boolean possible(int[] a) {
        int[] cnt = new int[MAX + 1];
        for (int i = 0; i < a.length; i++) {
            if (a[i] >= 0) {
                cnt[a[i]]++;
            } else {
                if (cnt[-a[i]] > 0) {
                    cnt[-a[i]]--;
                } else {
                    if (cnt[0] > 0) {
                        cnt[0]--;
                    } else {
                        return false;
                    }
                }
            }
        }
        return true;
    }

    static void test(int[] a) throws FileNotFoundException {
        try (PrintWriter out = new PrintWriter(String.format("%s/%02d", root, ++nTests))) {
            System.out.println("Writing test " + nTests);
            out.println(a.length);
            for (int i = 0; i < a.length; i++) {
                if (i > 0) {
                    out.print(" ");
                }
                out.print(a[i]);
            }
            out.println();
        }
    }
}

