/******************************************************************/
/* ACM ICPC 2017-2018                                             */
/* NEERC - Northern Eurasia Finals                                */
/* St Petersburg - Barnaul - Tbilisi - Almaty, December 3, 2017   */
/******************************************************************/
/* Problem F. The Final Level                                     */
/*                                                                */
/* Original idea         Georgiy Korneev                          */
/* Problem statement     Pavel Kunyavsky                          */
/* Test set              Pavel Kunyavsky                          */
/******************************************************************/
/* Checker                                                        */
/*                                                                */
/* Author                Pavel Kunyavsky                          */
/******************************************************************/

#include "testlib.h"
#include <cassert>

using namespace std;

int test_id;
int a, b, n;

#define WA(f, ...) quitf(_wa, "Test #%d [%d, %d, %d]: " f, test_id, ::a, ::b, ::n, __VA_ARGS__)

int answer(int a, int b, int n) {
  a = abs(a);
  b = abs(b);
  return max(a / n, max(b / n, (a + b) / (2 * n - 1))) + 1;
}

struct rectangle {
  int x;
  int y1, y2;
  int id;

  rectangle() {}
  rectangle(int x, int _y1, int _y2, int id) : x(x), y1(_y1), y2(_y2), id(id) {
    if (y1 > y2) {
      swap(y1, y2);
    }
  }

  bool contains(int a, int b) const {
    assert(y1 <= y2);
    return a == x && y1 <= b && b <= y2;
  }
};

void intersects(int id1, int id2) {
  WA("corners %d and %d intersects", id1 + 1, id2 + 1);
}

const int MAXC = 100 * 1000 * 1000;

vector<vector<int>> g;
vector<bool> used;

void dfs(int v) {
  used[v] = true;
  for (int u : g[v]) {
    if (!used[u]) {
      dfs(u);
    }
  }
}

void add_edge(int a, int b) {
  assert(0 <= a && a < (int)g.size());
  assert(0 <= b && b < (int)g.size());
  g[a].push_back(b);
  g[b].push_back(a);
}

void build_graph_par(vector<rectangle> h) {
  sort(h.begin(), h.end(), [](const rectangle& a, const rectangle& b) {
        if (a.x != b.x) return a.x < b.x;
        return a.y1 < b.y1;
      });
  for (int i = 1; i < (int)h.size(); i++) {
    if (h[i].x == h[i - 1].x) {
      if (h[i].y1 <= h[i - 1].y2) {
        intersects(h[i].id, h[i - 1].id);
      }
      if (h[i].y1 == h[i - 1].y2 + 1) {
        add_edge(h[i].id, h[i - 1].id);
      }
    }
  }
}

struct event {
  int ty;
  int x;
  int y1, y2;
  int id;
};

void build_graph_perp(const vector<rectangle>& h, const vector<rectangle>& v) {
  vector<event> evs;
  for (const auto& r : h) {
    evs.push_back({0, r.y1, r.x, r.x, r.id});
    evs.push_back({2, r.y2, r.x, r.x, r.id});
  }
  for (const auto& r : v) {
    evs.push_back({1, r.x, r.y1, r.y2, r.id});
  }

  sort(evs.begin(), evs.end(), [](const event& a, const event& b) {
        if (a.x != b.x) return a.x < b.x;
        return a.ty < b.ty;
      });

  map<int, int> m;

  for (const auto& e : evs) {
    if (e.ty == 0) {
      assert(m.find(e.y1) == m.end());
      if (m.find(e.y1 - 1) != m.end()) {
        add_edge(e.id, m[e.y1 - 1]);
      }
      if (m.find(e.y1 + 1) != m.end()) {
        add_edge(e.id, m[e.y1 + 1]);
      }
      m[e.y1] = e.id;
    } else if (e.ty == 1) {
      auto it = m.lower_bound(e.y1);
      if (it != m.end() && it->first <= e.y2) {
        intersects(e.id, it->second);
      }
      if (m.find(e.y1 - 1) != m.end()) {
        add_edge(e.id, m[e.y1 - 1]);
      }
      if (m.find(e.y2 + 1) != m.end()) {
        add_edge(e.id, m[e.y2 + 1]);
      }
    } else {
      assert(e.ty == 2);
      assert(m.find(e.y1) != m.end());
      m.erase(e.y1);
    }
  }
}

void check_one() {
  int k = ouf.readInt();
  if (k > MAXC) {
    WA("too many corners %d", k);
  }
  vector<rectangle> h, v;
  int from = -1, to = -1;
  for (int i = 0; i < k; i++) {
    int x1, y1, x2, y2;
    x1 = ouf.readInt(-MAXC, MAXC);
    y1 = ouf.readInt(-MAXC, MAXC);
    x2 = ouf.readInt(-MAXC, MAXC);
    y2 = ouf.readInt(-MAXC, MAXC);
    if (abs(x1 - x2) != n - 1 || abs(y1 - y2) != n - 1) {
      WA("corner #%d is not a corner of size %d\n", i + 1, n);
    }
    v.push_back(rectangle(x1, y1, y2, i));
    h.push_back(rectangle(y2, x1 + ((x1 > x2) ? -1 : 1), x2, i));
    if (v.back().contains(0, 0) || h.back().contains(0, 0)) {
      if (from != -1) {
        intersects(i, from);
      } else {
        from = i;
      }
    }
    if (v.back().contains(a, b) || h.back().contains(b, a)) {
      if (to != -1) {
        intersects(i, to);
      } else {
        to = i;
      }
    }
  }

  if (from == -1) {
    WA("(%d, %d) is outside of labyrinth", 0, 0);
  }
  if (to == -1) {
    WA("(%d, %d) is outside of labyrinth", a, b);
  }

  g = vector<vector<int>> (k);
  build_graph_par(v);
  build_graph_par(h);
  build_graph_perp(v, h);
  build_graph_perp(h, v);

  used = vector<bool>(k);
  dfs(from);
  if (!used[to]) {
    WA("there is no path from corner %d to corner %d", from + 1, to + 1);
  }
  int ans = answer(a, b, n);
  if (k > ans) {
    WA("wrong number of corners found %d, expected %d", k, ans);
  }
  if (k < ans) {
    quitf(_fail, "wrong number of corners found %d, expected %d", k, ans);
  }
  if (find(used.begin(), used.end(), false) != used.end()) {
    quitf(_fail, "some corner is not used in path, while the answer size is as expected");
  }
}

int main(int argc, char **argv) {
  registerTestlibCmd(argc, argv);

  int k = inf.readInt();
  while (test_id++ < k) {
    a = inf.readInt();
    b = inf.readInt();
    n = inf.readInt();
    check_one();
  }
  quitf(_ok, "%d tests", k);
}

