/******************************************************************/
/* ACM ICPC 2017-2018                                             */
/* NEERC - Northern Eurasia Finals                                */
/* St Petersburg - Barnaul - Tbilisi - Almaty, December 3, 2017   */
/******************************************************************/
/* Problem F. The Final Level                                     */
/*                                                                */
/* Original idea         Georgiy Korneev                          */
/* Problem statement     Pavel Kunyavsky                          */
/* Test set              Pavel Kunyavsky                          */
/******************************************************************/
/* Tests                                                          */
/*                                                                */
/* Author                Pavel Kunyavsky                          */
/******************************************************************/


import java.io.IOException;
import java.io.PrintWriter;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.ArrayList;
import java.util.Random;

public class Tests {
    private static final Path root = Paths.get("tests");
    private static final Random rnd = new Random(239017);
    private static final int MAX_TEST_CASES = 100;
    private static final int MAX_ANSWER = 100_000;
    private static final int MAXC = 100_000_000;

    static class Test {
        int a, b, n;

        public Test(int a, int b, int n) {
            this.a = a;
            this.b = b;
            this.n = n;
        }

        int answer() {
            int aa = Math.abs(a);
            int bb = Math.abs(b);
            return Math.max(aa / n, Math.max(bb / n,  (aa + bb) / (2 * n - 1))) + 1;
        }
    }

    public static void main(String[] args) throws IOException {
        Files.createDirectories(root);
        tests = new ArrayList<>();
        test(2, 3, 2);
        test(4, -1, 3);
        flush();

        for (int i = -10; i <= 10; i++) {
            for (int j = -10; j <= 10; j++) {
                for (int n = 2; n <= 5; n++) {
                    if (i != 0 || j != 0) {
                        test(i, j, n);
                    }
                }
            }
        }

        flush();

        for (int t : new int[]{MAX_ANSWER / 10, 100, 50, 20, 10, 5, 4, 3, 2, 1}) {
            for (int i = 0; i <= 3 * t && i <= 300; i++) {
                int a = rnd.nextInt(2 * MAXC + 1) - MAXC;
                int b = rnd.nextInt(2 * MAXC + 1) - MAXC;
                int n = 0;
                while (true) {
                    n = rnd.nextInt(MAXC / (MAX_ANSWER / t) - 2) + 2;
                    int answer = new Test(a, b, n).answer();
                    if ((MAX_ANSWER / (t + 1) <= answer || t > 1000) && answer <= MAX_ANSWER / t) {
                        break;
                    }
                }
                test(a, b, n);
            }
        }
        test(MAXC - 1, 0, MAXC / MAX_ANSWER);
        test(0, MAXC - 1, MAXC / MAX_ANSWER);
        test(MAXC - MAX_ANSWER / 2, MAXC - MAX_ANSWER / 2 - 1, MAXC / MAX_ANSWER);
        test(MAXC - MAX_ANSWER / 2 - 1, MAXC - MAX_ANSWER / 2, MAXC / MAX_ANSWER);

        flush();
    }


    private static ArrayList<Test> tests;
    private static int tot_answer;
    private static int nTests;

    private static void flush() {
        if (tests.size() == 0) {
            return;
        }
        try (PrintWriter out = new PrintWriter(String.format("%s/%02d", root, ++nTests))) {
            System.out.println("Writing test " + nTests);
            out.println(tests.size());
            for (Test t : tests) {
                out.println(t.a + " " + t.b + " " + t.n);
            }
        } catch (IOException e) {
            throw new AssertionError(e);
        }
        tests.clear();
        tot_answer = 0;
    }

    private static void test(int a, int b, int n) {
        Test t = new Test(a, b, n);
        if (tests.size() == MAX_TEST_CASES || tot_answer + t.answer() > MAX_ANSWER) {
            flush();
        }
        tests.add(t);
        tot_answer += t.answer();
    }

}

