/******************************************************************/
/* ACM ICPC 2017-2018                                             */
/* NEERC - Northern Eurasia Finals                                */
/* St Petersburg - Barnaul - Tbilisi - Almaty, December 3, 2017   */
/******************************************************************/
/* Problem G. The Great Wall                                      */
/*                                                                */
/* Original idea         Vitaliy Aksenov                          */
/* Problem statement     Vitaliy Aksenov                          */
/* Test set              Vitaliy Aksenov                          */
/******************************************************************/
/* Tests                                                          */
/*                                                                */
/* Author                Vitaliy Aksenov                          */
/******************************************************************/

import java.io.PrintWriter;
import java.io.IOException;
import java.util.Random;
import java.util.Arrays;

/**
 * Created by vaksenov on 18.11.2017.
 */
public class Tests {
    public static void main(String[] args) {
        new Tests().gen();
    }

    Random rnd = new Random(239);
    int MAX_N = 30_000;//100_000;
    int MAX_X = 1_000_000;

    int tests = 1;

    public void writeTest(int n, int R, long K, int[][] a) {
        try (PrintWriter out = new PrintWriter(String.format("tests/%02d", tests++))) {
            out.println(n + " " + R + " " + K);

            for (int i = 0; i < a.length; i++) {
                for (int j = 0; j < a[i].length; j++) {
                    out.print((j == 0 ? "" : " ") + a[i][j]);
                }
                out.println();
            }
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public long rndLong(long x) {
        return (rnd.nextLong() % x + x) % x;
    }

    public long getTotal(int n, int R) {
        return 1L * (n - R + 1) * (n - R) / 2;
    }

    public void writeSamples() {
        writeTest(4, 2, 1, new int[][]{{1, 2, 3, 4}, {3, 3, 5, 5}, {7, 7, 7, 7}});
    }

    public int[][] genRandomWithOne(int n) {
        int[][] a = new int[3][n];

        for (int i = 0; i < n; i++) {
            int[] x = new int[3];
            x[0] = 1;
            for (int j = 1; j < x.length; j++) {
                x[j] = rnd.nextInt(MAX_X - j) + 1;
            }
            Arrays.sort(x);
            for (int j = 1; j < x.length; j++) {
                while (x[j] <= x[j - 1]) {
                    x[j]++;
                }
            }
            for (int j = 0; j < x.length; j++) {
                a[j][i] = x[j];
            }
        }

        return a;
    }

    public int[][] genRandom(int n) {
        int[][] a = new int[3][n];

        for (int i = 0; i < n; i++) {
            int[] x = new int[3];
            for (int j = 0; j < x.length; j++) {
                x[j] = rnd.nextInt(MAX_X - j) + 1;
            }
            Arrays.sort(x);
            for (int j = 1; j < x.length; j++) {
                while (x[j] <= x[j - 1]) {
                    x[j]++;
                }
            }
            for (int j = 0; j < x.length; j++) {
                a[j][i] = x[j];
            }
        }

        return a;
    }

    public int[][] genRandomNearMax(int n) {
        int[][] a = new int[3][n];

        for (int i = 0; i < n; i++) {
            int[] x = new int[3];
            for (int j = 0; j < 3; j++) {
                x[j] = rnd.nextInt(MAX_X - MAX_X / 10 - 2) + MAX_X / 10;
            }
            Arrays.sort(x);
            a[0][i] = x[0];
            for (int j = 1; j < 3; j++) {
                while (x[j] <= x[j - 1]) {
                    x[j]++;
                }
                a[j][i] = x[j];
            }
        }

        return a;
    }

    public int[][] genMax(int n) {
        int[][] a = new int[3][n];

        for (int i = 0; i < n; i++) {
            a[0][i] = MAX_X - 2;
            a[1][i] = MAX_X - 1;
            a[2][i] = MAX_X;
        }

        return a;
    }

    public int[][] genMin(int n) {
        int[][] a = new int[3][n];

        for (int i = 0; i < n; i++) {
            a[0][i] = 1;
            a[1][i] = 2;
            a[2][i] = 3;
        }

        return a;
    }

    public void gen() {
        writeSamples();

        writeTest(2, 1, 1, genRandom(2));
        int[][] a = genRandom(3);
        writeTest(3, 2, 1, a);
        writeTest(3, 1, 1, a);
        writeTest(3, 1, 2, a);

        long total = getTotal(MAX_N, 1);
        writeTest(MAX_N, 1, 1, genRandomWithOne(MAX_N));
        writeTest(MAX_N, 1, total, genRandomWithOne(MAX_N));
        writeTest(MAX_N, 1, rndLong(total) + 1, genRandomWithOne(MAX_N));

        total = getTotal(MAX_N, 2);
        writeTest(MAX_N, 2, 1, genRandomWithOne(MAX_N));
        writeTest(MAX_N, 2, total, genRandomWithOne(MAX_N));
        writeTest(MAX_N, 1, rndLong(total) + 1, genRandomWithOne(MAX_N));

        int R = MAX_N / 2;
        total = getTotal(MAX_N, R);
        writeTest(MAX_N, R, rndLong(total) + 1, genRandom(MAX_N));
        writeTest(MAX_N, R, rndLong(total) + 1, genRandomWithOne(MAX_N));
        writeTest(MAX_N, R, rndLong(total) + 1, genMax(MAX_N));
        writeTest(MAX_N, R, rndLong(total) + 1, genMin(MAX_N));
        writeTest(MAX_N, R, rndLong(total) + 1, genRandomNearMax(MAX_N));

        R = rnd.nextInt(MAX_N - 1) + 1;
        writeTest(MAX_N, R, getTotal(MAX_N, R), genRandom(MAX_N));
        R = rnd.nextInt(MAX_N - 1) + 1;
        writeTest(MAX_N, R, 1, genRandom(MAX_N));
        for (int i = 0; i < 4; i++) {
            R = rnd.nextInt(MAX_N - 1) + 1;
            writeTest(MAX_N, R, rndLong(getTotal(MAX_N, R)) + 1, genRandom(MAX_N));
        }

        for (int i = 0; i < 2; i++) {
            R = rnd.nextInt(MAX_N - 1) + 1;
            writeTest(MAX_N, R, rndLong(getTotal(MAX_N, R)) + 1, genMax(MAX_N));
        }

        for (int i = 0; i < 2; i++) {
            R = rnd.nextInt(MAX_N - 1) + 1;
            writeTest(MAX_N, R, rndLong(getTotal(MAX_N, R)) + 1, genMin(MAX_N));
        }

        for (int i = 0; i < 2; i++) {
            R = rnd.nextInt(MAX_N - 1) + 1;
            writeTest(MAX_N, R, rndLong(getTotal(MAX_N, R)) + 1, genRandomNearMax(MAX_N));
        }
    }
}

