/******************************************************************/
/* ACM ICPC 2017-2018                                             */
/* NEERC - Northern Eurasia Finals                                */
/* St Petersburg - Barnaul - Tbilisi - Almaty, December 3, 2017   */
/******************************************************************/
/* Problem G. The Great Wall                                      */
/*                                                                */
/* Original idea         Vitaliy Aksenov                          */
/* Problem statement     Vitaliy Aksenov                          */
/* Test set              Vitaliy Aksenov                          */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Niyaz Nigmatullin                        */
/******************************************************************/

import java.io.BufferedReader
import java.io.InputStreamReader

val start = System.currentTimeMillis()

private fun BufferedReader.nextInt(): Int {
    var c = read()
    while (c <= 32) c = read()
    var ans = 0
    while (c > 32) {
        ans = ans * 10 + c - '0'.toInt()
        c = read()
    }
    return ans
}

private fun BufferedReader.nextLong(): Long {
    var c = read()
    while (c <= 32) c = read()
    var ans = 0L
    while (c > 32) {
        ans = ans * 10 + c - '0'.toInt()
        c = read()
    }
    return ans
}


class SolutionOK {

    class Fenwick(val a: LongArray) {
        val f = IntArray(a.size)

        fun set(x: Int, y: Int) {
            var i = x
            while (i < a.size) {
                f[i] += y
                i = i or (i + 1)
            }
        }

        fun getCount(y: Long): Int {
            var left = -1
            var right = a.size
            while (left < right - 1) {
                val mid = (left + right) shr 1
                if (a[mid] >= y) {
                    right = mid
                } else {
                    left = mid
                }
            }
            var i = left
            var ans = 0
            while (i >= 0) {
                ans += f[i]
                i = (i and (i + 1)) - 1
            }
            return ans
        }

    }

    fun readAndSolve() {
        val br = BufferedReader(InputStreamReader(System.`in`))
        val n = br.nextInt()
        val len = br.nextInt()
        val k = br.nextLong()
        val a = IntArray(n) { br.nextInt() }
        val b = IntArray(n) { br.nextInt() }
        val c = IntArray(n) { br.nextInt() }
        println(solve(len, k, a, b, c))
        System.err.println(System.currentTimeMillis() - start)
    }

    fun calcSumLen(a: IntArray, len: Int): LongArray {
        val n = a.size
        val s = LongArray(n) { a[it].toLong() }
        for (i in n - 2 downTo 0) s[i] += s[i + 1]
        for (i in 0 until n - len) {
            s[i] -= s[i + len]
        }
        return s.copyOf(n - len + 1)
    }

    fun solve(len: Int, k: Long, a: IntArray, b: IntArray, c: IntArray): Long {
        val n = a.size - len + 1
        val sum = a.fold(0L, { x, y -> x + y })
        for (i in 0 until n + len - 1) b[i] -= a[i]
        for (i in 0 until n + len - 1) c[i] -= a[i]
        val cb = IntArray(n + len - 1) { c[it] - b[it] }
        val sb = calcSumLen(b, len)
        val cover = calcSumLen(cb, len)
        val delta = LongArray(n) { (2 * b[it] - c[it]).toLong() }
        for (i in 1 until n) delta[i] += delta[i - 1]
        for (i in 1 until n) cover[i] -= delta[i - 1]
        val where = getWhere(cover)
        val whereB = getWhere(sb)
        var left = -1L
        var right = 1L shl 40
        val coverSorted = cover.clone()
        coverSorted.sort()
        val sbSorted = sb.clone()
        sbSorted.sort()
        val tree = Fenwick(coverSorted)
        val treePrev = Fenwick(sbSorted)
        System.err.println(System.currentTimeMillis() - start)
        while (left < right - 1) {
            val mid = (left + right) shr 1
            var count = 0L
            for (i in 0 until n) {
                val current = sb[i] + when(i) {
                    0 -> 0
                    else -> delta[i - 1]
                }
                count += tree.getCount(mid - current)
                count += treePrev.getCount(mid - sb[i])
                tree.set(where[i], 1)
                if (i >= len) {
                    tree.set(where[i - len], -1)
                    treePrev.set(whereB[i - len], 1)
                }
            }
            for (i in 0 until n - len) {
                treePrev.set(whereB[i], -1)
            }
            for (i in Math.max(n - len, 0) until n) {
                tree.set(where[i], -1)
            }
            if (count >= k) {
                right = mid
            } else {
                left = mid
            }
        }
        return left + sum
    }

    private fun getWhere(a: LongArray): IntArray {
        val n = a.size
        val order = Array(n) { it }
        order.sortBy { a[it] }
        val where = IntArray(n)
        for (i in 0 until n) where[order[i]] = i
        return where
    }
}

fun main(args: Array<String>) = SolutionOK().readAndSolve()

