/******************************************************************/
/* ACM ICPC 2017-2018                                             */
/* NEERC - Northern Eurasia Finals                                */
/* St Petersburg - Barnaul - Tbilisi - Almaty, December 3, 2017   */
/******************************************************************/
/* Problem G. The Great Wall                                      */
/*                                                                */
/* Original idea         Vitaliy Aksenov                          */
/* Problem statement     Vitaliy Aksenov                          */
/* Test set              Vitaliy Aksenov                          */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Niyaz Nigmatullin                        */
/******************************************************************/

import java.io.*;
import java.util.Arrays;
import java.util.Comparator;
import java.util.Random;
import java.util.StringTokenizer;

/**
 * Created by vaksenov on 11.11.2017.
 */
public class great_nn_java {
    public static void main(String[] args) {
        new great_nn_java().run();
    }

    BufferedReader br;
    StringTokenizer st;
    PrintWriter out;

    public String nextToken() throws IOException {
        while (st == null || !st.hasMoreTokens()) {
            st = new StringTokenizer(br.readLine());
        }
        return st.nextToken();
    }

    public int nextInt() throws IOException {
        return Integer.parseInt(nextToken());
    }


    static long[] calcSumLen(int[] a, int len) {
        int n = a.length;
        long[] s = new long[n];
        long cur = 0;
        for (int i = n - 1; i >= 0; i--) {
            cur += a[i];
            if (i + len < n) cur -= a[i + len];
            s[i] = cur;
        }
        return Arrays.copyOf(s, n - len + 1);
    }


    class Fenwick {

        long[] a;
        int[] f;

        Fenwick(long[] a) {
            this.a = a;
            f = new int[a.length];
        }

        void set(int x, int y) {
            for (int i = x; i < a.length; i |= i + 1) {
                f[i] += y;
            }
        }

        int getCount(long y) {
            int left = -1;
            int right = a.length;
            while (left < right - 1) {
                int mid = (left + right) >>> 1;
                if (a[mid] >= y) {
                    right = mid;
                } else {
                    left = mid;
                }
            }
            int ans = 0;
            for (int i = left; i >= 0; i = (i & i + 1) - 1) {
                ans += f[i];
            }
            return ans;
        }

    }


    public void solve() throws IOException {
        int n = nextInt();
        int L = nextInt();
        int k = nextInt();
        n = n - L + 1;
        int[] a = new int[n + L - 1];
        long sum = 0;
        for (int i = 0; i < n + L - 1; i++) {
            a[i] = nextInt();
            sum += a[i];
        }
        int[] b = new int[n + L - 1];
        for (int i = 0; i < n + L - 1; i++) {
            b[i] = nextInt() - a[i];
        }
        int[] c = new int[n + L - 1];
        long MAX = 0;
        for (int i = 0; i < n + L - 1; i++) {
            c[i] = nextInt() - a[i];
            MAX += c[i];
        }
        int[] cb = new int[n + L - 1];
        for (int i = 0; i < n + L - 1; i++) {
            cb[i] = c[i] - b[i];
        }
        long[] sb = calcSumLen(b, L);
        long[] cover = calcSumLen(cb, L);
        long[] delta = new long[n];
        for (int i = 0; i < n; i++) delta[i] = 2 * b[i] - c[i];
        for (int i = 1; i < n; i++) {
            delta[i] += delta[i - 1];
            cover[i] -= delta[i - 1];
        }
        long left = -1;
        long right = MAX + 1;
        long[] coverSorted = sortAndUnique(cover);
        long[] sbSorted = sortAndUnique(sb);
        int[] where = new int[n];
        int[] whereB = new int[n];
        for (int i = 0; i < n; i++) {
            where[i] = Arrays.binarySearch(coverSorted, cover[i]);
            whereB[i] = Arrays.binarySearch(sbSorted, sb[i]);
        }
        while (left < right - 1) {
            long mid = (left + right) >>> 1;
            long count = 0;
            Fenwick tree = new Fenwick(coverSorted);
            Fenwick treePrev = new Fenwick(sbSorted);
            for (int i = 0; i < n; i++) {
                long current = sb[i] + (i == 0 ? 0 : delta[i - 1]);
                count += tree.getCount(mid - current);
                count += treePrev.getCount(mid - sb[i]);
                tree.set(where[i], 1);
                if (i >= L) {
                    tree.set(where[i - L], -1);
                    treePrev.set(whereB[i - L], 1);
                }
                if (count >= k) break;
            }
//            for (int i = 0; i < n - L; i++) treePrev.set(whereB[i], -1);
//            for (int i = Math.max(0, n - L); i < n; i++) tree.set(where[i], -1);
            if (count >= k) {
                right = mid;
            } else {
                left = mid;
            }
        }
        out.println(left + sum);
    }

    static long[] sortAndUnique(long[] a) {
        a = a.clone();
        Arrays.sort(a);
        int j = 1;
        int n = a.length;
        for (int i = 1; i < n; i++) {
            if (a[i] != a[j - 1]) {
                a[j++] = a[i];
            }
        }
        return Arrays.copyOf(a, j);
    }

    public void run() {
        try {
            br = new BufferedReader(new InputStreamReader(System.in));
            out = new PrintWriter(new OutputStreamWriter(System.out));

            long time = System.currentTimeMillis();

            solve();

            System.err.println(System.currentTimeMillis() - time);

            out.close();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }
}

