/******************************************************************/
/* ACM ICPC 2017-2018                                             */
/* NEERC - Northern Eurasia Finals                                */
/* St Petersburg - Barnaul - Tbilisi - Almaty, December 3, 2017   */
/******************************************************************/
/* Problem G. The Great Wall                                      */
/*                                                                */
/* Original idea         Vitaliy Aksenov                          */
/* Problem statement     Vitaliy Aksenov                          */
/* Test set              Vitaliy Aksenov                          */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Vitaliy Aksenov                          */
/******************************************************************/

import java.io.*;
import java.util.Random;
import java.util.StringTokenizer;

/**
 * Created by vaksenov on 11.11.2017.
 */
public class great_va_sf2 {
    public static void main(String[] args) {
        new great_va_sf2().run();
    }

    BufferedReader br;
    StringTokenizer st;
    PrintWriter out;

    public String nextToken() throws IOException {
        while (st == null || !st.hasMoreTokens()) {
            st = new StringTokenizer(br.readLine());
        }
        return st.nextToken();
    }

    public int nextInt() throws IOException {
        return Integer.parseInt(nextToken());
    }

    Random rnd = new Random(239);

    public class Node {
        long x;
        int y;
        int sum;
        Node l, r;
        long add;

        public Node(long x) {
            this.x = x;
            this.y = rnd.nextInt();
            sum = 1;
        }

        public void push() {
            x += add;
            if (l != null) {
                l.add += add;
            }
            if (r != null) {
                r.add += add;
            }
            add = 0;
        }

        public void update() {
            sum = getSum(l) + getSum(r) + 1;
        }

        public String toString() {
            return (l == null ? "" : l.toString()) +
                    "{" + x + "," + sum + "," + add + "} " +
                    (r == null ? "" : r.toString());
        }
    }

    public int getSum(Node node) {
        return node == null ? 0 : node.sum;
    }

    public Node[] splitByValue(Node node, long x) {
        if (node == null) {
            return new Node[] {null, null};
        }
        node.push();
        if (node.x < x) {
            Node[] n = splitByValue(node.r, x);
            node.r = n[0];
            node.update();
            n[0] = node;
            return n;
        } else {
            Node[] n = splitByValue(node.l, x);
            node.l = n[1];
            node.update();
            n[1] = node;
            return n;
        }
    }

    public Node[] split(Node node, int s) {
        if (node == null) {
            return new Node[]{null, null};
        }
        node.push();
        if (getSum(node.l) + 1 <= s) {
            Node[] x = split(node.r, s - getSum(node.l) - 1);
            node.r = x[0];
            node.update();
            x[0] = node;
            return x;
        } else {
            Node[] x = split(node.l, s);
            node.l = x[1];
            node.update();
            x[1] = node;
            return x;
        }
    }

    public Node merge(Node l, Node r) {
        if (l == null) {
            return r;
        }
        if (r == null) {
            return l;
        }
        l.push();
        r.push();
        if (l.y < r.y) {
            l.r = merge(l.r, r);
            l.update();
            return l;
        } else {
            r.l = merge(l, r.l);
            r.update();
            return r;
        }
    }

    public void add(Node node, long add) {
        if (node != null) {
            node.add += add;
        }
    }

    public int getPos(Node node, long x) {
        if (node == null) {
            return 0;
        }
        node.push();
        if (node.x < x) {
            return getSum(node.l) + 1 + getPos(node.r, x);
        } else {
            return getPos(node.l, x);
        }
    }

    public Node insert(Node node, long x) {
        Node[] split = splitByValue(node, x);
        Node n = new Node(x);
        return merge(split[0], merge(n, split[1]));
    }

    public Node remove(Node node, long x) {
        Node[] s1 = splitByValue(node, x);
        Node[] s2 = split(s1[1], 1);
        return merge(s1[0], s2[1]);
    }

    public void solve() throws IOException {
        int n = nextInt();
        int L = nextInt();
        int k = nextInt();

        long sum = 0;
        int[] a = new int[n];
        for (int i = 0; i < n; i++) {
            a[i] = nextInt();
            sum += a[i];
        }

        int[] b = new int[n];
        for (int i = 0; i < b.length; i++) {
            b[i] = nextInt() - a[i];
        }

        long MAX = 0;
        int[] c = new int[n];
        for (int i = 0; i < c.length; i++) {
            c[i] = nextInt() - a[i];
            MAX += c[i];
        }

        long[] pb = new long[b.length + 1];
        for (int i = 1; i < pb.length; i++) {
            pb[i] = pb[i - 1] + b[i - 1];
        }

        long[] pc = new long[c.length + 1];
        for (int i = 1; i < pc.length; i++) {
            pc[i] = pc[i - 1] + c[i - 1];
        }

        long l = -1;
        long r = MAX + 1;
        while (l < r - 1) {
            long m = (l + r) / 2;

            Node nonIntersect = null;
            Node intersect = null;
            long totalLess = 0;
            for (int i = L - 1; i < c.length; i++) {
                if (i >= L) {
                    add(intersect, b[i] + (b[i - L] - c[i - L]));
//                    System.err.println("After add: " + intersect);
                }
                if (i >= 2 * L - 1) {
                    long lp = pb[i - L + 1] - pb[i - 2 * L + 1];
                    long rp = pb[i + 1] - pb[i - L + 1];
                    intersect = remove(intersect, lp + rp);
                    nonIntersect = insert(nonIntersect, lp);
                }

                totalLess += getPos(intersect, m);
                totalLess += getPos(nonIntersect, m - (pb[i + 1] - pb[i - L + 1]));

                intersect = insert(intersect, (pc[i + 1] - pc[i - L + 1]));
//                System.err.println("Intersect " + intersect);
//                System.err.println("nonIntersect " + nonIntersect);
            }

//            System.err.println(m + " " + totalLess);

            if (totalLess >= k) {
                r = m;
            } else {
                l = m;
            }
        }
        out.println(sum + r - 1);
    }

    public void run() {
        try {
            br = new BufferedReader(new InputStreamReader(System.in));
            out = new PrintWriter(new OutputStreamWriter(System.out));

            long time = System.currentTimeMillis();

            solve();

            System.err.println(System.currentTimeMillis() - time);

            out.close();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }
}

