/******************************************************************/
/* ACM ICPC 2017-2018                                             */
/* NEERC - Northern Eurasia Finals                                */
/* St Petersburg - Barnaul - Tbilisi - Almaty, December 3, 2017   */
/******************************************************************/
/* Problem H. Hack                                                */
/*                                                                */
/* Original idea         Petr Mitrichev                           */
/* Problem statement     Petr Mitrichev                           */
/* Test set              Petr Mitrichev                           */
/******************************************************************/
/* Interactor                                                     */
/*                                                                */
/* Author                Petr Mitrichev                           */
/******************************************************************/

import java.io.File;
import java.io.IOException;
import java.io.PrintWriter;
import java.math.BigInteger;
import java.util.Arrays;
import java.util.Scanner;
import java.util.stream.IntStream;
import java.util.stream.Stream;

public class Interact {
    private static final int OK_EXIT_CODE = 0;
    private static final int EARLY_EXIT_CODE = 10;

    static final int MAX_QUERIES = 30000;
    static final int MAX_BITS = 60;
    static final int PQ_BITS = 30;
    static final int NUM_TESTS = 30;
    static final long KEY1 = 4379748372483771371L;
    static final long KEY2 = 7743715836415763176L;
    static final long KEY3 = 2372462236437624732L;
    static final int MAX_SANE_NUMBER_LENGTH = 1000;

    private static int run(String inFilename, String outFilename) throws IOException {
        try (Scanner in = new Scanner(new File(inFilename));
             PrintWriter out = new PrintWriter(outFilename)) {
            final BigInteger n = new BigInteger(in.next()).xor(BigInteger.valueOf(KEY1));
            final BigInteger d = new BigInteger(in.next()).xor(BigInteger.valueOf(KEY2));
            int queries = 0;
            try (Scanner pipeIn = new Scanner(System.in);
                     PrintWriter pipeOut = new PrintWriter(System.out);
                     PrintWriter log = new PrintWriter(new File("Interact.log"))) {
                send(pipeOut, log, n.toString());
                while (true) {
                    String queryType;
                    try {
                        queryType = pipeIn.next();
                    } catch (Exception e) {
                        return writeResult(out, log, "PE", "After query " + queries + ": " + e.getMessage(), EARLY_EXIT_CODE);
                    }
                    log.println("<<< " + queryType);
                    log.flush();
                    if (queryType.equals("?")) {
                        ++queries;
                        if (queries > MAX_QUERIES) {
                            return writeResult(out, log, "WA", "Too many queries", EARLY_EXIT_CODE);
                        }
                        BigInteger a;
                        try {
                            a = readNumber(pipeIn, log);
                        } catch (Exception e) {
                            return writeResult(out, log, "PE", "Query " + queries + ": " + e.getMessage(), EARLY_EXIT_CODE);
                        }
                        if (a.compareTo(BigInteger.ZERO) < 0 || a.compareTo(n) >= 0) {
                            return writeResult(out, log, "WA", "Out of range: a=" + a + ", n=" + n, EARLY_EXIT_CODE);
                        }
                        int time = timeModPow(a, d, n);
                        send(pipeOut, log, "" + time);
                    } else if (queryType.equals("!")) {
                        BigInteger guess;
                        try {
                            guess = readNumber(pipeIn, log);
                        } catch (Exception e) {
                            return writeResult(out, log, "PE", "Query " + queries + ": " + e.getMessage(), EARLY_EXIT_CODE);
                        }
                        if (d.equals(guess)) {
                            return writeResult(out, log, "OK", queries + " queries", OK_EXIT_CODE);
                        } else {
                            return writeResult(out, log, "WA", "Incorrect guess: expected " + d + ", found " + guess, EARLY_EXIT_CODE);
                        }
                    } else {
                        return writeResult(out, log, "PE", "After query " + queries + ": expected ? or !, got something else", EARLY_EXIT_CODE);
                    }
                }
            }
        }
    }

    private static int timeMultiplication(BigInteger a, BigInteger b) {
        return (1 + a.bitLength()) * (1 + b.bitLength());
    }

    private static int timeModPow(BigInteger a, BigInteger d, BigInteger n) {
        BigInteger res = BigInteger.ONE;
        int time = 0;
        for (int i = 0; i < MAX_BITS; ++i) {
            if (d.testBit(i)) {
                time += timeMultiplication(res, a);
                res = res.multiply(a).mod(n);
            }
            time += timeMultiplication(a, a);
            a = a.multiply(a).mod(n);
        }
        return time;
    }

    private static BigInteger readNumber(Scanner pipeIn, PrintWriter log) throws Exception {
        String str = pipeIn.next();
        log.println("<<< " + str);
        // BigInteger parsing can be very slow, so we handle very long strings separately.
        if (str.length() > MAX_SANE_NUMBER_LENGTH) {
            throw new Exception("Too long number: " + str.length() + " characters");
        }
        return new BigInteger(str);
    }

    private static void send(final PrintWriter pipeOut, final PrintWriter log, final String string) {
        pipeOut.println(string);
        pipeOut.flush();
        log.println(">>> " + string);
        log.flush();
    }

    private static int writeResult(final PrintWriter out, final PrintWriter log, final String outcome, final String comment, int exitCode) {
        log.println(outcome + " " + comment);
        out.println(KEY3);
        out.println(outcome);
        out.println(comment);
        return exitCode;
    }

    public static void main(String[] args) throws IOException {
        System.exit(run(
            args.length >= 1 ? args[0] : "hack.in",
            args.length >= 2 ? args[1] : "hack.out"
        ));
    }
}

