/******************************************************************/
/* ACM ICPC 2017-2018                                             */
/* NEERC - Northern Eurasia Finals                                */
/* St Petersburg - Barnaul - Tbilisi - Almaty, December 3, 2017   */
/******************************************************************/
/* Problem H. Hack                                                */
/*                                                                */
/* Original idea         Petr Mitrichev                           */
/* Problem statement     Petr Mitrichev                           */
/* Test set              Petr Mitrichev                           */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Petr Mitrichev                           */
/******************************************************************/

import java.math.BigInteger;
import java.util.Arrays;
import java.util.Random;
import java.util.Scanner;

public class hack_petr {
    static final int MAX_BITS = 60;
    static final int MAX_QUERIES = 30000;
    static Random random = new Random(5437153151511L);

    public static void main(String[] args) {
        long start = System.currentTimeMillis();
        Scanner scanner = new Scanner(System.in);
        BigInteger n = new BigInteger(scanner.next());
        BigInteger[] a = new BigInteger[MAX_QUERIES];
        int[] time = new int[MAX_QUERIES];
        for (int i = 0; i < MAX_QUERIES; ++i) {
            a[i] = randomUpTo(n);
            System.out.println("? " + a[i]);
            System.out.flush();
            time[i] = scanner.nextInt();
        }
        System.err.println("Interaction time: " + (System.currentTimeMillis() - start));
        start = System.currentTimeMillis();
        BigInteger d = solve(a, n, time, MAX_BITS);
        System.err.println("Solution time: " + (System.currentTimeMillis() - start));
        System.out.println("! " + d);
        System.out.flush();
    }

    private static BigInteger randomUpTo(BigInteger n) {
        BigInteger a;
        do {
            a = new BigInteger(n.bitLength(), random);
        } while (a.compareTo(n) >= 0);
        return a;
    }

    private static int timeMultiplication(BigInteger a, BigInteger b) {
        return (1 + a.bitLength()) * (1 + b.bitLength());
    }

    private static BigInteger solve(BigInteger[] a, BigInteger n, int[] time, int maxBits) {
        for (int i = 0; i < a.length; ++i) {
            BigInteger pa = a[i];
            for (int pos = 0; pos < maxBits; ++pos) {
                time[i] -= timeMultiplication(pa, pa);
                pa = pa.multiply(pa).mod(n);
            }
        }
        BigInteger d = BigInteger.ZERO;
        BigInteger[] prod = new BigInteger[a.length];
        Arrays.fill(prod, BigInteger.ONE);
        for (int pos = 0; pos <= maxBits; ++pos) {
            BigInteger[] na = new BigInteger[a.length];
            int[] curTime = new int[time.length];
            int[] curTime2 = new int[time.length];
            boolean allZero = true;
            for (int x : time) if (x != 0) allZero = false;
            if (allZero) return d;
            for (int i = 0; i < a.length; ++i) {
                na[i] = a[i].multiply(a[i]).mod(n);
                curTime[i] = timeMultiplication(prod[i], a[i]);
                // Here we need any random number as second argument, but let's use na[i] since we've computed it anyway.
                curTime2[i] = timeMultiplication(prod[i], na[i]);
            }
            double x = covariation(time, curTime);
            double y = covariation(curTime, curTime);
            double z = covariation(curTime, curTime2);
            if (pos == 0 || Math.abs(x - y) < Math.abs(x - z)) {
                for (int i = 0; i < a.length; ++i) {
                    time[i] -= timeMultiplication(prod[i], a[i]);
                    prod[i] = prod[i].multiply(a[i]).mod(n);
                    if (time[i] < 0) {
                        throw new RuntimeException();
                    }
                }
                d = d.or(BigInteger.ONE.shiftLeft(pos));
            }
            for (int i = 0; i < a.length; ++i) {
                a[i] = na[i];
            }
        }
        throw new RuntimeException();
    }

    private static double covariation(int[] t1, int[] t2) {
        double ma = 0;
        double mb = 0;
        for (int i = 0; i < t1.length; ++i) {
            ma += t1[i];
            mb += t2[i];
        }
        ma /= t1.length;
        mb /= t1.length;
        double res = 0;
        for (int i = 0; i < t1.length; ++i) {
            res += (t1[i] - ma) * (t2[i] - mb);
        }
        res /= t1.length;
        return res;
    }

}

