/******************************************************************/
/* ACM ICPC 2017-2018                                             */
/* NEERC - Northern Eurasia Finals                                */
/* St Petersburg - Barnaul - Tbilisi - Almaty, December 3, 2017   */
/******************************************************************/
/* Problem H. Hack                                                */
/*                                                                */
/* Original idea         Petr Mitrichev                           */
/* Problem statement     Petr Mitrichev                           */
/* Test set              Petr Mitrichev                           */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Pavel Kunyavsky                          */
/******************************************************************/

#include <cstdio>
#include <cstdlib>
#include <vector>
#include <random>
#include <cmath>
#include <cassert>

using namespace std;

#define eprintf(...) fprintf(stderr,__VA_ARGS__)

#define TIMESTAMP(x) eprintf("["#x"] Time : %.3lf s.\n", clock()*1.0/CLOCKS_PER_SEC)
#define TIMESTAMPf(x,...) eprintf("[" x "] Time : %.3lf s.\n", __VA_ARGS__, clock()*1.0/CLOCKS_PER_SEC)



typedef long long ll;
typedef long double ld;

int bits(ll x) {
  if (!x) return 0;
  return 64 - __builtin_clzll(x);
}

ll n;

void add(ll &a, ll b) {
  if ((a += b) >= n) a -= n;
}

ll multiply(ll a, ll b) {
  ll res = 0;
  for (int i = 0; i < 60; i++) {
    if (b & (1LL << i)) {
      add(res, a);
    }
    add(a, a);
  }
  return res;
}

int multiply_time(ll a, ll b) {
  return (1 + bits(a)) * (1 + bits(b));
}

const int Q = 30000;


int pow_time(ll a, ll b) {
  int res_t = 0;
  ll res = 1;
  for (int i = 0; i < 60; i++) {
    if (b & (1LL << i)) {
      res_t += multiply_time(res, a);
      res = multiply(res, a);
    }
    res_t += multiply_time(a, a);
    a = multiply(a, a);
  }
  return res_t;
}

int pow_time2(ll a, ll b, int from) {
  int res_t = 0;
  ll res = 1;
  for (int i = 0; i < 60; i++) {
    if (b & (1LL << i)) {
      if (i >= from) {
        res_t += multiply_time(res, a);
      }
      res = multiply(res, a);
    }
    a = multiply(a, a);
  }
  return res_t;
}


struct state {
  ll a, res, a0;
  int tm;
};

ll rnd(ll n) {
  static std::mt19937_64 dev;
  ll x = dev() % n;
  while (x <= 0) {
    x = dev() % n;
  }
  return x;
}

ld avg(const vector<int> &a) {
  int n = (int)a.size();
  ld res = 0;
  for (int i = 0; i < n; i++) {
    res += ld(a[i])/ n;
  }
  return res;
}

ld cov(const vector<int> &a, const vector<int> &b) {
  int n = (int)a.size();
  ld avg_a = avg(a);
  ld avg_b = avg(b);


  ld res = 0;
  for (int i = 0; i < n; i++) {
    res += (a[i] - avg_a) * (b[i] - avg_b) / n;
  }
  return res;
}

int main() {
  assert(scanf("%lld", &n) == 1);

  vector<state> v(Q);

  assert(bits(1) == 1);
  assert(bits(2) == 2);
  assert(bits(3) == 2);
  assert(bits(4) == 3);

  for (int i = 0; i < Q; i++) {
    ll x = rnd(n);
    v[i].a0 = v[i].a = x;
    printf("? %lld\n", x);
    fflush(stdout);
    assert(scanf("%d", &v[i].tm) == 1);

    for (int it = 0; it < 60; it++) {
      v[i].tm -= multiply_time(x, x);
      x = multiply(x, x);
    }
    v[i].res = v[i].a;
    v[i].tm -= multiply_time(1, v[i].a);
  }

  TIMESTAMP("interact"); 

  ll d = 1;

  for (int it = 1; it < 60; it++) {
    for (state &s : v) {
      s.a = multiply(s.a, s.a);
    }
    vector<int> time_mul(Q);
    vector<int> time_real(Q);
    vector<int> time_rand(Q);
    for (int i = 0; i < Q; i++) {
      time_mul[i] = multiply_time(v[i].a, v[i].res);
      time_real[i] = v[i].tm;
      time_rand[i] = multiply_time(rnd(n), v[i].res);
    }

    // d == 1. cov(real, mul) = cov(mul + trash, mul) = cov(mul, mul) + cov(trash, mul) = cov(mul, mul)
    // d == 0. cov(real, mul) = cov(rand + trash, mul) = cov(rand, mul) + cov(trash, mul) = cov(rand, mul)

    ld cov_real_mul = cov(time_real, time_mul);
    ld cov_mul_mul = cov(time_mul, time_mul);
    ld cov_rand_mul = cov(time_rand, time_mul);

    /*
    eprintf("%Lf %Lf %Lf\n", cov_real_mul, cov_mul_mul, cov_rand_mul);
    if (cov_real_mul < 0) {
      for (int i = 0; i < 10; i++) {
        eprintf("%d %d\n", time_mul[i], time_real[i]);
      }
    }
    */

    ld eps = 1e-9;
    
    ld d_1_score = abs(log(max(eps, cov_real_mul / cov_mul_mul)));
    ld d_0_score = abs(log(max(eps, cov_real_mul / cov_rand_mul)));

    //eprintf("%Lf %Lf %Lf\n", d_1_score, d_0_score, min(d_0_score, d_1_score));

    if (d_1_score < d_0_score) {
      d |= (1LL << it);  
      for (state &s : v) {
        s.tm -= multiply_time(s.a, s.res);
        s.res = multiply(s.a, s.res);
      }
    }
    if (v[0].tm == 0) break;
  }

  for (int i = 0; i < Q; i++) {
    assert(v[i].tm == 0);
  }

  printf("! %lld\n", d);
  fflush(stdout);
  TIMESTAMP("solve");
  return 0;
}


