/******************************************************************/
/* ACM ICPC 2017-2018                                             */
/* NEERC - Northern Eurasia Finals                                */
/* St Petersburg - Barnaul - Tbilisi - Almaty, December 3, 2017   */
/******************************************************************/
/* Problem I. Interactive Sort                                    */
/*                                                                */
/* Original idea         Borys Minaiev                            */
/* Problem statement     Borys Minaiev                            */
/* Test set              Borys Minaiev                            */
/******************************************************************/
/* Interactor                                                     */
/*                                                                */
/* Author                Borys Minaiev                            */
/******************************************************************/

import java.io.File;
import java.io.IOException;
import java.io.PrintWriter;
import java.math.BigInteger;
import java.util.*;
import java.util.stream.Collectors;
import java.util.stream.IntStream;
import java.util.stream.Stream;

public class Interact {
    private static final int OK_EXIT_CODE = 0;
    private static final int EARLY_EXIT_CODE = 10;

    static final int MAX_QUERIES = 300000;
    static final long KEY = 23452622362364623L;
    static final int KEY2 = 23452351;

    static final boolean DO_NOT_LOG = true; // logging took a lot of time

    private static int run(String inFilename, String outFilename) throws IOException {
        try (Scanner in = new Scanner(new File(inFilename));
             PrintWriter out = new PrintWriter(outFilename)) {
            int n = in.nextInt();
            if (n < 1 || n > 10000) throw new IllegalArgumentException("Invalid n = " + n);
            int seed = in.nextInt() ^ KEY2;
            List<Integer> list = IntStream.range(1, n + 1).boxed().collect(Collectors.toList());
            Collections.shuffle(list, new Random(seed));
            List<Integer> even = list.stream().filter(i -> (i % 2 == 0)).collect(Collectors.toList());
            List<Integer> odd = list.stream().filter(i -> (i % 2 == 1)).collect(Collectors.toList());
            int queries = 0;
            try (Scanner pipeIn = new Scanner(System.in);
                 PrintWriter pipeOut = new PrintWriter(System.out);
                 PrintWriter log = new PrintWriter(new File("Interact.log"))) {
                send(pipeOut, log, Integer.toString(n));
                while (true) {
                    String queryType;
                    try {
                        queryType = pipeIn.next();
                    } catch (Exception e) {
                        return writeResult(out, log, "PE", "After query " + queries + ": " + e.getMessage(), EARLY_EXIT_CODE);
                    }
                    if (!DO_NOT_LOG) {
                        log.println("<<< " + queryType);
                    }
                    if (queryType.equals("?")) {
                        ++queries;
                        if (queries > MAX_QUERIES) {
                            return writeResult(out, log, "WA", "Too many queries", EARLY_EXIT_CODE);
                        }
                        int evenIndex, oddIndex;
                        try {
                            evenIndex = readNumber(pipeIn, log, 1, even.size());
                        } catch (Exception e) {
                            return writeResult(out, log, "PE", "Query " + queries + ": " + e.getMessage(), EARLY_EXIT_CODE);
                        }
                        try {
                            oddIndex = readNumber(pipeIn, log, 1, odd.size());
                        } catch (Exception e) {
                            return writeResult(out, log, "PE", "Query " + queries + ": " + e.getMessage(), EARLY_EXIT_CODE);
                        }
                        String result = even.get(evenIndex - 1) > odd.get(oddIndex - 1) ? ">" : "<";
                        send(pipeOut, log, result);
                    } else if (queryType.equals("!")) {
                        int[] vals = new int[n];
                        for (int i = 0; i < n; i++) {
                            try {
                                vals[i] = readNumber(pipeIn, log, 1, n);
                            } catch (Exception e) {
                                return writeResult(out, log, "PE", "Query " + queries + ": " + e.getMessage(), EARLY_EXIT_CODE);
                            }
                        }
                        even.addAll(odd);
                        for (int i = 0; i < n; i++) {
                            if (vals[i] != even.get(i)) {
                                return writeResult(out, log, "WA", "Incorrect guess. At position " + (i + 1) + " expected " + even.get(i) + ", found " + vals[i], EARLY_EXIT_CODE);
                            }
                        }
                        return writeResult(out, log, "OK", queries + " queries", OK_EXIT_CODE);
                    } else {
                        return writeResult(out, log, "PE", "After query " + queries + ": expected ? or !, got something else", EARLY_EXIT_CODE);
                    }
                }
            }
        }

    }

    private static int readNumber(Scanner pipeIn, PrintWriter log, int fromInclusive, int toInclusive) throws Exception {
        int value = pipeIn.nextInt();
        if (!DO_NOT_LOG) {
            log.println("<<< " + value);
        }
        if (value < fromInclusive || value > toInclusive) {
            throw new Exception("Expected value in range [" + fromInclusive + ".." + toInclusive + "], found " + value);
        }
        return value;
    }

    private static void send(final PrintWriter pipeOut, final PrintWriter log, final String string) {
        pipeOut.println(string);
        pipeOut.flush();
        if (!DO_NOT_LOG) {
            log.println(">>> " + string);
        }
    }

    private static int writeResult(final PrintWriter out, final PrintWriter log, final String outcome, final String comment, int exitCode) {
        log.println(outcome + " " + comment);
        out.println(KEY);
        out.println(outcome);
        out.println(comment);
        return exitCode;
    }

    public static void main(String[] args) throws IOException {
        System.exit(run(
                args.length >= 1 ? args[0] : "interactive.in",
                args.length >= 2 ? args[1] : "interactive.out"
        ));
    }
}

