/******************************************************************/
/* ACM ICPC 2017-2018                                             */
/* NEERC - Northern Eurasia Finals                                */
/* St Petersburg - Barnaul - Tbilisi - Almaty, December 3, 2017   */
/******************************************************************/
/* Problem I. Interactive Sort                                    */
/*                                                                */
/* Original idea         Borys Minaiev                            */
/* Problem statement     Borys Minaiev                            */
/* Test set              Borys Minaiev                            */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Borys Minaiev                            */
/******************************************************************/

import java.io.*;
import java.util.*;

import static java.util.stream.IntStream.concat;

public class interactive_bm {
    private FastScanner in;
    private PrintWriter out;

    class Interactor {
        int[] even, odd;
        boolean interactWithStdin;
        int n;

        Interactor() {
            interactWithStdin = true;
            n = in.nextInt();
        }

        int getEvenCnt() {
            return n / 2;
        }

        int getOddCnt() {
            return (n + 1) / 2;
        }

        Interactor(int n) {
            this.n = n;
            even = new int[n / 2];
            odd = new int[(n + 1) / 2];
            for (int i = 1; i <= n; i++) {
                if (i % 2 == 0) {
                    even[(i - 1) / 2] = i;
                } else {
                    odd[i / 2] = i;
                }
            }
            shuffle(even);
            shuffle(odd);
        }

        int queries = 0;

        boolean isBigger(int i, int j) {
            queries++;
            if (interactWithStdin) {
                out.println("? " + (i + 1) + " " + (j + 1));
                out.flush();
                return in.next().equals(">");
            }
            return even[i] > odd[j];
        }

        void answer(int[] resA, int[] resB) {
            if (interactWithStdin) {
                out.print("!");
                concat(Arrays.stream(resA), Arrays.stream(resB)).boxed().forEach(i -> out.print(" " + i));
                out.println();
                out.flush();
                return;
            }
            System.err.println("queries " + queries);
            if (!Arrays.equals(resA, even) || !Arrays.equals(resB, odd)) {
                throw new AssertionError();
            }
        }
    }

    private void solve(boolean interactWithStdin) {
        Interactor interactor = interactWithStdin ? new Interactor() : new Interactor(10000);
        int evenCnt = interactor.getEvenCnt();
        int oddCnt = interactor.getOddCnt();
        ArrayList<ArrayList<Integer>> groups = new ArrayList<>();
        ArrayList<Integer> all = new ArrayList<>();
        for (int i = 0; i < evenCnt; i++) {
            all.add(i);
        }
        groups.add(all);
        int[] resB = new int[oddCnt];
        Arrays.fill(resB, -1);
        for (int it = 0; it < oddCnt; it++) {
            int bId = -1;
            while (bId == -1 || resB[bId] != -1) {
                bId = rnd.nextInt(oddCnt);
            }
            int l = 0, r = groups.size() - 1;
            while (r - l > 1) {
                int mid = (l + r) >> 1;
                ArrayList<Integer> ids = groups.get(mid);
                int checkId = ids.get(rnd.nextInt(ids.size()));
                if (interactor.isBigger(checkId, bId)) {
                    r = mid;
                } else {
                    l = mid;
                }
            }
            int sum = 0;
            ArrayList<ArrayList<Integer>> newGroups = new ArrayList<>();
            for (int i = 0; i < l; i++) {
                sum += groups.get(i).size();
                newGroups.add(groups.get(i));
            }
            for (int x = l; x <= r; x++) {
                ArrayList<Integer> now = groups.get(x);
                ArrayList<Integer> left = new ArrayList<>();
                ArrayList<Integer> right = new ArrayList<>();
                for (int y : now) {
                    if (interactor.isBigger(y, bId)) {
                        right.add(y);
                    } else {
                        left.add(y);
                        sum++;
                    }
                }
                if (left.size() != 0) {
                    newGroups.add(left);
                }
                if (right.size() != 0) {
                    newGroups.add(right);
                }
            }
            resB[bId] = sum * 2 + 1;
            for (int i = r + 1; i < groups.size(); i++) {
                newGroups.add(groups.get(i));
            }
            groups = newGroups;
        }
        int[] resA = new int[groups.size()];
        for (int i = 0; i < groups.size(); i++) {
            resA[groups.get(i).get(0)] = (i + 1) * 2;
        }
        interactor.answer(resA, resB);
    }


    Random rnd = new Random(123);

    void shuffle(int[] a) {
        for (int i = 1; i < a.length; i++) {
            int pos = rnd.nextInt(i + 1);
            int tmp = a[i];
            a[i] = a[pos];
            a[pos] = tmp;
        }
    }

    private void runIO() {
        in = new FastScanner(System.in);
        out = new PrintWriter(System.out);

        solve(true);

        out.close();
    }

    private class FastScanner {
        BufferedReader br;
        StringTokenizer st;

        FastScanner(File f) {
            try {
                br = new BufferedReader(new FileReader(f));
            } catch (FileNotFoundException e) {
                e.printStackTrace();
            }
        }

        FastScanner(InputStream f) {
            br = new BufferedReader(new InputStreamReader(f));
        }

        String next() {
            while (st == null || !st.hasMoreTokens()) {
                String s = null;
                try {
                    s = br.readLine();
                } catch (IOException e) {
                    e.printStackTrace();
                }
                if (s == null)
                    return null;
                st = new StringTokenizer(s);
            }
            return st.nextToken();
        }

        boolean hasMoreTokens() {
            while (st == null || !st.hasMoreTokens()) {
                String s = null;
                try {
                    s = br.readLine();
                } catch (IOException e) {
                    e.printStackTrace();
                }
                if (s == null)
                    return false;
                st = new StringTokenizer(s);
            }
            return true;
        }

        int nextInt() {
            return Integer.parseInt(next());
        }

        long nextLong() {
            return Long.parseLong(next());
        }

        double nextDouble() {
            return Double.parseDouble(next());
        }
    }

    public static void main(String[] args) {
        new interactive_bm().runIO();
    }
}
