/******************************************************************/
/* ACM ICPC 2017-2018                                             */
/* NEERC - Northern Eurasia Finals                                */
/* St Petersburg - Barnaul - Tbilisi - Almaty, December 3, 2017   */
/******************************************************************/
/* Problem I. Interactive Sort                                    */
/*                                                                */
/* Original idea         Borys Minaiev                            */
/* Problem statement     Borys Minaiev                            */
/* Test set              Borys Minaiev                            */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Borys Minaiev                            */
/******************************************************************/

import java.io.*;
import java.util.*;

import static java.util.stream.IntStream.concat;

public class interactive_bm_random_opt3 {
    private FastScanner in;
    private PrintWriter out;

    Random rnd = new Random(123);

    Interactor interactor;

    short[] qX;
    short[] qY;
    BitSet[] was, g;
    List<Integer>[] gBack, gForw;
    Answer ans;
    int even;

    private void solve() {
        interactor = new Interactor();
        long START = System.currentTimeMillis();
        int n = interactor.n;
        even = n / 2;
        int odd = (n + 1) / 2;
        gBack = new ArrayList[n];
        gForw = new ArrayList[n];
        for (int i = 0; i < n; i++) {
            gBack[i] = new ArrayList<>();
            gForw[i] = new ArrayList<>();
        }
        was = new BitSet[n];
        for (int i = 0; i < n; i++) {
            was[i] = new BitSet(n);
        }
        qX = new short[n * n / 2];
        qY = new short[n * n / 2];
        g = new BitSet[n];
        for (int i = 0; i < n; i++) {
            g[i] = new BitSet(n);
        }
        ans = new Answer(n);
        if (answerFound(ans)) {
            return;
        }
        for (int it = 0; it < 10000; it++) {
            int x = rnd.nextInt(even);
            int y = rnd.nextInt(odd);
            if (go(x, y)) {
                return;
            }
        }
        for (int x = 0; x < even; x++) {
            for (int y = 0; y < odd; y++) {
                if (go(x, y)) {
                    return;
                }
            }
        }
        System.err.println("time = " + (System.currentTimeMillis() - START));
    }

    boolean go(int x, int y) {
        if (g[x].get(even + y) || g[even + y].get(x)) {
            return false;
        }
        y += even;
        if (interactor.isBigger(x, y - even)) {
            int tmp = x;
            x = y;
            y = tmp;
        }
        g[x].set(y);
        gBack[y].add(x);
        gForw[x].add(y);
        was[x].set(y);
        int qIt = 0, qSz = 0;
        qX[qSz] = (short) x;
        qY[qSz++] = (short) y;
        while (qIt < qSz) {
            x = qX[qIt];
            y = qY[qIt++];
            ans.sub(x);
            g[x].set(y);
            for (int tox : gBack[x]) {
                if (!was[tox].get(y)) {
                    was[tox].set(y);
                    qX[qSz] = (short) tox;
                    qY[qSz++] = (short) y;
                }
            }
            for (int toy : gForw[y]) {
                if (!was[x].get(toy)) {
                    was[x].set(toy);
                    qX[qSz] = (short) x;
                    qY[qSz++] = (short) toy;
                }
            }
        }

        return (answerFound(ans));
    }

    class Interactor {
        int[] even, odd;
        boolean interactWithStdin;
        int n;

        Interactor() {
            interactWithStdin = true;
            n = in.nextInt();
        }

        int getEvenCnt() {
            return n / 2;
        }

        int getOddCnt() {
            return (n + 1) / 2;
        }

        Interactor(int n) {
            this.n = n;
            even = new int[n / 2];
            odd = new int[(n + 1) / 2];
            for (int i = 1; i <= n; i++) {
                if (i % 2 == 0) {
                    even[(i - 1) / 2] = i;
                } else {
                    odd[i / 2] = i;
                }
            }
            shuffle(even);
            shuffle(odd);
        }

        int queries = 0;

        boolean isBigger(int i, int j) {
            queries++;
            if (interactWithStdin) {
                out.println("? " + (i + 1) + " " + (j + 1));
                out.flush();
                return in.next().equals(">");
            }
            return even[i] > odd[j];
        }

        void answer(int[] res) {
            if (interactWithStdin) {
                out.print("!");
                Arrays.stream(res).boxed().forEach(i -> out.print(" " + i));
                out.println();
                out.flush();
                return;
            }
            System.err.println("queries " + queries);
            int[] expected = concat(Arrays.stream(even), Arrays.stream(odd)).toArray();
            if (!Arrays.equals(res, expected)) {
                throw new AssertionError();
            }
        }
    }

    void shuffle(int[] a) {
        for (int i = 1; i < a.length; i++) {
            int pos = rnd.nextInt(i + 1);
            int tmp = a[i];
            a[i] = a[pos];
            a[pos] = tmp;
        }
    }

    class Answer {

        int[] res;
        int[] cnt;
        int diff;

        Answer(int n) {
            res = new int[n];
            Arrays.fill(res, n);
            cnt = new int[n + 1];
            cnt[n] = n;
            diff = 1;
        }

        boolean sub(int x) {
            cnt[res[x]]--;
            if (cnt[res[x]] == 0) {
                diff--;
            }
            res[x]--;
            cnt[res[x]]++;
            if (cnt[res[x]] == 1) {
                diff++;
            }
            return (diff == res.length);
        }
    }

    private boolean answerFound(Answer ans) {
        if (ans.diff == ans.res.length) {
            interactor.answer(ans.res);
            return true;
        }
        return false;
    }

    private void run() {
        try {
            in = new FastScanner(new File("interactive_bm_random_slow.in"));
            out = new PrintWriter(new File("interactive_bm_random_slow.out"));

            solve();

            out.close();
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        }
    }

    private void runIO() {
        in = new FastScanner(System.in);
        out = new PrintWriter(System.out);

        solve();

        out.close();
    }

    private class FastScanner {
        BufferedReader br;
        StringTokenizer st;

        FastScanner(File f) {
            try {
                br = new BufferedReader(new FileReader(f));
            } catch (FileNotFoundException e) {
                e.printStackTrace();
            }
        }

        FastScanner(InputStream f) {
            br = new BufferedReader(new InputStreamReader(f));
        }

        String next() {
            while (st == null || !st.hasMoreTokens()) {
                String s = null;
                try {
                    s = br.readLine();
                } catch (IOException e) {
                    e.printStackTrace();
                }
                if (s == null)
                    return null;
                st = new StringTokenizer(s);
            }
            return st.nextToken();
        }

        boolean hasMoreTokens() {
            while (st == null || !st.hasMoreTokens()) {
                String s = null;
                try {
                    s = br.readLine();
                } catch (IOException e) {
                    e.printStackTrace();
                }
                if (s == null)
                    return false;
                st = new StringTokenizer(s);
            }
            return true;
        }

        int nextInt() {
            return Integer.parseInt(next());
        }

        long nextLong() {
            return Long.parseLong(next());
        }

        double nextDouble() {
            return Double.parseDouble(next());
        }
    }

    public static void main(String[] args) {
        new interactive_bm_random_opt3().runIO();
    }
}
