/******************************************************************/
/* ACM ICPC 2017-2018                                             */
/* NEERC - Northern Eurasia Finals                                */
/* St Petersburg - Barnaul - Tbilisi - Almaty, December 3, 2017   */
/******************************************************************/
/* Problem J. Journey from Petersburg to Moscow                   */
/*                                                                */
/* Original idea         Gleb Evstropov                           */
/* Problem statement     Gleb Evstropov                           */
/* Test set              Gleb Evstropov                           */
/******************************************************************/
/* Tests                                                          */
/*                                                                */
/* Author                Gleb Evstropov                           */
/******************************************************************/

import java.io.*;
import java.math.BigInteger;
import java.util.*;

public class Tests {
    class Test {
		int n;
		int m;
		int k;
		int count;
		int[] u;
		int[] v;
		int[] w;

		public void reset(int n_, int m_, int k_) {
			n = n_;
			m = m_;
			k = k_;
			count = 0;

			u = new int[m];
			v = new int[m];
			w = new int[m];
		}

		public void addEdge(int u_, int v_, int w_) {
			u[count] = u_;
			v[count] = v_;
			w[count] = w_;
			count++;
		}

		public void shuffle() {
			for (int i = 1; i < m; i++) {
				int j = myRandInt(0, i - 1);
				int tmp = u[j];
				u[j] = u[i];
				u[i] = tmp;
				tmp = v[j];
				v[j] = v[i];
				v[i] = tmp;
				tmp = w[j];
				w[j] = w[i];
				w[i] = tmp;
			}
			for (int i = 0; i < m; i++) {
				if (myRandInt(0, 1) == 0) {
					int tmp = u[i];
					u[i] = v[i];
					v[i] = tmp;
				}
			} 
		}

		Test(int n_, int m_, int k_) {
			reset(n_, m_, k_);
		}
	}

	class DSU {
		int n;
		int comps;
		int[] parent;

		DSU(int n_) {
			n = n_;
			parent = new int[n];

			comps = n;
			for (int i = 0; i < n; i++) {
				parent[i] = i;
			}
		}

		int getParent(int v) {
			if (parent[v] != v) {
				parent[v] = getParent(parent[v]);	
			}

			return parent[v];
		}

		boolean join(int u, int v) {
			u = getParent(u);
			v = getParent(v);

			if (u != v) {
				parent[u] = v;
				comps--;

				return true;
			}

			return false;
		}
	}
    
    int nTests = 0;
    static File root = new File("tests");

    Random random = new Random(43159345394151999L);

    public static void main(String[] args) throws IOException {
        if (!root.exists()) {
            try {
                root.mkdir();
            } catch (Exception e) {
                System.out.println("Can not create tests/ directory: " + e);
                return;
            }
        }

        new Tests().generate();
    }

    public void generate() {
        int kMinN = 2;
	    int kMaxN = 3000;
    	int kMinM = 1;
	    int kMaxM = 3000;
    	int kMinW = 1;
	    int kMaxW = 1_000_000_000;

	    // samples
	    writeTest(genFirstSample());
	    writeTest(genSecondSample());
	    // small hand tests
	    writeTest(genTwoNodes());
	    writeTest(genTriangleKOneDirect());
	    writeTest(genTriangleKTwoDirect());
	    writeTest(genTriangleKOneIndirect());
	    writeTest(genTriangleKTwoIndirect());
	    // Tricky hand tests
	    writeTest(genSmartHand1());
	    writeTest(genSmartHand2());
	    writeTest(genSmartHand3());
	    writeTest(genSmartHand4());
	    writeTest(genSmartHand5());

	    writeTest(genCliqueRandomWeights(4, 1, 1, 1000));
	    writeTest(genCliqueRandomWeights(4, 2, 1, 1000));
	    writeTest(genCliqueRandomWeights(10, 1, kMinW, kMaxW));
	    writeTest(genCliqueRandomWeights(10, 2, kMinW, kMaxW));
	    writeTest(genCliqueRandomWeights(10, 3, kMinW, kMaxW));
	    writeTest(genCliqueRandomWeights(54, 1, kMinW, kMaxW));
	    writeTest(genCliqueRandomWeights(54, 2, kMinW, kMaxW));
	    writeTest(genCliqueRandomWeights(54, 3, kMinW, kMaxW));
   	    writeTest(genCliqueRandomWeights(54, 4, kMinW, kMaxW));
   	    writeTest(genCliqueRandomWeights(54, 5, kMinW, kMaxW));
   	    writeTest(genCliqueRandomWeights(54, 10, kMinW, kMaxW));
   	    writeTest(genCliqueRandomWeights(54, 53, kMinW, kMaxW));

   	    writeTest(genBambooRandomWeights(4, 3, kMaxW, kMaxW));
   	    writeTest(genBambooRandomWeights(3000, 1, kMaxW, kMaxW));
   	    writeTest(genBambooRandomWeights(3000, 2999, kMaxW, kMaxW));
   	    writeTest(genBambooRandomWeights(3000, 1, kMinW, kMaxW));
   	    writeTest(genBambooRandomWeights(3000, 2, kMinW, kMaxW));
   	    writeTest(genBambooRandomWeights(3000, 3, kMinW, kMaxW));
   	    writeTest(genBambooRandomWeights(3000, 4, kMinW, kMaxW));
   	    writeTest(genBambooRandomWeights(3000, 5, kMinW, kMaxW));
   	    writeTest(genBambooRandomWeights(3000, 10, kMinW, kMaxW));
   	    writeTest(genBambooRandomWeights(3000, 100, kMinW, kMaxW));
   	    writeTest(genBambooRandomWeights(3000, 1000, kMinW, kMaxW));
   	    writeTest(genBambooRandomWeights(3000, 2997, kMinW, kMaxW));
   	    writeTest(genBambooRandomWeights(3000, 2998, kMinW, kMaxW));
   	    writeTest(genBambooRandomWeights(3000, 2999, kMinW, kMaxW));

    	writeTest(genRandomGraph(1000, 3000, 1, kMinW, kMaxW));
    	writeTest(genRandomGraph(1000, 3000, 2, kMinW, kMaxW));
    	writeTest(genRandomGraph(1000, 3000, 3, kMinW, kMaxW));
    	writeTest(genRandomGraph(1000, 3000, 4, kMinW, kMaxW));
    	writeTest(genRandomGraph(1000, 3000, 5, kMinW, kMaxW));
    	writeTest(genRandomGraph(1000, 3000, 10, kMinW, kMaxW));
    	writeTest(genRandomGraph(1000, 3000, 20, kMinW, kMaxW));
    	writeTest(genRandomGraph(1000, 3000, 30, kMinW, kMaxW));
    	writeTest(genRandomGraph(1000, 3000, 50, kMinW, kMaxW));
    	writeTest(genRandomGraph(1000, 3000, 100, kMinW, kMaxW));

    	writeTest(genRandomGraph(2000, 3000, 1, kMinW, kMaxW));
    	writeTest(genRandomGraph(2000, 3000, 2, kMinW, kMaxW));
    	writeTest(genRandomGraph(2000, 3000, 3, kMinW, kMaxW));
    	writeTest(genRandomGraph(2000, 3000, 4, kMinW, kMaxW));
    	writeTest(genRandomGraph(2000, 3000, 5, kMinW, kMaxW));
    	writeTest(genRandomGraph(2000, 3000, 10, kMinW, kMaxW));
    	writeTest(genRandomGraph(2000, 3000, 20, kMinW, kMaxW));
    	writeTest(genRandomGraph(2000, 3000, 30, kMinW, kMaxW));
    	writeTest(genRandomGraph(2000, 3000, 50, kMinW, kMaxW));
    	writeTest(genRandomGraph(2000, 3000, 100, kMinW, kMaxW));
    	writeTest(genRandomGraph(2000, 3000, 200, kMinW, kMaxW));
    	writeTest(genRandomGraph(2000, 3000, 300, kMinW, kMaxW));
    	writeTest(genRandomGraph(2000, 3000, 400, kMinW, kMaxW));
    	writeTest(genRandomGraph(2000, 3000, 500, kMinW, kMaxW));
    	writeTest(genRandomGraph(2000, 3000, 600, kMinW, kMaxW));
    	writeTest(genRandomGraph(2000, 3000, 700, kMinW, kMaxW));
    	writeTest(genRandomGraph(2000, 3000, 800, kMinW, kMaxW));
	   	writeTest(genRandomGraph(2000, 3000, 900, kMinW, kMaxW));
    	writeTest(genRandomGraph(2000, 3000, 1000, kMinW, kMaxW));


    	writeTest(genRandomGraph(2500, 3000, 500, kMinW, kMaxW));
    	writeTest(genRandomGraph(2700, 3000, 600, kMinW, kMaxW));
    	writeTest(genRandomGraph(2900, 3000, 700, kMinW, kMaxW));
    	writeTest(genRandomGraph(2990, 3000, 800, kMinW, kMaxW));
	   	writeTest(genRandomGraph(3000, 3000, 900, kMinW, kMaxW));

	   	writeTest(genAntiLevit(1501, 1));
	   	writeTest(genAntiLevit(1501, 10));
	   	writeTest(genAntiLevit(1501, 100));
	   	writeTest(genAntiLevit(1501, 500));
	   	writeTest(genAntiLevit(1501, 1000));
	   	writeTest(genAntiLevit(1501, 1500));

	   	writeTest(genLargeHeap(1501, 1));
	   	writeTest(genLargeHeap(1501, 3));
	   	writeTest(genLargeHeap(1501, 10));
	   	writeTest(genLargeHeap(1501, 200));
	   	writeTest(genLargeHeap(1501, 300));
	   	writeTest(genLargeHeap(1501, 1000));
	   	writeTest(genLargeHeap(1501, 1500));

	   	writeTest(genKnapsack(750, 1, kMinW, kMaxW));
	   	writeTest(genKnapsack(750, 10, kMinW, kMaxW));
	   	writeTest(genKnapsack(750, 100, kMinW, kMaxW));
	   	writeTest(genKnapsack(750, 200, kMinW, kMaxW));
	   	writeTest(genKnapsack(750, 500, kMinW, kMaxW));
	   	writeTest(genKnapsack(750, 550, kMinW, kMaxW));
	   	writeTest(genKnapsack(750, 600, kMinW, kMaxW));
	   	writeTest(genKnapsack(750, 650, kMinW, kMaxW));
	   	writeTest(genKnapsack(750, 700, kMinW, kMaxW));
	   	writeTest(genKnapsack(750, 730, kMinW, kMaxW));
	   	writeTest(genKnapsack(750, 740, kMinW, kMaxW));
	   	writeTest(genKnapsack(750, 745, kMinW, kMaxW));
	   	writeTest(genKnapsack(750, 750, kMinW, kMaxW));
	   	writeTest(genKnapsack(750, 755, kMinW, kMaxW));
	   	writeTest(genKnapsack(750, 760, kMinW, kMaxW));
	   	writeTest(genKnapsack(750, 770, kMinW, kMaxW));
 	   	writeTest(genKnapsack(750, 780, kMinW, kMaxW));
	   	writeTest(genKnapsack(750, 790, kMinW, kMaxW));
	   	writeTest(genKnapsack(750, 800, kMinW, kMaxW));
	   	writeTest(genKnapsack(750, 850, kMinW, kMaxW));
	   	writeTest(genKnapsack(750, 900, kMinW, kMaxW));
	   	writeTest(genKnapsack(750, 1000, kMinW, kMaxW));
	   	writeTest(genKnapsack(750, 1100, kMinW, kMaxW));
	   	writeTest(genKnapsack(750, 1200, kMinW, kMaxW));
	   	writeTest(genKnapsack(750, 1300, kMinW, kMaxW));
	   	writeTest(genKnapsack(750, 1400, kMinW, kMaxW));
	   	writeTest(genKnapsack(750, 1500, kMinW, kMaxW));

	   	writeTest(genLine(500, 3000, 100, kMinW, kMaxW));
	   	writeTest(genLine(500, 3000, 200, kMinW, kMaxW));
	   	writeTest(genLine(500, 3000, 300, kMinW, kMaxW));
	   	writeTest(genLine(500, 3000, 400, kMinW, kMaxW));
		writeTest(genLine(1000, 3000, 100, kMinW, kMaxW));
		writeTest(genLine(1000, 3000, 200, kMinW, kMaxW));
		writeTest(genLine(1000, 3000, 300, kMinW, kMaxW));
		writeTest(genLine(1000, 3000, 400, kMinW, kMaxW));
   		writeTest(genLine(1000, 3000, 500, kMinW, kMaxW));
   		writeTest(genLine(1000, 3000, 600, kMinW, kMaxW));
   		writeTest(genLine(1000, 3000, 700, kMinW, kMaxW));
   		writeTest(genLine(1000, 3000, 800, kMinW, kMaxW));
   		writeTest(genLine(1000, 3000, 900, kMinW, kMaxW));
   		writeTest(genLine(1500, 3000, 100, kMinW, kMaxW));
   		writeTest(genLine(1500, 3000, 200, kMinW, kMaxW));
   		writeTest(genLine(1500, 3000, 400, kMinW, kMaxW));
   		writeTest(genLine(1500, 3000, 600, kMinW, kMaxW));
   		writeTest(genLine(1500, 3000, 800, kMinW, kMaxW));
   		writeTest(genLine(1500, 3000, 1000, kMinW, kMaxW));
   		writeTest(genLine(1500, 3000, 1200, kMinW, kMaxW));
    
    	genAlmostEqualPaths(1499, 3, 2, 777, 100, kMinW, kMaxW);
    	genAlmostEqualPaths(999, 4, 2, 100, 1000, kMinW, kMaxW);
    	genAlmostEqualPaths(999, 4, 3, 0, 1000, kMinW, kMaxW);
    	genAlmostEqualPaths(3, 1000, 500, 1, 1000, kMinW, kMaxW); 
    	genAlmostEqualPaths(3, 1000, 900, 2, 1000, kMinW, kMaxW);
    	genAlmostEqualPaths(10, 300, 250, 298, 1000, kMinW, kMaxW);
    	genAlmostEqualPaths(100, 30, 10, 15, 1000, kMinW, kMaxW); 
    }

    public Test genAlmostEqualPaths(int p, int len, int k, int who, int step, int minW, int maxW) {
    	int n = p * (len - 1) + 2;
    	int m = p * len;
    	Test test = new Test(p * (len - 1) + 2, p * len, k);
    	int cnt = 2;
    	for (int i = 0; i < p; i++) {
    		test.addEdge(1, cnt, minW + i * step);
    		cnt++;
    		for (int j = 1; j < len - 1; j++) {
    			test.addEdge(cnt - 1, cnt, minW + i * step);
    			cnt++;
    		}
    		int h = 0;
    		if (who == i) {
    			h = 1;
    		}
    		test.addEdge(cnt - 1, n, maxW - (k - 1) * step - h);
    	}

    	test.shuffle();
    	return test;
    }

    public Test genLine(int n, int m, int k, int minW, int maxW) {
    	Test test = new Test(n, m, k);
    	int cnt = 0;
    	for (int i = 1; i < n && cnt < m; i++) {
    		for (int j = 1; j <= n - i && cnt < m; j++) {
    			test.addEdge(j, j + i, myRandInt(minW, maxW));
    			cnt++;
    		}
    	}

    	test.shuffle();
    	return test;
    }

    public Test genKnapsack(int parts, int k, int minW, int maxW) {
    	Test test = new Test(1 + parts * 3, parts * 4, k);
    	for (int i = 0; i < parts; i++) {
    		int[] ws = new int[4];
    		for (int j = 0; j < 4; j++)
    			ws[j] = myRandInt(minW, maxW);
    		Arrays.sort(ws);

    		int lst = i * 3 + 1;
    		int u = i * 3 + 2;
    		int v = i * 3 + 3;
    		int w = i * 3 + 4;
    		test.addEdge(lst, u, ws[0]);
    		test.addEdge(u, w, ws[3]);
    		test.addEdge(lst, v, ws[1]);
    		test.addEdge(v, w, ws[2]); 
    	}

    	test.shuffle();
    	return test;
    }

    public Test genLargeHeap(int n, int k) {
    	Test test = new Test(n, 2 * n - 3, k);
    	for (int i = 1; i < n; i++) {
    		test.addEdge(i, i + 1, i);
    	}
    	for (int i = 3; i <= n; i++) {
    		test.addEdge(1, i, n * n - i);
    	}

    	test.shuffle();
    	return test;    
    }

    public Test genAntiLevit(int n, int k) {
    	Test test = new Test(n, 2 * n - 3, k);
    	for (int i = 1; i < n - 2; i++) {
    		test.addEdge(i, i + 1, i);
    	}
    	test.addEdge(n - 2, n, n - 1);
    	for (int i = 1; i <= n - 2; i++) {
    		test.addEdge(i, n - 1, n * n - i);
    	}
    	test.addEdge(n, n - 1, n * n - n);

    	test.shuffle();
    	return test;
    }

    public Test genRandomGraph(int n, int m, int k, int minW, int maxW) {
    	boolean[][] edges = new boolean[n][n];
    	DSU dsu = new DSU(n);
    	Test test = new Test(n, m, k);

    	while (dsu.comps > 1) {
    		int u = myRandInt(1, n) - 1;
    		int v = myRandInt(1, n) - 1;
    		if (dsu.join(u, v)) {
    			edges[u][v] = true;
    			edges[v][u] = true;
    			test.addEdge(u + 1, v + 1, myRandInt(minW, maxW)); 
    		}
    	}

    	while (test.count < m) {
    		int u = myRandInt(1, n) - 1;
    		int v = myRandInt(1, n) - 1;
    		if (u != v && !edges[u][v]) {
    			edges[u][v] = true;
    			edges[v][u] = true;
    			test.addEdge(u + 1, v + 1, myRandInt(minW, maxW));	
    		}
    	}

    	test.shuffle();
    	return test;
    }

    public Test genBambooRandomWeights(int n, int k, int minW, int maxW) {
    	Test test = new Test(n, n - 1, k);
    	for (int i = 1; i < n; i++) {
    		test.addEdge(i, i + 1, myRandInt(minW, maxW));
    	}

    	return test;
    }

    public Test genCliqueRandomWeights(int n, int k, int minW, int maxW) {
    	Test test = new Test(n, n * (n - 1) / 2, k);
    	for (int i = 1; i < n; i++) {
    		for (int j = i + 1; j <= n; j++) {
    			test.addEdge(i, j, myRandInt(minW, maxW));
    		}
    	}	

    	return test;
    }

    public Test genTriangleKOneDirect() {
    	Test test = new Test(3, 3, 1);
    	test.addEdge(1, 3, 4);
    	test.addEdge(1, 2, 3);
    	test.addEdge(3, 2, 5);

    	return test;
    }

    public Test genTriangleKOneIndirect() {
    	Test test = new Test(3, 3, 1);
    	test.addEdge(1, 2, 2);
    	test.addEdge(2, 3, 3);
    	test.addEdge(1, 3, 4);

    	return test;
    }

    public Test genTriangleKTwoDirect() {
    	Test test = new Test(3, 3, 2);
    	test.addEdge(1, 2, 1);
    	test.addEdge(2, 3, 1);
    	test.addEdge(3, 1, 1);

    	return test;
    }

    public Test genTriangleKTwoIndirect() {
    	Test test = new Test(3, 3, 2);
    	test.addEdge(1, 2, 1);
    	test.addEdge(2, 3, 1);
    	test.addEdge(3, 1, 3);

    	return test;
    }

    public Test genTwoNodes() {
    	Test test = new Test(2, 1, 1);
    	test.addEdge(1, 2, 5);

    	return test;
    }

    public Test genFirstSample() {
    	Test test = new Test(6, 7, 2);
    	test.addEdge(1, 2, 6);
    	test.addEdge(2, 3, 1);
    	test.addEdge(2, 4, 3);
    	test.addEdge(2, 5, 5);
    	test.addEdge(3, 6, 10);
    	test.addEdge(4, 6, 9);
    	test.addEdge(5, 6, 8);
    
    	return test;
    }

    public Test genSecondSample() {
    	Test test = new Test(5, 5, 3);
    	test.addEdge(2, 1, 1);
    	test.addEdge(3, 2, 1);
    	test.addEdge(4, 3, 1);
    	test.addEdge(4, 5, 1);
    	test.addEdge(1, 5, 2);
    
    	return test;
    }

    public Test genSmartHand1() {
    	Test test = new Test(8, 8, 2);
    	test.addEdge(1, 2, 2);
    	test.addEdge(2, 3, 2);
    	test.addEdge(3, 4, 2);
    	test.addEdge(4, 5, 2);
    	test.addEdge(5, 8, 10);
    	test.addEdge(1, 6, 4);
    	test.addEdge(6, 7, 4);
    	test.addEdge(7, 8, 9);

    	return test;
    }

    public Test genSmartHand2() {
    	Test test = new Test(8, 8, 2);
    	test.addEdge(1, 2, 2);
    	test.addEdge(2, 3, 2);
    	test.addEdge(3, 4, 10);
    	test.addEdge(4, 8, 2);
    	test.addEdge(1, 5, 3);
    	test.addEdge(5, 6, 8);
    	test.addEdge(6, 7, 3);
    	test.addEdge(7, 8, 3);

    	return test;
    }

    public Test genSmartHand3() {
    	Test test = new Test(10, 12, 2);
    	test.addEdge(1, 2, 1000);
    	test.addEdge(2, 3, 2000);
    	test.addEdge(3, 10, 1000);
    	test.addEdge(1, 4, 1100);
    	test.addEdge(4, 5, 1900);
    	test.addEdge(5, 10, 1100);
    	test.addEdge(1, 6, 1200);
    	test.addEdge(6, 7, 1799);
    	test.addEdge(7, 10, 1200);
    	test.addEdge(1, 8, 1300);
    	test.addEdge(8, 9, 1700);
    	test.addEdge(9, 10, 1300);

    	return test;
    }

    public Test genSmartHand4() {
    	Test test = new Test(8, 9, 2);
    	test.addEdge(1, 2, 10);
    	test.addEdge(2, 3, 10);
    	test.addEdge(3, 4, 12);
    	test.addEdge(4, 8, 1);
    	test.addEdge(1, 5, 12);
    	test.addEdge(5, 6, 1);
    	test.addEdge(6, 7, 10);
    	test.addEdge(7, 8, 10);
    	test.addEdge(3, 6, 1);

    	return test;
    }

    public Test genSmartHand5() {
    	Test test = new Test(8, 9, 3);
    	test.addEdge(1, 2, 10);
    	test.addEdge(2, 3, 10);
    	test.addEdge(3, 4, 12);
    	test.addEdge(4, 8, 1);
    	test.addEdge(1, 5, 12);
    	test.addEdge(5, 6, 1);
    	test.addEdge(6, 7, 10);
    	test.addEdge(7, 8, 10);
    	test.addEdge(3, 6, 1);

    	return test;
    }

    public int myRandInt(int lb, int rb) {
    	return lb + random.nextInt(rb - lb + 1);
    }                

    public void writeTest(Test test) {  
        try (PrintWriter out = new PrintWriter(String.format("%s/%03d", root.getName(), ++nTests))) {
            System.out.println("Writing test " + nTests);
            out.println(test.n + " " + test.m + " " + test.k);
            for (int i = 0; i < test.m; i++) {
  				out.println(test.u[i] + " " + test.v[i] + " " + test.w[i]);
            }
        } catch (Exception e) {
            System.out.println("Can not write test " + nTests + ": " + e);
        }
    }
}

