/******************************************************************/
/* ACM ICPC 2017-2018                                             */
/* NEERC - Northern Eurasia Finals                                */
/* St Petersburg - Barnaul - Tbilisi - Almaty, December 3, 2017   */
/******************************************************************/
/* Problem J. Journey from Petersburg to Moscow                   */
/*                                                                */
/* Original idea         Gleb Evstropov                           */
/* Problem statement     Gleb Evstropov                           */
/* Test set              Gleb Evstropov                           */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Pavel Mavrin                             */
/******************************************************************/

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.util.Arrays;
import java.util.StringTokenizer;

/**
 * @author Pavel Mavrin
 */
public class journey_pm {

    private static final long INF = (long) 1e15;

    private void solve() throws IOException {
        int n = nextInt();
        int m = nextInt();
        int k = nextInt();
        init(n, m);
        long[] ww = new long[m];
        for (int i = 0; i < m; i++) {
            int u = nextInt() - 1;
            int v = nextInt() - 1;
            long w = nextInt();
            addEdge(u, v, w);
            ww[i] = w;
        }
        Arrays.sort(ww);
        minW = 0;
        long res = dijkstra(0, n - 1);
        for (int i = 0; i < ww.length; i++) {
            minW = ww[i];
            res = Math.min(res, dijkstra(0, n - 1) + k * minW);
        }
        out.println(res);
    }

    long minW;

    int n, m;
    int[] head;
    int[] nx;
    int[] dst;
    long[] w;
    int last;
    long[] d;
    int[] heap;
    int[] heapRev;
    int heapSize;

    void init(int n, int m) {
        m *= 2;
        this.n = n;
        this.m = m;
        last = 0;
        head = new int[n];
        nx = new int[m];
        dst = new int[m];
        w = new long[m];
        heap = new int[n];
        heapRev = new int[n];
        d = new long[n];
        for (int i = 0; i < n; i++) {
            heap[i] = i;
            heapRev[i] = i;
        }
        Arrays.fill(head, -1);
    }

    void addEdge(int x, int y, long weight) {
        nx[last] = head[x];
        dst[last] = y;
        w[last] = weight;
        head[x] = last;
        last++;
        nx[last] = head[y];
        dst[last] = x;
        w[last] = weight;
        head[y] = last;
        last++;
    }


    private long dijkstra(int from, int to) {
        Arrays.fill(d, INF);
        heapSize = n;
        d[from] = 0;
        siftUp(heapRev[from]);
        for (int i = 0; i < n; i++) {
            int x = removeMin();
            if (d[x] == INF) {
                break;
            }
            int j = head[x];
            while (j >= 0) {
                int y = dst[j];
                long ww = Math.max(w[j] - minW, 0);
                long ll = d[x] + ww;
                if (d[y] > ll) {
                    d[y] = ll;
                    siftUp(heapRev[y]);
                }
                j = nx[j];
            }
        }
        return d[to];
    }

    private void siftUp(int i) {
        while (i > 0 && d[heap[(i - 1) / 2]] > d[heap[i]]) {
            swap(i, (i - 1) / 2);
            i = (i - 1) / 2;
        }
    }

    private int removeMin() {
        int res = heap[0];
        swap(0, heapSize - 1);
        heapSize--;
        int i = 0;
        while (2 * i + 1 < heapSize) {
            int j = i;
            if (d[heap[2 * i + 1]] < d[heap[j]]) {
                j = 2 * i + 1;
            }
            if (2 * i + 2 < heapSize && d[heap[2 * i + 2]] < d[heap[j]]) {
                j = 2 * i + 2;
            }
            if (i == j) break;
            swap(i, j);
            i = j;
        }
        return res;
    }

    private void swap(int i, int j) {
        int t = heap[i];
        heap[i] = heap[j];
        heap[j] = t;
        heapRev[heap[i]] = i;
        heapRev[heap[j]] = j;
    }

    // ------------------

    BufferedReader br = new BufferedReader(new InputStreamReader(System.in));
    StringTokenizer st;
    PrintWriter out = new PrintWriter(System.out);

    String next() throws IOException {
        while (st == null || !st.hasMoreTokens()) {
            st = new StringTokenizer(br.readLine());
        }
        return st.nextToken();
    }

    int nextInt() throws IOException {
        return Integer.parseInt(next());
    }

    public static void main(String[] args) throws IOException {
        new journey_pm().run();
    }

    private void run() throws IOException {
        solve();
        out.close();
    }

}

