/******************************************************************/
/* ACM ICPC 2017-2018                                             */
/* NEERC - Northern Eurasia Finals                                */
/* St Petersburg - Barnaul - Tbilisi - Almaty, December 3, 2017   */
/******************************************************************/
/* Problem J. Journey from Petersburg to Moscow                   */
/*                                                                */
/* Original idea         Gleb Evstropov                           */
/* Problem statement     Gleb Evstropov                           */
/* Test set              Gleb Evstropov                           */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Roman Elizarov                           */
/******************************************************************/

package journey_re_wa

data class Road(val u: Int, val v: Int, val w: Int, var ord: Int = 0)

data class Res(val w: Long, val l: Int, val cut: Int)

class DS(private val n: Int) {
    private var sz = 0
    private val pq = IntArray(n)
    private val idx = IntArray(n)
    private val ws = LongArray(n)
    private val ls = IntArray(n)
    private val f = BooleanArray(n)

    private fun clear() {
        sz = 0
        idx.fill(-1)
        f.fill(false)
    }

    private fun Int.isBetterOrEqThan(u: Int) = ws[this] < ws[u] || ws[this] == ws[u] && ls[this] <= ls[u]

    private fun add(u: Int, w: Long, l: Int) {
        if (f[u]) return
        if (idx[u] < 0) {
            idx[u] = sz++
            pq[idx[u]] = u
        } else {
            if (ws[u] < w || ws[u] == w && ls[u] <= l) return
        }
        ws[u] = w
        ls[u] = l
        var i = idx[u]
        while (i > 0) {
            val j = (i - 1) / 2
            if (pq[j].isBetterOrEqThan(pq[i])) break
            swap(i, j)
            i = j
        }
    }

    private fun swap(i: Int, j: Int) {
        val u = pq[i]
        val v = pq[j]
        idx[u] = j
        idx[v] = i
        pq[j] = u
        pq[i] = v
    }

    private fun isEmpty() = sz == 0

    private fun remove(): Int {
        val u = pq[0]
        f[u] = true
        if (--sz == 0) return u
        swap(0, sz)
        var i = 0
        while (true) {
            var j = 2 * i + 1
            if (j >= sz) break
            if (j + 1 < sz && pq[j + 1].isBetterOrEqThan(pq[j])) j++
            if (pq[i].isBetterOrEqThan(pq[j])) break
            swap(i, j)
            i = j
        }
        return u
    }

    fun compute(g: Map<Int, List<Road>>, cut: Int): Res {
        clear()
        add(0, 0, 0)
        while (!isEmpty()) {
            val u = remove()
            for (r in g[u]!!) {
                val w = if (r.ord < cut) 0 else r.w
                add(r.v, ws[u] + w, ls[u] + (if (w == 0) 0 else 1))
            }
        }
        return Res(ws[n - 1], ls[n - 1], cut)
    }
}

fun main(args: Array<String>) {
    val (n, m, k) = readLine()!!.split( " ").map { it.toInt() }
    val inp = List(m) {
        readLine()!!.split(" ").map { it.toInt() }.let {
            Road(it[0] - 1, it[1] - 1, it[2])
        }
    }
    inp.sortedBy { it.w }.forEachIndexed { ord, road -> road.ord = ord }
    val g = inp
        .flatMap { listOf(it, it.copy(u = it.v, v = it.u)) }
        .groupBy { it.u }
    val d = DS(n)
    val ans = (0..m)
        .map { cut -> d.compute(g, cut) }
        .filter { it.l == k || it.cut == 0 && it.l < k }
        .map { it.w }
        .min()
    println(ans)
}
