/******************************************************************/
/* ACM ICPC 2017-2018                                             */
/* NEERC - Northern Eurasia Finals                                */
/* St Petersburg - Barnaul - Tbilisi - Almaty, December 3, 2017   */
/******************************************************************/
/* Problem K. Knapsack Cryptosystem                               */
/*                                                                */
/* Original idea         Mikhail Dvorkin                          */
/* Problem statement     Mikhail Dvorkin                          */
/* Test set              Mikhail Dvorkin                          */
/******************************************************************/
/* Tests                                                          */
/*                                                                */
/* Author                Mikhail Dvorkin                          */
/******************************************************************/

import java.io.*;
import java.math.BigInteger;
import java.util.*;

public class Tests {
	private static File dir = new File("tests");
	private int curTest = 1;
	private static boolean verbose = true;

	private String testName;
	private PrintWriter out;
	private PrintWriter cert;
	private Random r = new Random(20752984375436566L);

	public void run() {
		t(440, 1, 10, 20, 50, 140, 420);
		for (int s = 0; s < 4; s++) {
			t(s, 1, 1, 2);
		}
		tRandom(aLinear(32, 30, 2, 566));
		tRandom(aLinear(64, 1, 2, 0));
		tRandom(aLinear(64, 1, 2, 0), 1);
		tRandom(aLinear(63, 1, 2, 1));
		tRandom(aLinear(63, 1, 2, 1), 0);
		tRandom(aLinear(40, 1, 3, 0));
		tRandom(aLinear(40, 2, 3, 1));
		tRandom(aLinear(44, 2017, 2, 3));
		tRandom(aLinear(44, 2018, 2, 3, true));
		tRandom(aLinear(50, 566, 2, 39, true));
		tRandom(aLinear(48, 32 * 13, 2, 7, true));
		for (int n = 38; n <= 54; n++) {
			tRandom(aLinear(n, 1L << (64 - n), 2, 0), 0.5 + 0.25 * r.nextInt(2));

			long[] a = new long[n];
			long v = Long.MAX_VALUE;
			for (int i = n - 1; i >= 0; i--) {
				v -= r.nextInt(1 << (63 - n));
				a[i] = v;
				v /= 2;
			}
			tRandom(a);
		}
		for (int n = 44; n <= 51; n++) {
			int s = 56 - n;
			boolean mode = r.nextBoolean();
			long[] a = new long[n];
			long sum = 1L << (63 - n);
			for (int i = 0; i < n; i++) {
				long v = sum + r.nextInt(1 << (Math.min(s + 4 + i, 30)));
				int z = mode ? s + 1 - (i % s) : r.nextInt(s);
				v >>= z; v <<= z;
				a[i] = v;
				sum += v;
			}
			tRandom(a);
		}
		for (int n = 35; n <= 51; n++) {
			long mul;
			switch (r.nextInt(3)) {
			case 0:
				mul = 0;
				break;
			case 1:
				mul = -1;
				break;
			default:
				mul = r.nextLong();
			}
			mul = (mul << n) | (r.nextLong() >>> (64 - n)) | 1;
			long first = 1L << (64 - n);
			int k2 = 0;
			boolean noise = false;
			if (r.nextInt(4) == 0) {
				first /= 64;
				first *= 1 + r.nextInt(64 - 1);
				k2 = 64;
				noise = true;
			}
			long[] a = aLinear(n, first, 2, k2, noise);
			if (r.nextBoolean()) {
				a[n - 1] += 7;
			} else {
				for (int i = 0; i < 16; i++) {
					a[n - 16 + i] += 1 << i;
				}
			}
			tRandom(a, 0.8, mul);
		}
		for (int n : new int[]{1, 3, 38, 44, 50, 64}) {
			long[] a = aLinear(n, 1, 2, 0);
			long sum = 0;
			for (int i = 0; i < n - 1; i++) {
				sum += a[i];
			}
			a[n - 1] = -1 - sum;
			tRandom(a, 0.9);
		}
		t(0, 1, 1);
		t(1, 1, 1);
	}

	long[] aLinear(int n, long first, long k1, long k2) {
		return aLinear(n, first, k1, k2, false);
	}

	long[] aLinear(int n, long first, long k1, long k2, boolean noise) {
		long[] a = new long[n];
		a[0] = first;
		for (int i = 1; i < n; i++) {
			a[i] = k1 * a[i - 1] + (noise ? (1 + r.nextInt((int) k2)) : k2);
		}
		check(a);
		return a;
	}

	void tRandom(long[] a) {
		tRandom(a, 0.5);
	}

	void tRandom(long[] a, double threshold) {
		long mul = r.nextLong() | 1;
		tRandom(a, threshold, mul);
	}

	void tRandom(long[] a, double threshold, long mul) {
		System.out.println(Arrays.toString(a));
		check(a);
		long[] b = new long[a.length];
		long sum = 0;
		for (int i = 0; i < a.length; i++) {
			b[i] = a[i] * mul;
			if (r.nextDouble() < threshold) {
				sum += b[i];
			}
		}
		t(sum, mul, b);
	}

	private void t(long sum, long mul, long... b) {
		open();
		out.println(b.length);
		for (long x : b) {
			out.println(toUnsigned(x));
		}
		out.println(toUnsigned(sum));
		cert.println(toUnsigned(mul));
		close();
	}

	void check(long[] a) {
		BigInteger sum = BigInteger.ZERO;
		for (long x : a) {
			BigInteger bx = toUnsigned(x);
			if (bx.signum() <= 0) {
				throw new RuntimeException("Negative");
			}
			if (sum.compareTo(bx) >= 0) {
				throw new RuntimeException("Overflow");
			}
			sum = sum.add(bx);
		}
//		System.out.println(sum.doubleValue() / (1L << 32) / (1L << 32) + " " + sum);
		if (sum.bitLength() > Long.SIZE) {
			throw new RuntimeException("Sum >= 2^64");
		}
	}

	public BigInteger toUnsigned(long x) {
		BigInteger bi = BigInteger.valueOf(x);
		if (x < 0) {
			bi = bi.add(BigInteger.ONE.shiftLeft(Long.SIZE));
		}
		return bi;
	}

	private void open() {
		try {
			testName = "" + curTest / 10 + curTest % 10;
			out = new PrintWriter(new File(dir, testName));
			cert = new PrintWriter(new File(dir, testName + ".cert"));
			if (verbose) { 
				System.out.print("Generating " + testName);
			}
		} catch (IOException e) {
			throw new RuntimeException("Unable to open " + testName + " for writing", e);
		}
	}

	private void close() {
		out.close();
		cert.close();
		if (verbose) {
			System.out.println(" is done.");
		}
		curTest++;
	}

	public static void main(String[] args) {
		Locale.setDefault(Locale.US);
		dir.mkdirs();
		new Tests().run();
	}
}

