/******************************************************************/
/* ACM ICPC 2017-2018                                             */
/* NEERC - Northern Eurasia Finals                                */
/* St Petersburg - Barnaul - Tbilisi - Almaty, December 3, 2017   */
/******************************************************************/
/* Problem K. Knapsack Cryptosystem                               */
/*                                                                */
/* Original idea         Mikhail Dvorkin                          */
/* Problem statement     Mikhail Dvorkin                          */
/* Test set              Mikhail Dvorkin                          */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Borys Minaiev                            */
/******************************************************************/

import java.io.*;
import java.math.BigInteger;
import java.util.*;

public class knapsack_bm_re {
    private FastScanner in;
    private PrintWriter out;

    BigInteger generateBigInteger(long v) {
        BigInteger res = BigInteger.valueOf(v);
        if (res.compareTo(BigInteger.ZERO) < 0) {
            res = res.add(BigInteger.valueOf(2).pow(63));
        }
        return res;
    }

    class Number {
        long pow2;
        long value;
        long valueInv;

        long getA(long r1) {
            return value * r1 * pow2;
        }

        Number(long v) {
            value = v;
            pow2++;
            while (value % 2 == 0) {
                value >>>= 1;
                pow2 *= 2;
            }
            BigInteger MOD = BigInteger.valueOf(2).pow(64);
            BigInteger invB1 = BigInteger.valueOf(value);
            if (invB1.compareTo(BigInteger.ZERO) < 0) {
                invB1 = invB1.add(BigInteger.valueOf(2).pow(63));
            }
            invB1 = invB1.modInverse(MOD);
            valueInv = invB1.longValue();
        }
    }

    void find(long[] bs, long sum1) {
        List<Number> numbers = new ArrayList<>();
        for (long v : bs) {
            numbers.add(new Number(v));
        }

        for (long aOdd = 1; ; aOdd += 2) {
//            System.err.println("check " + aOdd);
            long r1 = aOdd * numbers.get(0).valueInv;
            long ss = 0;
            boolean ok = true;
            for (Number num : numbers) {
                long value = num.getA(r1);
                if (value < ss) {
                    ok = false;
                    break;
                }
                ss += value;
            }
            if (ok) {
                List<BigInteger> genA = new ArrayList<>();
                for (Number num : numbers) {
                    long value = num.getA(r1);
                    genA.add(generateBigInteger(value));
                }
//                System.err.println("check:");
                long sum = sum1;
//                System.err.println("sum = " + sum + ", r = " + BigInteger.valueOf(r1).modInverse(BigInteger.valueOf(2).pow(64)));
                Number n = new Number(sum);
                BigInteger from = generateBigInteger(n.getA(r1));
//                System.err.println("from = " + from);
                char[] res = new char[bs.length];
                for (int i = bs.length - 1; i >= 0; i--) {
                    if (from.compareTo(genA.get(i)) >= 0) {
                        from = from.subtract(genA.get(i));
                        res[i] = '1';
                        sum -= bs[i];
//                        System.err.println("Now we use " + genA.get(i));
                    } else {
                        res[i] = '0';
                    }
                }
                if (from.compareTo(BigInteger.ZERO) != 0) {
                    continue;
//                    System.err.println(from);
//                    throw new AssertionError();
                }
                if (sum != 0) {
                    continue;
//                    throw new AssertionError();
                }
                out.println(new String(res));
//                System.err.println("FOUND!!!!");
                return;
            }
        }
//        throw new AssertionError();
    }

    void solve() {
        int n = in.nextInt();
        long[] a = new long[n];
        for (int i = 0; i < n; i++) {
            a[i] = new BigInteger(in.next()).longValue();
        }
        long need = new BigInteger(in.next()).longValue();
        if (n < 45) {
            findSmall(a, need);
        } else {
            find(a, need);
        }
    }

    void check(String res, long[] a, long sum) {
        for (int i = 0; i < a.length; i++) {
            if (res.charAt(i) == '1') {
                sum -= a[i];
            }
        }
        if (sum != 0) {
            throw new AssertionError();
        }
    }

    void findSmall(long[] a, long sum) {
        int n = a.length;
        long[] left = new long[n / 2];
        long[] right = new long[(n + 1) / 2];
        for (int i = 0; i < left.length; i++) {
            left[i] = a[i];
        }
        for (int i = 0; i < right.length; i++) {
            right[i] = a[i + left.length];
        }
        long[][] sumLeft = genSum(left);
        long[][] sumRight = genSum(right);
        for (int i = 0; i < sumLeft[0].length; i++) {
            long need = sum - sumLeft[0][i];
            int pos = Arrays.binarySearch(sumRight[0], need);
            if (pos >= 0) {
                String result = print(sumLeft[1][i], left.length) + print(sumRight[1][pos], right.length);
                check(result, a, sum);
                out.println(result);
                return;
            }
        }
        throw new AssertionError();
    }

    String print(long x, int len) {
        String res = "";
        for (int i = len - 1; i >= 0; i--) {
            if (((1 << i) & x) != 0) {
                res += "1";
            } else {
                res += "0";
            }
        }
        return res;
    }

    long[][] genSum(long[] vals) {
        int n = vals.length;
        if (n == 0) {
            return new long[][]{{0}, {0}};
        }
        long[][] smaller = genSum(Arrays.copyOf(vals, vals.length - 1));
        int smallestShift = 0;
        long currentValue = vals[vals.length - 1];
        for (int i = 0; i < vals.length - 1; i++) {
            if (smaller[0][i] + currentValue < smaller[0][smallestShift] + currentValue) {
                smallestShift = i;
            }
        }
        long[][] res = new long[2][1 << n];
        int i = 0, j = 0, it = 0;
        while (i < smaller[0].length && j < smaller[0].length) {
            long v1 = smaller[0][i];
            int idx = (smallestShift + j) % smaller[0].length;
            long v2 = smaller[0][idx] + currentValue;
            if (v1 < v2) {
                res[0][it] = v1;
                res[1][it] = smaller[1][i] << 1;
                i++;
            } else {
                res[0][it] = v2;
                res[1][it] = (smaller[1][idx] << 1) | 1;
                j++;
            }
            it++;
        }
        while (i < smaller[0].length) {
            long v1 = smaller[0][i];
            res[0][it] = v1;
            res[1][it] = smaller[1][i] << 1;
            i++;
            it++;
        }
        while (j < smaller[0].length) {
            int idx = (smallestShift + j) % smaller[0].length;
            long v2 = smaller[0][idx] + currentValue;
            res[0][it] = v2;
            res[1][it] = (smaller[1][idx] << 1) | 1;
            j++;
            it++;
        }
        return res;
    }

    private void solve132() {
        Random rnd = new Random(123);
        for (int tc = 0; tc < 10000; tc++) {
            System.err.println("tc = " + tc);
            long a = rnd.nextInt(1001) + 1;
            List<Long> as = new ArrayList<>();
            as.add(a);
            System.err.println("ai = " + a);
            long sum = a;
            while (sum < 1e18 && as.size() < 44) {
                long next = sum + rnd.nextInt(10) + 1;
                as.add(next);
                sum += next;
            }
            long r = 1 + 2 * rnd.nextInt(100000);
            System.err.println("R = " + r);
            System.err.println("inv = " + BigInteger.valueOf(r).modInverse(BigInteger.valueOf(2).pow(64)));
            List<Long> bs = new ArrayList<>();
            for (long ai : as) {
                bs.add(ai * r);
            }
            System.err.println(as);
            System.err.println(bs);
            long find = 0;
            long findA = 0;
            for (int i = 0; i < bs.size(); i++) {
                if (rnd.nextBoolean()) {
                    find += bs.get(i);
                    findA += as.get(i);
                    System.err.println("USE " + as.get(i));
                }
            }
            System.err.println("findA = " + findA);
            System.err.println("-> " + BigInteger.valueOf(findA).multiply(BigInteger.valueOf(r)).mod(BigInteger.valueOf(2).pow(64)));
            System.err.println("find = " + find);
            long[] bbs = new long[bs.size()];
            for (int i = 0; i < bbs.length; i++) {
                bbs[i] = bs.get(i);
            }
            findSmall(bbs, find);
        }
    }

    private void run() {
        try {
            in = new FastScanner(new File("knapsack_bm_re.in"));
            out = new PrintWriter(new File("knapsack_bm_re.out"));

            solve();

            out.close();
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        }
    }

    private void runIO() {
        in = new FastScanner(System.in);
        out = new PrintWriter(System.out);

        solve();

        out.close();
    }

    private class FastScanner {
        BufferedReader br;
        StringTokenizer st;

        FastScanner(File f) {
            try {
                br = new BufferedReader(new FileReader(f));
            } catch (FileNotFoundException e) {
                e.printStackTrace();
            }
        }

        FastScanner(InputStream f) {
            br = new BufferedReader(new InputStreamReader(f));
        }

        String next() {
            while (st == null || !st.hasMoreTokens()) {
                String s = null;
                try {
                    s = br.readLine();
                } catch (IOException e) {
                    e.printStackTrace();
                }
                if (s == null)
                    return null;
                st = new StringTokenizer(s);
            }
            return st.nextToken();
        }

        boolean hasMoreTokens() {
            while (st == null || !st.hasMoreTokens()) {
                String s = null;
                try {
                    s = br.readLine();
                } catch (IOException e) {
                    e.printStackTrace();
                }
                if (s == null)
                    return false;
                st = new StringTokenizer(s);
            }
            return true;
        }

        int nextInt() {
            return Integer.parseInt(next());
        }

        long nextLong() {
            return Long.parseLong(next());
        }

        double nextDouble() {
            return Double.parseDouble(next());
        }
    }

    public static void main(String[] args) {
        new knapsack_bm_re().runIO();
    }
}
