/******************************************************************/
/* ACM ICPC 2017-2018                                             */
/* NEERC - Northern Eurasia Finals                                */
/* St Petersburg - Barnaul - Tbilisi - Almaty, December 3, 2017   */
/******************************************************************/
/* Problem K. Knapsack Cryptosystem                               */
/*                                                                */
/* Original idea         Mikhail Dvorkin                          */
/* Problem statement     Mikhail Dvorkin                          */
/* Test set              Mikhail Dvorkin                          */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Mikhail Dvorkin                          */
/******************************************************************/

import java.io.*;
import java.math.BigInteger;
import java.util.*;

public class knapsack_md_bug3 {
	public void run() {
		int n = in.nextInt();
		long[] b = new long[n];
		for (int i = 0; i < n; i++) {
			b[i] = new BigInteger(in.next()).longValue();
		}
		long sum = new BigInteger(in.next()).longValue();
		long ans = n <= 44 ? solveMeetInTheMiddle(b, sum) : solveMerkleHellman(b, sum);
		for (int i = 0; i < n; i++) {
			out.print((ans >> i) & 1);
		}
	}

	long solveMerkleHellman(long[] b, long sum) {
		int n = b.length;
		long b0rev = modInverse(b[0] >> Long.numberOfTrailingZeros(b[0]));
		for (long x = 1;; x++) {
			long q = x * b0rev;
			long need = sum * q;
			long mask = 0;
			for (int i = n - 1; i >= 0; i--) {
				long a = b[i] * q;
				if (need >= 0 && (a <= 0 || a > need)) {
					continue;
				}
				need -= a;
				mask |= 1L << i;
			}
			if (need == 0) {
				return mask;
			}
		}
	}
	
	long modInverse(long x) {
		return BigInteger.valueOf(x).modInverse(BigInteger.ONE.shiftLeft(64)).longValue();
	}
	
	long solveMeetInTheMiddle(long[] b, long sum) {
		int n = b.length;
		long[][] left = search(Arrays.copyOf(b, n / 2), null);
		long[][] right = search(Arrays.copyOfRange(b, n / 2, n), sum);
		int i = 0;
		int j = 0;
		while (true) {
			int compare = Long.compare(left[0][i], right[0][j]);
			if (compare == 0) {
				break;
			} else if (compare < 0) {
				i++;
			} else {
				j++;
			}
		}
		return left[1][i] | (right[1][j] << (n / 2));
	}

	long[][] search(long[] b, Long sum) {
		int n = b.length;
		if (n == 0) {
			return new long[][]{new long[]{sum == null ? 0 : sum}, new long[]{0}};
		}
		long[][] prev = search(Arrays.copyOf(b, n - 1), sum);
		long val = b[n - 1] * (sum == null ? 1 : -1);
		int m = prev[0].length;
		long[][] result = new long[2][m * 2];
		int i = 0;
		int jShift = 0;
		for (int j = 1; j < m; j++) {
			if (prev[0][j] + val < prev[0][jShift] + val) {
				jShift = j;
			}
		}
		int j = 0;
		for (int k = 0; k < 2 * m; k++) {
			if (j == m || i < m && prev[0][i] <= prev[0][(jShift + j) % m] + val) {
				result[0][k] = prev[0][i];
				result[1][k] = prev[1][i];
				i++;
			} else {
				result[0][k] = prev[0][(jShift + j) % m] + val;
				result[1][k] = prev[1][(jShift + j) % m] | (1L << (n - 1));
				j++;
			}
		}
		return result;
	}

	static Scanner in;
	static PrintWriter out;

	public static void main(String[] args) throws IOException {
		in = new Scanner(System.in);
		out = new PrintWriter(System.out);
		new knapsack_md_bug3().run();
		in.close();
		out.close();
	}
}

