/******************************************************************/
/* ACM ICPC 2017-2018                                             */
/* NEERC - Northern Eurasia Finals                                */
/* St Petersburg - Barnaul - Tbilisi - Almaty, December 3, 2017   */
/******************************************************************/
/* Problem K. Knapsack Cryptosystem                               */
/*                                                                */
/* Original idea         Mikhail Dvorkin                          */
/* Problem statement     Mikhail Dvorkin                          */
/* Test set              Mikhail Dvorkin                          */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Petr Mitrichev                           */
/******************************************************************/

import java.io.*;
import java.math.BigInteger;
import java.util.Arrays;
import java.util.StringTokenizer;

/**
 * Built using CHelper plug-in
 * Actual solution is at the top
 */
public class knapsack_petr_bug2 {
    public static void main(String[] args) {
        InputStream inputStream = System.in;
        OutputStream outputStream = System.out;
        InputReader in = new InputReader(inputStream);
        PrintWriter out = new PrintWriter(outputStream);
        Knapsack solver = new Knapsack();
        solver.solve(1, in, out);
        out.close();
    }

    static class Knapsack {
        private static final long VAL = 4937486617361751531L;
        int HASH_MAX = 1 << 24;

        public void solve(int testNumber, InputReader in, PrintWriter out) {
            int n = in.nextInt();
            BigInteger[] b = new BigInteger[n];
            long[] bl = new long[n];
            for (int i = 0; i < n; ++i) {
                b[i] = new BigInteger(in.next());
                bl[i] = b[i].longValue();
            }
            BigInteger s = new BigInteger(in.next());
            long sl = s.longValue();
            if (n <= 44) {
                int n1 = n / 2;
                int n2 = n - n1;
                long[] a1 = generate(Arrays.copyOfRange(bl, 0, n1));
                long[] a2 = generate(Arrays.copyOfRange(bl, n1, n));
                int[] nextByHash = new int[a1.length];
                int[] firstByHash = new int[HASH_MAX];
                Arrays.fill(firstByHash, -1);
                for (int i1 = 0; i1 < a1.length; ++i1) {
                    int h = (int) (Long.reverse(a1[i1] * VAL) & (HASH_MAX - 1));
                    nextByHash[i1] = firstByHash[h];
                    firstByHash[h] = i1;
                }
                for (int i2 = 0; i2 < a2.length; ++i2) {
                    int h = (int) (Long.reverse((sl - a2[i2]) * VAL) & (HASH_MAX - 1));
                    int i1 = firstByHash[h];
                    while (i1 >= 0) {
                        if (a1[i1] + a2[i2] == sl) {
                            int t = i1;
                            for (int i = 0; i < n1; ++i) {
                                out.print(t % 2);
                                t /= 2;
                            }
                            t = i2;
                            for (int i = 0; i < n2; ++i) {
                                out.print(t % 2);
                                t /= 2;
                            }
                            out.println();
                            return;
                        }
                        i1 = nextByHash[i1];
                    }
                }
            } else {
                long max = (1L << (65 - n));
                int p2 = b[0].getLowestSetBit();
                if (p2 > 65 - n) throw new RuntimeException();
                long by = b[0].shiftRight(p2).modInverse(BigInteger.ONE.shiftLeft(64 - p2)).longValue();
                if (!b[0].multiply(BigInteger.valueOf(by)).mod(BigInteger.ONE.shiftLeft(64)).equals(BigInteger.ONE.shiftLeft(p2))) {
                    throw new RuntimeException();
                }
                long[] bt = new long[n];
                for (int i = 0; i < n; ++i) {
                    bt[i] = bl[i] * by;
                }
                long st = sl * by;
                long[] bf = new long[n];
                int[] take = new int[n];
                outer:
                for (long step = (1 << p2); step < max; ++step) {
                    long m = (step >> p2);
                    //if (p2 > 0) m *= (1 + (step << (64 - p2)));
                    long sum = 0;
                    int overflows = 0;
                    for (int i = 0; i < n; ++i) {
                        long cur = bt[i] * m;
                        if (cur <= 0) {
                            if (sum < 0 && sum >= cur) {
                                continue outer;
                            }
                        } else {
                            if (sum < 0 || sum >= cur) {
                                continue outer;
                            }
                        }
                        sum += cur;
                        if (sum < cur) ++overflows;
                        if (overflows > 1 || (overflows == 1 && sum >= 0)) {
                            continue outer;
                        }
                        bf[i] = cur;
                    }
                    long sf = st * m;

                    for (int i = n - 1; i >= 0; --i) {
                        if (sf < 0 || (bf[i] > 0 && sf >= bf[i])) {
                            sf -= bf[i];
                            take[i] = 1;
                        } else {
                            take[i] = 0;
                        }
                    }
                    if (sf == 0) {
                        for (int x : take) out.print(x);
                        out.println();
                        return;
                    }
                }
            }
            throw new RuntimeException();
        }

        private long[] generate(long[] a) {
            long[] b = new long[1 << a.length];
            b[0] = 0;
            for (int i = 0; i < a.length; ++i) {
                int d = 1 << i;
                long v = a[i];
                for (int j = 0; j < d; ++j) {
                    b[j + d] = b[j] + v;
                }
            }
            return b;
        }

    }

    static class InputReader {
        public BufferedReader reader;
        public StringTokenizer tokenizer;

        public InputReader(InputStream stream) {
            reader = new BufferedReader(new InputStreamReader(stream), 32768);
            tokenizer = null;
        }

        public String next() {
            while (tokenizer == null || !tokenizer.hasMoreTokens()) {
                try {
                    tokenizer = new StringTokenizer(reader.readLine());
                } catch (IOException e) {
                    throw new RuntimeException(e);
                }
            }
            return tokenizer.nextToken();
        }

        public int nextInt() {
            return Integer.parseInt(next());
        }

    }
}


