/******************************************************************/
/* ACM ICPC 2017-2018                                             */
/* NEERC - Northern Eurasia Finals                                */
/* St Petersburg - Barnaul - Tbilisi - Almaty, December 3, 2017   */
/******************************************************************/
/* Problem L. Laminar Family                                      */
/*                                                                */
/* Original idea         Maxim Akhmedov                           */
/* Problem statement     Maxim Akhmedov                           */
/* Test set              Maxim Akhmedov                           */
/******************************************************************/
/* Tests                                                          */
/*                                                                */
/* Author                Maxim Akhmedov                           */
/******************************************************************/

import java.io.*;
import java.util.*;

abstract class Generator<T extends Generator> {
    Tests parent;
    Random random;
    
    Generator(Tests parent) {
        this.parent = parent;
        this.random = parent.random;
    }

    List<Integer>[] G;
    int[][] E;
    int ept = 0;
    int[][] P;
    int ppt = 0;
    int noisePathCount = 0;

    public T setN(int n) {
        G = new List[n];
        for (int i = 0; i < n; i++) {
            G[i] = new ArrayList<>(1);
        }
        E = new int[n - 1][2];
        return (T)this;
    }

    public T setK(int k) {
        P = new int[k][2];
        return (T)this;
    }

    T setNoisePathCount(int noisePathCount) {
        this.noisePathCount = noisePathCount;
        return (T)this;
    }

    T addEdge(int a, int b) {
        if (a < 0 || b < 0 || a >= G.length || b >= G.length) {
            throw new AssertionError();
        }
        if (ept == E.length) {
            throw new AssertionError();
        }
        G[a].add(b);
        G[b].add(a);
        E[ept][0] = a;
        E[ept][1] = b;
        ++ept;
        return (T)this;
    }

    T addPath(int a, int b) {
        if (a < 0 || b < 0 || a >= G.length || b >= G.length) {
            throw new AssertionError();
        }
        if (ppt == P.length) {
            throw new AssertionError();
        }
        P[ppt][0] = a;
        P[ppt][1] = b;
        ++ppt;
        return (T)this;
    }

    void flush(boolean shuffle) {
        // TODO: proper shuffling.
        try (PrintWriter out = new PrintWriter(String.format("%s/%02d", parent.root.getName(), ++parent.nTests))) {
            System.out.println("Writing test " + parent.nTests);
            int n = G.length;
            int k = P.length + noisePathCount;
            if (n > parent.maxN || k > parent.maxK) {
                throw new AssertionError();
            }
            out.println(n + " " + k);
            int[] perm = new int[n];
            if (ept != n - 1) {
                throw new AssertionError();
            }
            if (ppt != P.length) {
                throw new AssertionError();
            }
            P = Arrays.copyOf(P, k);
            for (int i = ppt; i < k; ++i) {
                P[i] = new int[] {random.nextInt(n), random.nextInt(n)};
            }

            for (int i = 0; i < n; i++) {
                perm[i] = i + 1;
                if (shuffle) {
                    int j = random.nextInt(i + 1);
                    int t = perm[i];
                    perm[i] = perm[j];
                    perm[j] = t;
                }
            }

            if (shuffle) {
                for (int i = 0; i < E.length; i++) {
                    int j = random.nextInt(i + 1);
                    int[] t = E[i];
                    E[i] = E[j];
                    E[j] = t;
                }

                for (int i = 0; i < P.length; i++) {
                    int j = random.nextInt(i + 1);
                    int[] t = P[i];
                    P[i] = P[j];
                    P[j] = t;
                }
            }

            for (int i = 0; i < E.length; i++) {
                int a = perm[E[i][0]];
                int b = perm[E[i][1]];
                if (shuffle && random.nextInt(2) == 1) {
                    int t = a;
                    a = b;
                    b = t;
                }
                out.println(a + " " + b);
            }

            for (int i = 0; i < P.length; i++) {
                int a = perm[P[i][0]];
                int b = perm[P[i][1]];
                if (shuffle && random.nextInt(2) == 1) {
                    int t = a;
                    a = b;
                    b = t;
                }
                out.println(a + " " + b);
            }
        } catch (IOException e) {
            System.out.println("Can not flush " + parent.nTests + ": " + e);
        }
        E = null;
        P = null;
        ept = ppt = 0;
    }
}

class HandGenerator extends Generator<HandGenerator> {
    HandGenerator(Tests parent) {
        super(parent);
    }
}

class BambooGenerator extends Generator<BambooGenerator>
{
    int n;
    BambooGenerator(Tests parent, int n) {
        super(parent);
        this.n = n;
    }

    BambooGenerator generateBamboo() {
        setN(n);
        for (int i = 0; i < n - 1; i++) {
            addEdge(i, i + 1);
        }
        return this;
    }

    BambooGenerator generateIndependent() {
        int k = n - noisePathCount;
        setK(k);
        for (int i = 0; i < k; ++i) {
            addPath(i, i);
        }
        return this;
    }

    BambooGenerator generateCoinciding() {
        int k = n - noisePathCount;
        setK(k);
        for (int i = 0; i < k; ++i) {
            addPath(0, n - 1);
        }
        return this;
    }

    BambooGenerator generateNested() {
        int k = n - noisePathCount;
        int l = 0, r = n - 1;
        setK(k);
        for (int i = 0; i < k; i++) {
            addPath(l, r);
            if (random.nextInt(2) == 0) {
                ++l;
            } else {
                --r;
            }
        }
        return this;
    }

    BambooGenerator generateSomeStructure(int p) {
        int k = n - noisePathCount;
        setK(k);
        for (int i = 0; i < k - k / 2; i++) {
            addPath(0, n - 1);
        }
        for (int i = 0; i < k / 2; i++) {
            int a = 2 * i, b = 2 * i + 1;
            if (a > p && a > 0) {
                --a;
                --b;
                p = n;
            }
            addPath(a, b);
        }
        return this;
    }
}

class StarGenerator extends Generator<StarGenerator>
{
    int n;
    StarGenerator(Tests parent, int n) {
        super(parent);
        this.n = n;
    }

    StarGenerator generateStar() {
        setN(n);
        for (int i = 1; i < n; i++) {
            addEdge(0, i);
        }
        return this;
    }

    StarGenerator generateIndependent() {
        int k = n - noisePathCount;
        setK(k);
        for (int i = 0; i < k; ++i) {
            addPath(i, i);
        }
        return this;
    }

    StarGenerator generateCoinciding() {
        int k = n - noisePathCount;
        setK(k);
        for (int i = 0; i < k; ++i) {
            addPath(0, n - 1);
        }
        return this;
    }

    StarGenerator generateVeryBad() {
        int k = n - noisePathCount;
        setK(k);
        for (int i = 0; i < k; i++) {
            addPath(i, (i + 1) % k);
        }
        return this;
    }

    StarGenerator generateSomeStructure() {
        int k = n - noisePathCount;
        setK(k);
        for (int i = 0; i < k; i++) {
            int r = random.nextInt(2);
            if (r == 0) {
                addPath(1, 2);
            } else {
                int a = random.nextInt(n);
                addPath(a, a);
            }
        }
        return this;
    }
}

class PathBasedGenerator<T extends PathBasedGenerator> extends Generator<T>
{
    int prohibitedVertex;

    PathBasedGenerator(Tests parent, int prohibitedVertex)
    {
        super(parent);
        this.prohibitedVertex = prohibitedVertex;
    }

    int[] pathImpl(int x, int y, int cnt, int prv) {
        if (x == prohibitedVertex) {
            return null;
        }
        if (x == y) {
            int[] res = new int[cnt + 1];
            res[cnt] = x;
            return res;
        }
        for (int t : G[x]) {
            if (t == prv) {
                continue;
            }
            int[] res = pathImpl(t, y, cnt + 1, x);
            if (res == null) {
                continue;
            }
            res[cnt] = x;
            return res;
        }
        return null;
    }

    int[] path(int x, int y) {
        return pathImpl(x, y, 0, -1);
    }

    void go(int[] path, int cnt) {
        if (cnt == 0) {
            return;
        }
        if (path.length == 0) {
            return;
        }
        int a = random.nextInt(path.length);
        int b = random.nextInt(path.length);
        if (a > b) {
            int t = a;
            a = b;
            b = t;
        }
        addPath(path[a], path[b]);
        --cnt;
        if (cnt == 0) {
            return;
        }
        int[] central = Arrays.copyOfRange(path, a, b + 1);
        int[] left = Arrays.copyOfRange(path, 0, a);
        int[] right = Arrays.copyOfRange(path, b + 1, path.length);
        int cntCentral = 0, cntLeft = 0, cntRight = 0;
        for (int i = 0; i < cnt; i++) {
            int x = random.nextInt(path.length);
            if (x < a) {
                ++cntLeft;
            } else if (a <= x && x <= b) {
                ++cntCentral;
            } else if (b < x) {
                ++cntRight;
            } else {
                throw new AssertionError();
            }
        }
        go(central, cntCentral);
        go(left, cntLeft);
        go(right, cntRight);
    }
}

class PerfectBinaryTreeGenerator extends PathBasedGenerator<PerfectBinaryTreeGenerator> {
    int n, k;
    PerfectBinaryTreeGenerator(Tests parent, int n, int k) {
        super(parent, -1);
        this.n = n;
        this.k = k;
    }

    PerfectBinaryTreeGenerator generatePerfectBinaryTree() {
        setN(n);
        for (int i = 1; i < n; i++) {
            addEdge(i, (i - 1) / 2);
        }
        return this;
    }

    PerfectBinaryTreeGenerator generateInteresting() {
        setK(k - noisePathCount);
        for (int i = 0; i < k - noisePathCount; i++) {
            int x, y;
            while (true) {
                x = random.nextInt(n);
                y = x - 1;
                if (y >= 0 && x % 2 == 1 && Integer.highestOneBit(x) % 2 == 0) {
                    break;
                }
            }
            addPath(x, y);
        }
        return this;
    }

    PerfectBinaryTreeGenerator generatePaths() {
        System.out.println("This test may take some time to generate, please be patient...");
        int leaves = 0;
        for (int i = 0; i < n; i++) {
            if (2 * i >= n) {
                ++leaves;
            }
        }
        setK(Math.min(k, leaves) - noisePathCount);
        for (int i = 0; i < n; i++) {
            if (2 * i < n || ppt == P.length) {
                continue;
            }
            int j = i;
            int iter = 1;
            while (j % 2 == 0 && j > 0) {
                j = j >> 1;
                ++iter;
            }
            int[] p = path(i, j);
            go(p, Math.min(P.length - ppt, iter));
        }
        return this;
    }
}

class RandomYesMultiTestGenerator extends PathBasedGenerator<RandomYesMultiTestGenerator>
{
    int s;
    int n;
    RandomYesMultiTestGenerator(Tests parent, int s, int n) {
        super(parent, 0);
        this.s = s;
        this.n = n;
    }

    RandomYesMultiTestGenerator generate() {
        int subtreeCount = (n - 1) / s;
        int n = subtreeCount * s + 1;
        setN(subtreeCount * s + 1);
        setK(n - 1);
        int vpt = 1;

        for (int i = 0; i < subtreeCount; ++i) {
            for (int j = 0; j < s; j++) {
                int par = (j == 0) ? 0 : i * s + 1 + random.nextInt(j);
                addEdge(par, i * s + 1 + j);
            }
            int a = i * s + 1 + random.nextInt(s);
            int b = i * s + 1 + random.nextInt(s);
            int[] p = path(a, b);
            go(p, s);
        }
        return this;
    }
}

class RandomBambooYesGenerator extends PathBasedGenerator<RandomBambooYesGenerator>
{
    int n, k;
    RandomBambooYesGenerator(Tests parent, int n, int k) {
        super(parent, -1);
        this.n = n;
        this.k = k;
    }

    RandomBambooYesGenerator generate() {
        setN(n);
        setK(k);

        for (int i = 0; i < n - 1; i++) {
            addEdge(i, i + 1);
        }

        int[] p = path(0, n - 1);
        go(p, k);

        return this;
    }
}

public class Tests {
    final int maxN = 100 * 1000;
    final int maxK = 100 * 1000;

    int nTests = 0;
    static File root = new File("tests");
    Random random = new Random(43159345394151999L);

    public static void main(String[] args) throws IOException {
        if (!root.exists()) {
            try {
                root.mkdir();
            } catch (Exception e) {
                System.out.println("Can not create tests/ directory: " + e);
                return;
            }
        }

        new Tests().generate();
    }

    void generate() {
        generateSamples();
        generateHandTests();
        // Bunch of tests for checking against the naive solution.
        generateTestBunch(15, 15, false);
        // Bunch of large tests.
        generateTestBunch(maxN, maxK, true);
    }

    ////////////////////////////////////////////////////////////////////////////////

    void generateSamples() {
        // No: (0 1) partially interects with (3, 1).
        new HandGenerator(this)
                .setN(4)
                .setK(2)
                .addEdge(0, 1)
                .addEdge(1, 2)
                .addEdge(1, 3)
                .addPath(0, 1)
                .addPath(3, 1)
                .flush(false);

        // Yes.
        new HandGenerator(this)
                .setN(6)
                .setK(5)
                .addEdge(0, 1)
                .addEdge(1, 2)
                .addEdge(2, 3)
                .addEdge(4, 5)
                .addEdge(4, 1)
                .addPath(1, 0)
                .addPath(5, 5)
                .addPath(0, 3)
                .addPath(2, 3)
                .addPath(3, 0)
                .flush(false);
    }

    ////////////////////////////////////////////////////////////////////////////////

    void generateHandTests() {
        // Single vertex, single path.
        new HandGenerator(this)
                .setN(1)
                .setK(1)
                .addPath(0, 0)
                .flush(false);

        // Single vertex, two paths.
        new HandGenerator(this)
                .setN(1)
                .setK(2)
                .addPath(0, 0)
                .addPath(0, 0)
                .flush(false);

        // Two vertices, edge is covered with single path.
        new HandGenerator(this)
                .setN(2)
                .setK(1)
                .addEdge(0, 1)
                .addPath(0, 1)
                .flush(false);

        // Two vertices, edge is not covered with two paths.
        new HandGenerator(this)
                .setN(2)
                .setK(2)
                .addEdge(0, 1)
                .addPath(0, 0)
                .addPath(1, 1)
                .flush(false);

        // Two vertices, edge is covered with the first path, but not the second.
        new HandGenerator(this)
                .setN(2)
                .setK(2)
                .addEdge(0, 1)
                .addPath(1, 0)
                .addPath(1, 1)
                .flush(false);

        // Two vertices, edge is covered with the second path, but not the first nor the second.
        new HandGenerator(this)
                .setN(2)
                .setK(3)
                .addEdge(1, 0)
                .addPath(0, 0)
                .addPath(1, 0)
                .addPath(1, 1)
                .flush(false);

        // Three vertices, answer is No.
        new HandGenerator(this)
                .setN(3)
                .setK(2)
                .addEdge(1, 0)
                .addEdge(2, 1)
                .addPath(1, 0)
                .addPath(1, 2)
                .flush(false);

        // Three vertices, answer is Yes.
        new HandGenerator(this)
                .setN(3)
                .setK(5)
                .addEdge(1, 0)
                .addEdge(2, 1)
                .addPath(0, 2)
                .addPath(1, 2)
                .addPath(0, 0)
                .addPath(1, 1)
                .addPath(2, 2)
                .flush(true);
    }

    ////////////////////////////////////////////////////////////////////////////////

    void generateTestBunch(int n, int k, boolean shuffle) {
        for (int s = 2; s <= Math.log(n) / 2 + 2; s++) {
            new RandomYesMultiTestGenerator(this, s, n)
                    .generate()
                    .flush(shuffle);

            new RandomYesMultiTestGenerator(this, s, n - 3)
                    .setNoisePathCount(random.nextInt(3) + 1)
                    .generate()
                    .flush(shuffle);
        }

        for (int i = 0; i < Math.log(n) / 2 + 2; i++) {
            new RandomBambooYesGenerator(this, n, k)
                    .generate()
                    .flush(shuffle);

            new RandomBambooYesGenerator(this, n, k - 3)
                    .setNoisePathCount(random.nextInt(3) + 1)
                    .generate()
                    .flush(shuffle);
        }

        {
            HandGenerator gen = new HandGenerator(this)
                    .setN(1)
                    .setK(k);
            for (int i = 0; i < k; i++) {
                gen.addPath(0, 0);
            }
            gen.flush(shuffle);
        }

        {
            HandGenerator gen = new HandGenerator(this)
                    .setN(2)
                    .setK(k)
                    .addEdge(0, 1);
            for (int i = 0; i < k; i++) {
                gen.addPath(random.nextInt(2), random.nextInt(2));
            }
            gen.flush(shuffle);
        }

        new BambooGenerator(this, n)
                .generateBamboo()
                .generateCoinciding()
                .flush(shuffle);

        new BambooGenerator(this, n)
                .setNoisePathCount(1)
                .generateBamboo()
                .generateCoinciding()
                .flush(shuffle);

        new BambooGenerator(this, n)
                .setNoisePathCount(1)
                .generateBamboo()
                .generateIndependent()
                .flush(shuffle);

        new BambooGenerator(this, n)
                .generateBamboo()
                .generateNested()
                .flush(shuffle);

        new BambooGenerator(this, n)
                .setNoisePathCount(1)
                .generateBamboo()
                .generateNested()
                .flush(shuffle);

        new BambooGenerator(this, n)
                .generateBamboo()
                .generateSomeStructure(random.nextInt(n))
                .flush(shuffle);

        new BambooGenerator(this, n)
                .generateBamboo()
                .generateSomeStructure(n)
                .flush(shuffle);

        new BambooGenerator(this, n)
                .generateBamboo()
                .setK(1)
                .addPath(0, n - 1)
                .flush(shuffle);

        new BambooGenerator(this, n)
                .setNoisePathCount(n)
                .setK(0)
                .generateBamboo()
                .flush(shuffle);

        new StarGenerator(this, n)
                .generateStar()
                .generateIndependent()
                .flush(shuffle);

        new StarGenerator(this, n)
                .generateStar()
                .generateIndependent()
                .flush(shuffle);

        new StarGenerator(this, n)
                .setNoisePathCount(random.nextInt(3) + 3)
                .generateStar()
                .generateIndependent()
                .flush(shuffle);

        new StarGenerator(this, n)
                .generateStar()
                .generateCoinciding()
                .flush(shuffle);

        new StarGenerator(this, n)
                .setNoisePathCount(random.nextInt(3) + 3)
                .generateStar()
                .generateCoinciding()
                .flush(shuffle);

        new StarGenerator(this, n)
                .generateStar()
                .generateSomeStructure()
                .flush(shuffle);

        new StarGenerator(this, n)
                .generateStar()
                .setK(2)
                .addPath(1, 2)
                .addPath(3, 3)
                .flush(shuffle);

        new PerfectBinaryTreeGenerator(this, n, k)
                .generatePerfectBinaryTree()
                .generateInteresting()
                .flush(shuffle);

        new PerfectBinaryTreeGenerator(this, n, k)
                .setNoisePathCount(random.nextInt(3) + 3)
                .generatePerfectBinaryTree()
                .generateInteresting()
                .flush(shuffle);

        new PerfectBinaryTreeGenerator(this, n, k)
                .generatePerfectBinaryTree()
                .generatePaths()
                .flush(shuffle);

        new PerfectBinaryTreeGenerator(this, n, k)
                .setNoisePathCount(random.nextInt(3) + 3)
                .generatePerfectBinaryTree()
                .generatePaths()
                .flush(shuffle);
    }
}

