/******************************************************************/
/* ACM ICPC 2017-2018                                             */
/* NEERC - Northern Eurasia Finals                                */
/* St Petersburg - Barnaul - Tbilisi - Almaty, December 3, 2017   */
/******************************************************************/
/* Problem L. Laminar Family                                      */
/*                                                                */
/* Original idea         Maxim Akhmedov                           */
/* Problem statement     Maxim Akhmedov                           */
/* Test set              Maxim Akhmedov                           */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Maxim Akhmedov                           */
/******************************************************************/

import java.io.*;
import java.util.*;

public class laminarity_ma_n {
    private final InputReader reader;
    private final OutputWriter writer;

    public laminarity_ma_n(InputReader reader, OutputWriter writer) {
        this.reader = reader;
        this.writer = writer;
    }

    public static void main(String[] args) {
        InputReader reader = new InputReader(System.in);
        OutputWriter writer = new OutputWriter(System.out);
        new laminarity_ma_n(reader, writer).run();
        writer.writer.flush();
    }

    List<Integer>[] E;
    List<Integer>[] paths;
    long[] mask;
    int[] parent;
    int[] pathEndpointXor;
    int[] stackVertex;
    int[] positionCount;
    int[] vertexPosition;
    int spt = 0;
    int[] pathState;

    int otherEndpoint(int p, int x) {
        return pathEndpointXor[p] ^ x;
    }

    void maskDfs(int x, int prv) {
        parent[x] = prv;
        for (int y : E[x]) {
            if (y == prv) {
                continue;
            }
            maskDfs(y, x);
            mask[x] ^= mask[y];
        }
    }

    boolean edgeIsCovered(int a, int b) {
        if (parent[b] == a) {
            int t = a;
            a = b;
            b = t;
        }
        return mask[a] != 0;
    }

    int coveredDegree(int x) {
        int result = 0;
        for (int y : E[x]) {
            if (edgeIsCovered(x, y)) {
                ++result;
            }
        }
        return result;
    }

    boolean buildPath(int x, int prv, int position) {
        if (coveredDegree(x) > 2) {
            return false;
        }

        vertexPosition[x] = position;
        stackVertex[spt] = x;
        int leftmostTouched = position;
        for (int p : paths[x]) {
            if (pathState[p] == 0) {
                ++positionCount[position];
                pathState[p] = 1;
            } else if (pathState[p] == 1) {
                int previousEndpoint = otherEndpoint(p, x);
                if (leftmostTouched > vertexPosition[previousEndpoint]) {
                    leftmostTouched = vertexPosition[previousEndpoint];
                }
                --positionCount[vertexPosition[previousEndpoint]];
                if (positionCount[vertexPosition[previousEndpoint]] < 0) {
                    throw new AssertionError();
                }
                pathState[p] = 2;
            } else {
                throw new AssertionError();
            }
        }
        ++spt;
        while (spt > 0 && positionCount[vertexPosition[stackVertex[spt - 1]]] == 0) {
            --spt;
        }
        if (spt != 0 && vertexPosition[stackVertex[spt - 1]] > leftmostTouched) {
            return false;
        }

        for (int y : E[x]) {
            if (y == prv) {
                continue;
            }
            if (!edgeIsCovered(x, y)) {
                continue;
            }
            return buildPath(y, x, position + 1);
        }

        if (spt != 0) {
            throw new AssertionError();
        }
        return true;
    }

    public void run() {
        int n = reader.nextInt();
        int k = reader.nextInt();
        E = new List[n];
        paths = new List[n];
        mask = new long[n];
        parent = new int[n];
        pathEndpointXor = new int[k];
        stackVertex = new int[n];
        positionCount = new int[n];
        vertexPosition = new int[n];
        Arrays.fill(vertexPosition, -1);
        pathState = new int[k];

        for (int i = 0; i < n; i++) {
            E[i] = new ArrayList<>(1);
            paths[i] = new ArrayList<>();
        }
        Random rnd = new Random();
        for (int i = 0; i < n - 1; i++) {
            int a = reader.nextInt() - 1;
            int b = reader.nextInt() - 1;
            E[a].add(b);
            E[b].add(a);
        }

        for (int i = 0; i < k; i++) {
            int a = reader.nextInt() - 1;
            int b = reader.nextInt() - 1;
            if (a == b) {
                continue;
            }
            long pathMask = rnd.nextLong();
            mask[a] ^= pathMask;
            mask[b] ^= pathMask;
            paths[a].add(i);
            paths[b].add(i);
            pathEndpointXor[i] = a ^ b;
        }

        maskDfs(0, -1);
        for (int i = 0; i < n; i++) {
            if (coveredDegree(i) == 1 && vertexPosition[i] == -1) {
                if (!buildPath(i, -1, 0)) {
                    writer.printf("No\n");
                    return;
                }
            }
        }
        writer.printf("Yes\n");
    }

    static class InputReader {
        public BufferedReader reader;
        public StringTokenizer tokenizer;

        public InputReader(InputStream stream) {
            reader = new BufferedReader(new InputStreamReader(stream), 32768);
            tokenizer = null;
        }

        public String next() {
            while (tokenizer == null || !tokenizer.hasMoreTokens()) {
                try {
                    tokenizer = new StringTokenizer(reader.readLine());
                } catch (IOException e) {
                    throw new RuntimeException(e);
                }
            }
            return tokenizer.nextToken();
        }

        public int nextInt() {
            return Integer.parseInt(next());
        }

        public double nextDouble() {
            return Double.parseDouble(next());
        }

        public long nextLong() {
            return Long.parseLong(next());
        }
    }

    static class OutputWriter {
        public PrintWriter writer;

        OutputWriter(OutputStream stream) {
            writer = new PrintWriter(stream);
        }

        public void printf(String format, Object... args) {
            writer.print(String.format(Locale.ENGLISH, format, args));
        }
    }
}
